IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfBusinessCardUpdate')
	BEGIN
		PRINT 'Dropping Procedure adfBusinessCardUpdate'
		DROP  Procedure  adfBusinessCardUpdate
	END

GO

PRINT 'Creating Procedure adfBusinessCardUpdate'
GO
/******************************************************************************
**		File: 
**		Name: adfBusinessCardUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		07.03.13	SAP				  OPENXML
*******************************************************************************/
CREATE Procedure adfBusinessCardUpdate
	@doc			Xml,
	@XPathRoot		nvarchar(256),
	@ID				TIdentifier,
	@Class			TClass,
	@FileAs			TName,
	@Comments		TNotes,
	@CompanyID		TIdentifier,
	@PositionID		TIdentifier
AS
	DECLARE @result INT
	SET NOCOUNT ON
	SET QUOTED_IDENTIFIER ON

	UPDATE [BusinessCard]
	SET
		[FileAs] = @FileAs,
		[Comments] = @Comments,
		[CompanyID] = @CompanyID,
		[PositionID] = @PositionID,
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT
	WHERE
		[ID] = @ID AND [Class] = @Class
	IF @@error != 0
		RETURN 1
	
	IF @XPathRoot = '/adfEmployeeGet'
	BEGIN
		
		DELETE [Phone] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1

		INSERT INTO [Phone] 
			([BusinessCardID], [BusinessCardClass], [PhoneTypeID], [Phone])
		SELECT
			@ID,
			@Class,
			T.c.value('PhoneTypeID[1]','int'),
			T.c.value('Phone[1]','varchar(50)')
		FROM
			@doc.nodes('/adfEmployeeGet/Phone') AS T(c)
				
		IF @@error != 0
			RETURN 1

		DELETE [Address] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1
			
		INSERT INTO [Address]
			([BusinessCardID], [BusinessCardClass], [AddressTypeID], [Street], [City], [Region], 
			[PostalCode], [Country], [Mail])
		SELECT
			@ID,
			@Class,
			T.c.value('AddressTypeID[1]','int'),
			T.c.value('Street[1]','nvarchar(256)'),
			T.c.value('City[1]','nvarchar(50)'),
			T.c.value('Region[1]','nvarchar(256)'),
			T.c.value('PostalCode[1]','varchar(50)'),
			T.c.value('Country[1]','nvarchar(256)'),
			(CASE 
				WHEN T.c.value('Mail[1]','varchar(5)')='false' THEN 0 
				ELSE 1 
			END)
		FROM
			@doc.nodes('/adfEmployeeGet/Address') AS T(c)
						
		IF @@error != 0
			RETURN 1

		DELETE [Email] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1

		INSERT INTO [Email]
			([BusinessCardID], [BusinessCardClass], [EmailTypeID], [Email], [DisplayAs])
		SELECT
			@ID,
			@Class,
			T.c.value('EmailTypeID[1]','int'),
			T.c.value('Email[1]','nvarchar(256)'),
			T.c.value('Email[1]','nvarchar(256)')
		FROM
			@doc.nodes('/adfEmployeeGet/Email') AS T(c)
			
		IF @@error != 0
			RETURN 1	
	END
	ELSE IF @XPathRoot = '/adfCompanyGet'
	BEGIN
		
		DELETE [Phone] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1

		INSERT INTO [Phone] 
			([BusinessCardID], [BusinessCardClass], [PhoneTypeID], [Phone])
		SELECT
			@ID,
			@Class,
			T.c.value('PhoneTypeID[1]','int'),
			T.c.value('Phone[1]','varchar(50)')
		FROM
			@doc.nodes('/adfCompanyGet/Phone') AS T(c)
				
		IF @@error != 0
			RETURN 1

		DELETE [Address] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1
			
		INSERT INTO [Address]
			([BusinessCardID], [BusinessCardClass], [AddressTypeID], [Street], [City], [Region], 
			[PostalCode], [Country], [Mail])
		SELECT
			@ID,
			@Class,
			T.c.value('AddressTypeID[1]','int'),
			T.c.value('Street[1]','nvarchar(256)'),
			T.c.value('City[1]','nvarchar(50)'),
			T.c.value('Region[1]','nvarchar(256)'),
			T.c.value('PostalCode[1]','varchar(50)'),
			T.c.value('Country[1]','nvarchar(256)'),
			(CASE 
				WHEN T.c.value('Mail[1]','varchar(5)')='false' THEN 0 
				ELSE 1 
			END)
		FROM
			@doc.nodes('/adfCompanyGet/Address') AS T(c)
						
		IF @@error != 0
			RETURN 1

		DELETE [Email] WHERE [BusinessCardID] = @ID AND [BusinessCardClass] = @Class
		IF @@error != 0
			RETURN 1

		INSERT INTO [Email]
			([BusinessCardID], [BusinessCardClass], [EmailTypeID], [Email], [DisplayAs])
		SELECT
			@ID,
			@Class,
			T.c.value('EmailTypeID[1]','int'),
			T.c.value('Email[1]','nvarchar(256)'),
			T.c.value('Email[1]','nvarchar(256)')
		FROM
			@doc.nodes('/adfCompanyGet/Email') AS T(c)
			
		IF @@error != 0
			RETURN 1	
	END

	RETURN 0
GO

GRANT EXEC ON adfBusinessCardUpdate TO PUBLIC
GO
