IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfCompanyGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfCompanyGet'
		DROP PROCEDURE [dbo].[adfCompanyGet]
	END
GO

PRINT 'Creating procedure adfCompanyGet'
GO

/******************************************************************************
**		File: adfCompanyGet.sql
**		Name: adfCompanyGet
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 10/04/2004 12:32:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------		--------		-------------------------------------------
**		17.11.09		SYV				    fnPjm6HasBillingPersonAccessToCompany
**
**		6.05.10		KOV				  [Company].[ApplyVAT]
**		
**
**		31.05.10		SPV				     
**									[PaymentCurrencyPoint]  [ApplyVAT]
**
**		21.05.10		KOV				  @ExchangeBanned, @ExportFinanceOnce
**
**		23.6.11		MAN			  [Company].[Number]
**		19.02.13	SAP			  [PlanProfitability],[PlanPurchases] 
**								[BIN]
*******************************************************************************/

CREATE PROCEDURE [adfCompanyGet]
	@ID TIdentifier
AS
	DECLARE @Class TClass, @UserID TIdentifier, @Private BIT
	SET NOCOUNT ON
	
	DECLARE @HasAccess INT
	SET @HasAccess = dbo.adfHasAccessRightByName('ManageCompanies') | dbo.adfHasAccessRightByName('ViewAllCompanies')
		| dbo.fnPjm6HasBillingPersonAccessToCompany(@ID)
	IF @HasAccess = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SET @Class = dbo.adfGetClassByName('Adf.Company')
	SET @UserID = dbo.adfGetCurrentUserID()
	IF EXISTS(SELECT * FROM [UserContact] WHERE [UserID] = @UserID AND [BusinessCardClass]=@Class AND [BusinessCardID]=@ID)
		SET @Private = 1
	ELSE
		SET @Private = 0
		
	SELECT
		[Company].[ID],
		[Company].[Class],
		[Company].[State],
		[Company].[Flag],
		[Company].[FileAs],
		[Company].[FoundationDate],
		[Company].[LegalName],
		[Company].[KPP],
		[Company].[LegalCode],
		[Company].[BankAccountID],
		[Company].[ExecutiveEmployeeID],
		[Company].[AccountantEmployeeID],
		[Company].[Own],
		[Company].[ManagerEmployeeID],
		[Company].[CompanySizeID],
		[Company].[CompanyTurnoverID],
		[Company].[CompanyStatusID],
		[Company].[Comments],
		[Company].[Created],
		[Company].[CreatedBy],
		[Company].[Modified],
		[Company].[ModifiedBy],
		[Company].[Timestamp],
		[ExtendedProperties].[ExtendedProperties],
		@Private as [Private],
		ISNULL([Company].[ApplyVAT], 0) as [ApplyVAT],
		ISNULL([Company].[PaymentCurrencyPoint], 0) as [PaymentCurrencyPoint],
		ISNULL([Company].[ExportFinanceOnce],0) as [ExportFinanceOnce],
		ISNULL([Company].[ExchangeBanned],0) as [ExchangeBanned],
		[Folder].[ID] AS [FolderID],
		[Company].[Number],
		[Company].[PlanProfitability],
		[Company].[PlanPurchases],
		[Company].[BIN]
	FROM
		[Company] INNER JOIN [ExtendedProperties]
			ON ([ExtendedProperties].[Class]=@Class AND [ExtendedProperties].[ID]=@ID)
		LEFT OUTER JOIN [Folder]
			ON [Folder].[FolderID] IS NULL AND [Folder].[CompanyID] = [Company].[ID]
	WHERE
		[Company].[ID] = @ID

	
	EXEC adfBusinessCardExtraInfoGet @Class, @ID
	
	SELECT
		[CompanyIndustryBranch].[IndustryBranchID]
	FROM
		[CompanyIndustryBranch]
	WHERE
		[CompanyIndustryBranch].[CompanyID] = @ID
		
	RETURN 0
GO

GRANT EXECUTE ON [adfCompanyGet] TO PUBLIC
GO

