IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'CompanyStatus') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: CompanyStatus                                         */
	/*==============================================================*/
	create table CompanyStatus (
	   ID                   TIdentifier          identity,
	   Class                TClass               not null,
	   State                TState               not null,
	   Flag                 TFlag                not null,
	   Code                 TCode                not null,
	   FileAs               TName                not null,
	   Created              TSysDateTime         not null default GETDATE(),
	   CreatedBy            TUserID              not null,
	   Modified             TSysDateTime         not null default GETDATE(),
	   ModifiedBy           TUserID              not null,
	   Comments             TNotes               null,
	   Timestamp            timestamp            not null,
	   constraint CompanyStatusPK primary key  (ID)
	)
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'CompanyStatusID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
	ALTER TABLE [Company] ADD [CompanyStatusID] TIdentifier NULL
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'Number' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Employee')
	ALTER TABLE [Employee] ADD [Number] TCode null
GO

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'Number' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
	ALTER TABLE [Company] ADD [Number] TCode null
GO



IF NOT EXISTS(SELECT [ID] FROM [AddressType] WHERE [ID] = 7)
BEGIN
	DECLARE @Class TClass
	SET @Class = dbo.adfGetClassByName('Adf.AddressType')

	SET IDENTITY_INSERT [AddressType] ON
	
	ALTER TABLE [AddressType] DISABLE TRIGGER ALL
	ALTER TABLE [DocumentGlobal] DISABLE TRIGGER ALL

	INSERT INTO [AddressType] ([ID], [State], [Flag], [FileAs]) 
	VALUES (7, 100, 0, '')
	
	INSERT INTO [DocumentGlobal] ([Class], [ID], [Language], [FileAs])
	VALUES	(@Class, 7, 'ru', '')

	INSERT INTO [DocumentGlobal] ([Class], [ID], [Language], [FileAs])
	VALUES	(@Class, 7, 'en', 'Consignee')

	ALTER TABLE [AddressType] ENABLE TRIGGER ALL
	ALTER TABLE [DocumentGlobal] ENABLE TRIGGER ALL
	
	SET IDENTITY_INSERT [AddressType] OFF	
END
GO 

--<ASA>

IF EXISTS(SELECT * FROM [AddressType] WHERE [FileAs] = '') 
BEGIN
	ALTER TABLE [AddressType] DISABLE TRIGGER ALL
	ALTER TABLE [DocumentGlobal] DISABLE TRIGGER ALL

	UPDATE [AddressType] SET [FileAs] = '' WHERE [FileAs] = ''
	UPDATE [DocumentGlobal] SET [FileAs] = '' WHERE [FileAs] = ''

	ALTER TABLE [AddressType] ENABLE TRIGGER ALL
	ALTER TABLE [DocumentGlobal] ENABLE TRIGGER ALL
END
GO

--</ASA>

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'ApplyVAT' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
BEGIN
	
	ALTER TABLE [Company] ADD [ApplyVAT] TBool NULL
	
	DECLARE @sql varchar(2000)
	SET @sql = '
		DECLARE
			@value TVariant,
			@ApplyVAT TBool
		
		EXEC adfParameterGet @Name=''ApplyVAT'', @Group=''CommonBusiness'', @Value = @value OUTPUT
		SET @ApplyVAT = CAST(@value as bit)	
		
		
		ALTER TABLE [Company] DISABLE TRIGGER ALL
		
		UPDATE [Company]
		SET
			[Company].[ApplyVAT] = @ApplyVAT
			
		ALTER TABLE [Company] ENABLE TRIGGER ALL'
			
	EXEC (@sql)
	
END
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'PaymentCurrencyPoint' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
BEGIN
	
	ALTER TABLE [Company] ADD [PaymentCurrencyPoint] TIdentifier 
	
	DECLARE @query varchar(2000)
	SET @query = '
		DECLARE
			@value TVariant,
			@PaymentCurrencyPoint TIdentifier
		
		EXEC adfParameterGet @Name=''PaymentCurrencyPoint'', @Group=''CommonBusiness'', @Value = @value OUTPUT
		SET @PaymentCurrencyPoint = ISNULL(CAST(@value as int),0)	
		
		
		ALTER TABLE [Company] DISABLE TRIGGER ALL
		
		UPDATE [Company]
		SET
			[Company].[PaymentCurrencyPoint] = @PaymentCurrencyPoint
			
		ALTER TABLE [Company] ENABLE TRIGGER ALL'
			
	EXEC (@query)
	
END

IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'ExchangeBanned' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
BEGIN
	
	ALTER TABLE [Company] ADD [ExchangeBanned] TIdentifier 
	
	SET @query = '
		
		ALTER TABLE [Company] DISABLE TRIGGER ALL
		
		UPDATE [Company]
		SET
			[Company].[ExchangeBanned] = 1
			
		ALTER TABLE [Company] ENABLE TRIGGER ALL'
			
	EXEC (@query)
	
END
IF NOT EXISTS(SELECT * FROM dbo.syscolumns WHERE [name] = 'ExportFinanceOnce' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Company')
BEGIN
	
	ALTER TABLE [Company] ADD [ExportFinanceOnce] TIdentifier 
	
	SET @query = '
		DECLARE
			@value TVariant,
			@ExportFinanceOnce TBool
		
		EXEC adfParameterGet @Name=''ExportFinanceOnce'', @Group=''Pjm6'', @Value = @value OUTPUT
		SET @ExportFinanceOnce = ISNULL(CAST(@value as int),0)	
		
		
		ALTER TABLE [Company] DISABLE TRIGGER ALL
		
		UPDATE [Company]
		SET
			[Company].[ExportFinanceOnce] = @ExportFinanceOnce
			
		ALTER TABLE [Company] ENABLE TRIGGER ALL'
			
	EXEC (@query)
	
END

IF NOT EXISTS (SELECT * FROM  syscolumns WHERE Name = 'CompanyID'  and status = 0x08 AND OBJECT_NAME(id)='Employee')
BEGIN
	ALTER TABLE Employee ALTER COLUMN CompanyID TIdentifier NULL 
END
GO