﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ContactChangesGet]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ContactChangesGet'
	drop procedure [exch].[ContactChangesGet]
end
go

print 'Creating procedure ContactChangesGet'
go

create procedure [exch].[ContactChangesGet] @UserID int  with execute as 'pjmexchangesync'
as
begin
	set nocount on;
	declare @EmployeeClass TClass;
	
	set @EmployeeClass = dbo.adfGetClassByName('Adf.Employee');

	with [Contact] ([Class], [ID], [RowVersion]) as
	(
		select
			[E].[Class],
			[E].[ID],
			cast([E].[Timestamp] as bigint) as [RowVersion]
		from 
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
				on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
		where
			[S].[UserID] = @UserID
	),
	[ExchangeLink] ([UserID], [DocumentClass], [DocumentID], [RowVersion]) as
	(
		select
			[UserID],
			[DocumentClass],
			[DocumentID],
			[RowVersion]
		from
			[exch].[ExchangeLink]
		where
			[UserID] = @UserID and [DocumentClass] = @EmployeeClass
	),
	[Reminder] ([ID], [EventTime], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			min([R].[EventTime]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[Employee] as [E]
					on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [E].[Class] and [R].[DocumentID] = [E].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID
		and
			[UR].[State] = 1
		and
			[R].[EventTime] > getdate()
		and
			[R].[Subtype] <> 'CB'
		group by
			[R].[DocumentID]
	)
	select
		coalesce([Contact].[Class], [L].[DocumentClass]) as [Class],
		coalesce([Contact].[ID], [L].[DocumentID]) as [ID]
	from	
		[Contact] full outer join [ExchangeLink] as [L]
			on ([Contact].[Class] = [L].[DocumentClass] and [Contact].[ID] = [L].[DocumentID])
		left outer join [Reminder]
			on ([Contact].[ID] = [Reminder].[ID])
	where
		isnull((case when [Contact].[RowVersion] > isnull([Reminder].[RowVersion], 0) then [Contact].[RowVersion] else [Reminder].[RowVersion] end), 0)  != isnull([L].[RowVersion], 0);

	return 0;
end
go

grant execute on [exch].[ContactChangesGet] to [projectmateservice];
go
