﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ReminderUpdate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ReminderUpdate'
	drop procedure [exch].[ReminderUpdate]
end
go

print 'Creating procedure ReminderUpdate'
go

create procedure [exch].[ReminderUpdate] @UserID TIdentifier, @DocumentClass TClass, @DocumentID TIdentifier, @EventTime TDateTime, @NextInterval int
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare @SyncReminders int, @Subtype char(2), @EmployeeClass TClass;
	SET @EmployeeClass = [dbo].[adfGetClassByName]('Adf.Employee')

	select @SyncReminders = isnull(cast([Value] as int), 1) from [UserParameter] where [Name] = 'SyncExchangeNotifications' and [UserID] = @UserID;

	select @Subtype = [Subtype] from [ReminderType] where [Class] = @DocumentClass;
	if @Subtype is null OR @DocumentClass = @EmployeeClass
		select @Subtype = [Subtype] from [ReminderType] where [Class] is null;

	if @SyncReminders = 1
	begin
		if @EventTime is not null and (select count(*) from [Reminder] where [DocumentClass] = @DocumentClass and [DocumentID] = @DocumentID) <= 1
		begin
			declare @ReminderID TIdentifier;
			select
				@ReminderID = [ID]
			from 
				[Reminder]
			where 
				[DocumentClass] = @DocumentClass and [DocumentID] = @DocumentID;
	
			if @ReminderID is null
			begin
				insert into [Reminder] 
					([DocumentClass], [DocumentID], [Subtype], [EventTime])
				values 
					(@DocumentClass, @DocumentID, @Subtype, @EventTime);

				set @ReminderID = scope_identity();
			end
			else
			begin
				update [Reminder] 
				set 
					[EventTime] = @EventTime,
					[Modified] = default
				where 
					[ID] = @ReminderID;
			end

			if not exists(select * from [UserReminder] where [ReminderID] = @ReminderID and [UserID] = @UserID)
			begin
				insert into [UserReminder] 
					([ReminderID], [UserID], [State], [OriginalInterval], [NextInterval])
				values
					(@ReminderID, @UserID, 1, @NextInterval, @NextInterval)
			end
			else
			begin
				update [UserReminder] 
				set
					[State] = 1,
					[OriginalInterval] = @NextInterval,
					[NextInterval] = @NextInterval
				where 
					[ReminderID] = @ReminderID AND [UserID] = @UserID
			end			
		end
	end
	return 0;
end;
go
