﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[TimeEntryChangesGet]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure TimeEntryChangesGet'
	drop procedure [exch].[TimeEntryChangesGet]
end
go

print 'Creating procedure TimeEntryChangesGet'
go

create procedure [exch].[TimeEntryChangesGet] @UserID int  with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare @TimeEntryClass TClass, @calendarSyncPeriod int, @date date;
	
	set @calendarSyncPeriod = isnull(cast((select [Value] from [UserParameter] where [Name] = 'SyncExchangeCalendarEntriesTimeLimit' AND [UserID] = @UserID) as int), 1);
	set @calendarSyncPeriod = case when @calendarSyncPeriod = 0 then 1 when @calendarSyncPeriod = 1 then 7 else 30 end;
	set @date = getdate();
	set @date = dateadd(day, -@calendarSyncPeriod, @date);
	
	set @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry');

	with [TimeEntry] ([Class], [ID], [RowVersion]) as
	(
		select
			[E].[Class],
			[E].[ID],
			cast([E].[Timestamp] as bigint) as [RowVersion]
		from 
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[TimeEntry] as [E]
				on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
		where
			[S].[UserID] = @UserID and [E].[StartTime] >= @date
	),
	[ExchangeLink] ([UserID], [DocumentClass], [DocumentID], [RowVersion]) as
	(
		select
			[UserID],
			[DocumentClass],
			[DocumentID],
			[RowVersion]
		from
			[exch].[ExchangeLink]
		where
			[UserID] = @UserID and [DocumentClass] = @TimeEntryClass
	),
	[Reminder] ([ID], [EventTime], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			min([R].[EventTime]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[TimeEntry] as [E]
					on ([S].[DocumentClass] = [E].[Class] and [S].[DocumentID] = [E].[ID])
			inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [E].[Class] and [R].[DocumentID] = [E].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID and [E].[StartTime] >= @date
		and
			[UR].[State] = 1
		and
			[R].[EventTime] > getdate()
		group by
			[R].[DocumentID]
	)
	select
		coalesce([TimeEntry].[Class], [L].[DocumentClass]) as [Class],
		coalesce([TimeEntry].[ID], [L].[DocumentID]) as [ID]
	from	
		[TimeEntry] full outer join [ExchangeLink] as [L]
			on ([TimeEntry].[Class] = [L].[DocumentClass] and [TimeEntry].[ID] = [L].[DocumentID])
		left outer join [Reminder]
			on ([TimeEntry].[ID] = [Reminder].[ID])
	where
		isnull((case when [TimeEntry].[RowVersion] > isnull([Reminder].[RowVersion], 0) then [TimeEntry].[RowVersion] else [Reminder].[RowVersion] end), 0)  != isnull([L].[RowVersion], 0);

	return 0;
end
go

grant execute on [exch].[TimeEntryChangesGet] to [projectmateservice];
go
