IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm5GetInvoicePlanned]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm5GetInvoicePlanned'
		DROP FUNCTION [dbo].[fnPjm5GetInvoicePlanned]
	END

GO

PRINT 'Creating function fnPjm5GetInvoicePlanned'
GO
/******************************************************************************
**		File: 
**		Name: fnPjm5GetTaskListByAssignment
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION fnPjm5GetInvoicePlanned(@ProjectID int, @StartDate datetime, @EndDate datetime, @Date datetime, @NationalCurrency varchar(8))
RETURNS decimal(18,2)
AS
BEGIN
	DECLARE @Result		money	
	
	DECLARE @table TABLE(	
		[ID]				int,
		[TotalWithVATPC]	money,
		[TotalWithVATBC]	money,
		[Payment]			money,
		[DueDate]			datetime,
		[ProjectCurrencyCode] varchar(8),
		[BaseCurrencyRate] decimal(18,4)
		)
	INSERT INTO @table(
		[ID],
		[TotalWithVATPC],
		[TotalWithVATBC],
		[Payment],
		[DueDate],
		[ProjectCurrencyCode],
		[BaseCurrencyRate]
		)	
	
	SELECT
		[Invoice].[ID],
		[Invoice].[TotalWithVATPC]- 
				ISNULL((SELECT 
					SUM(i.[TotalWithVATPC]) 
				FROM [AdvanceInvoice] INNER JOIN [Invoice] i
					ON i.[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
				WHERE
					[AdvanceInvoice].[InvoiceID] = [Invoice].[ID])
				, 0),
		[Invoice].[TotalWithVATBC]- 
				ISNULL((SELECT 
					SUM(i.[TotalWithVATBC]) 
				FROM [AdvanceInvoice] INNER JOIN [Invoice] i
					ON i.[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
				WHERE
					[AdvanceInvoice].[InvoiceID] = [Invoice].[ID])
				, 0),
		SUM(ISNULL([PaymentDetail].[Value], 0.00)),
		[Invoice].[DueDate],
		[Project].[CurrencyCode],
		[Invoice].[BaseCurrencyRate]	
	FROM	
		[Invoice]
			INNER JOIN [Project]
				ON [Invoice].[ProjectID] = [Project].[ID]
			LEFT OUTER JOIN [PaymentDetail]
				ON [Invoice].[ID] = [PaymentDetail].[InvoiceID]
	WHERE
	 	([Invoice].[State] = 6 OR 
	 	([Invoice].[State] = 2 AND [Invoice].[DueDate] >= @Date)) AND
		[Invoice].[ProjectID] = @ProjectID
	GROUP BY	
		[Invoice].[ID],
		[Invoice].[TotalWithVATPC],
		[Invoice].[TotalWithVATBC],
		[Invoice].[DueDate],
		[Project].[CurrencyCode],
		[Invoice].[BaseCurrencyRate]	
		
	SELECT
		@Result	 = SUM(CASE WHEN t.[TotalWithVATPC] = t.[Payment] THEN 0
							ELSE t.[TotalWithVATBC] - CASE WHEN t.[ProjectCurrencyCode] = @NationalCurrency
															THEN t.[Payment] / t.[BaseCurrencyRate]
															ELSE t.[Payment] * t.[BaseCurrencyRate]
														END
						END)										
	FROM
		@table AS t
					
	WHERE
		(t.[DueDate] >= @StartDate AND t.[DueDate] < @EndDate) OR (t.[DueDate] >= @StartDate AND @EndDate IS NULL)				
			
	RETURN(@Result)
END
GO

GRANT EXEC ON fnPjm5GetInvoicePlanned TO PUBLIC
GO
