IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetTimeEntriesInFinanceByCustomer]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetTimeEntriesInFinanceByCustomer'
		DROP FUNCTION [dbo].[fnReportGetTimeEntriesInFinanceByCustomer]
	END
GO

PRINT 'Creating function fnReportGetTimeEntriesInFinanceByCustomer'
GO

/******************************************************************************
**		File: fnReportGetTimeEntriesInFinanceByCustomer.sql
**		Name: fnReportGetTimeEntriesInFinanceByCustomer
**
**              
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Nikita.Golyshev
**		Date: 05.12.14 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetTimeEntriesInFinanceByCustomer
(
	@PeriodStart TDateTime,
	@PeriodEnd TDateTime,
	@CustomerID int
)
RETURNS @Result TABLE
(
	DocumentID TIdentifier,
	LinkClass	   TClass,
	LinkDocumentID TIdentifier,
	State	TState,
	ThroughCalculation TFlag
)
BEGIN
	DECLARE
		@CalculationClass TClass,
		@StatementClass TClass,
		@InvoiceClass TClass,
		@TimeEntryClass TClass,
		@ExpenseClass TClass,
		@ApprovedState TState
		
	SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET	@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')

	SET @ApprovedState = 6
		
	DECLARE @DocumentApproved TABLE
	(
		ID TIdentifier
	)

	DECLARE @DocumentInCalculation TABLE
	(
		DocumentID		 TIdentifier,
		CalculationID	 TIdentifier,
		CalculationState TState
	)
	DECLARE @DocumentInStatement TABLE
	(
		DocumentID		TIdentifier,
		StatementID		TIdentifier,
		StatementState	TState
	)
	DECLARE @DocumentInInvoice TABLE
	(
		DocumentID		TIdentifier,
		InvoiceID		TIdentifier,
		InvoiceState	TState
	)
	DECLARE @DocumentInCalculationThroughCalculation TABLE
	(
		DocumentID		 TIdentifier,
		CalculationID	 TIdentifier,
		CalculationState TState
	)
	DECLARE @DocumentInStatementThroughCalculation TABLE
	(
		DocumentID		TIdentifier,
		StatementID		TIdentifier,
		StatementState	TState
	)
	DECLARE @DocumentInInvoiceThroughCalculation TABLE
	(
		DocumentID		TIdentifier,
		InvoiceID		TIdentifier,
		InvoiceState	TState
	)

	INSERT INTO @DocumentApproved( ID )
	SELECT 
		[TimeEntry].[ID]
	FROM
		[TimeEntry]
	WHERE
		[TimeEntry].[State] = @ApprovedState
		AND
		[TimeEntry].[StartTime] >= @PeriodStart
		AND
		[TimeEntry].[StartTime] < @PeriodEnd
		AND
		(
			@CustomerID IS NULL
			OR
			[TimeEntry].[ProjectID] IN 
			(
				SELECT 
					[ID] 
				FROM 
					[Project]
				WHERE
					[Project].[CustomerCompanyID] = @CustomerID		
			)
		)

	INSERT INTO @DocumentInCalculation (DocumentID, CalculationID, CalculationState)
	SELECT
		[CalculationLine].[DocumentID],
		[Calculation].[ID],
		[Calculation].[State]
	FROM
		[CalculationLine]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	WHERE
		[CalculationLine].[DocumentClass] = @TimeEntryClass
		AND
		[CalculationLine].[DocumentID] IN
		(
			SELECT
				[@DocumentApproved].[ID]
			FROM
				@DocumentApproved
			WHERE
				[@DocumentApproved].[ID] = [CalculationLine].[DocumentID]
		)
		AND [Calculation].[State] <> 4 --  


	INSERT INTO @DocumentInStatement( DocumentID, StatementID, StatementState)
	SELECT
		[StatementLine].[DocumentID],
		[Statement].[ID],
		[Statement].[State]
	FROM
		[StatementLine]
		INNER JOIN [Statement]
			ON [Statement].[ID] = [StatementLine].[StatementID]
	WHERE
		[StatementLine].[DocumentClass] = @TimeEntryClass
		AND
		[StatementLine].[DocumentID] IN
		(
			SELECT
				[@DocumentApproved].[ID]
			FROM
				@DocumentApproved
		)
		AND [Statement].[State] <> 4 --  
		
	INSERT INTO @DocumentInInvoice ( DocumentID,InvoiceID,InvoiceState)
	SELECT
		[InvoiceLine].[DocumentID],
		[Invoice].[ID],
		[Invoice].[State]
	FROM
		[InvoiceLine]
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
	WHERE
		[InvoiceLine].[DocumentClass] = @TimeEntryClass
		AND
		[InvoiceLine].[DocumentID] IN
		(
			SELECT
				[@DocumentApproved].[ID]
			FROM
				@DocumentApproved
			WHERE
				[@DocumentApproved].[ID] = [InvoiceLine].[DocumentID]
		)
		AND [Invoice].[State]	 NOT IN (3,7) --   / 

	INSERT INTO @DocumentInCalculationThroughCalculation ( DocumentID, CalculationID, CalculationState)
	SELECT
		[@DocumentInCalculation].[DocumentID],
		[Calculation].[ID],
		[Calculation].[State]
	FROM
		[CalculationAdvance]
		INNER JOIN [Calculation]
			ON [CalculationAdvance].[CalculationID] = [Calculation].[ID]
		INNER JOIN @DocumentInCalculation
			ON [@DocumentInCalculation].[CalculationID] = [CalculationAdvance].[AdvanceCalculationID]
	WHERE
		[@DocumentInCalculation].[CalculationID] IN
		(	
			SELECT
				[CalculationLine].[CalculationID]
			FROM
				[CalculationLine]
			WHERE
				[CalculationLine].[DocumentClass] = @TimeEntryClass
		)
		
	INSERT INTO @DocumentInInvoiceThroughCalculation ( DocumentID, InvoiceID, InvoiceState )
	SELECT
		[@DocumentInCalculation].[DocumentID],
		[Invoice].[ID],
		[Invoice].[State]
	FROM
		[InvoiceLine]
		INNER JOIN @DocumentInCalculation
			ON [@DocumentInCalculation].[CalculationID] = [InvoiceLine].[DocumentID] AND [InvoiceLine].[DocumentClass] = @CalculationClass
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			
	INSERT INTO @DocumentInInvoiceThroughCalculation( DocumentID, InvoiceID, InvoiceState)
	SELECT
		[@DocumentInCalculationThroughCalculation].[DocumentID],
		[Invoice].[ID],
		[Invoice].[State]
	FROM
		[InvoiceLine]
		INNER JOIN @DocumentInCalculationThroughCalculation
			ON [@DocumentInCalculationThroughCalculation].[CalculationID] = [InvoiceLine].[DocumentID] AND [InvoiceLine].[DocumentClass] = @CalculationClass
		INNER JOIN [Invoice]
			ON 	[Invoice].[ID] = [InvoiceLine].[InvoiceID]
			
	INSERT INTO @DocumentInStatementThroughCalculation ( DocumentID,StatementID,StatementState)
	SELECT
		[@DocumentInCalculation].[DocumentID],
		[Statement].[ID],
		[Statement].[State]
	FROM
		[StatementLine]
		INNER JOIN @DocumentInCalculation
			ON [@DocumentInCalculation].[CalculationID] = [StatementLine].[DocumentID] AND [StatementLine].[DocumentClass] = @CalculationClass
		INNER JOIN [Statement]
			ON [Statement].[ID] = [StatementLine].[StatementID]

	INSERT INTO @DocumentInStatementThroughCalculation(	DocumentID,StatementID,StatementState)
	SELECT
		[@DocumentInCalculationThroughCalculation].[DocumentID],
		[Statement].[ID],
		[Statement].[State]
	FROM
		[StatementLine]
		INNER JOIN @DocumentInCalculationThroughCalculation
			ON [@DocumentInCalculationThroughCalculation].[CalculationID] = [StatementLine].[DocumentID] AND [StatementLine].[DocumentClass] = @CalculationClass
		INNER JOIN [Statement]
			ON [Statement].[ID] = [StatementLine].[StatementID]
	
	DECLARE @Temp TABLE
	(
		DocumentID TIdentifier,
		LinkClass	   TClass,
		LinkDocumentID TIdentifier,
		State	TState,
		ThroughCalculation TFlag
	)	
	
	INSERT INTO @Temp
	(
		DocumentID,
		LinkClass,
		LinkDocumentID,
		State,
		ThroughCalculation
	)
	SELECT
		[@DocumentInCalculation].[DocumentID] AS [DocumentID], 
		@CalculationClass AS [LinkClass],
		[@DocumentInCalculation].[CalculationID] AS [LinkDocumentID],
		[@DocumentInCalculation].[CalculationState] AS [State],
		0 AS [ThroughCalculation]
	FROM
		@DocumentInCalculation
	UNION
	SELECT
		[@DocumentInStatement].[DocumentID],
		@StatementClass,
		[@DocumentInStatement].[StatementID],
		[@DocumentInStatement].[StatementState],
		0
	FROM
		@DocumentInStatement
	UNION
	SELECT
		[@DocumentInInvoice].[DocumentID],
		@InvoiceClass,
		[@DocumentInInvoice].[InvoiceID],
		[@DocumentInInvoice].[InvoiceState],
		0
	FROM
		@DocumentInInvoice
	UNION
	SELECT
		[@DocumentInCalculationThroughCalculation].[DocumentID],
		@CalculationClass,
		[@DocumentInCalculationThroughCalculation].[CalculationID],
		[@DocumentInCalculationThroughCalculation].[CalculationState],
		1
	FROM
		@DocumentInCalculationThroughCalculation
	UNION
	SELECT
		[@DocumentInStatementThroughCalculation].[DocumentID],
		@StatementClass,
		[@DocumentInStatementThroughCalculation].[StatementID],
		[@DocumentInStatementThroughCalculation].[StatementState],
		1
	FROM
		@DocumentInStatementThroughCalculation
	UNION
	SELECT
		[@DocumentInInvoiceThroughCalculation].[DocumentID],
		@InvoiceClass,
		[@DocumentInInvoiceThroughCalculation].[InvoiceID],
		[@DocumentInInvoiceThroughCalculation].[InvoiceState],
		1
	FROM
		@DocumentInInvoiceThroughCalculation
	
	--  ,   
	INSERT INTO @Result
	(
		DocumentID,
		LinkClass,
		LinkDocumentID,
		State,
		ThroughCalculation
	)
	SELECT * FROM @Temp
	WHERE [LinkClass] = @CalculationClass OR
		([LinkClass] = @StatementClass AND [DocumentID] NOT IN (SELECT [DocumentID] FROM @Temp WHERE [LinkClass] = @CalculationClass)) OR
		([LinkClass] = @InvoiceClass AND [DocumentID] NOT IN 
		(SELECT [DocumentID] FROM @Temp WHERE [LinkClass] = @CalculationClass OR [LinkClass] = @StatementClass))

RETURN
END
GO