IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetPeriodName]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetPeriodName'
		DROP FUNCTION [dbo].[fnReportGetPeriodName]
	END

GO

PRINT 'Creating function fnReportGetPeriodName'
GO
/******************************************************************************
**		File: 
**		Name: fnReport7GetPeriodName
**		Desc:    	
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 18.04.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION fnReportGetPeriodName(@PeriodStart TDateTime, @PeriodEnd TDateTime, @LangCode TCode3, @Short bit, @WithYear bit, @PeriodType int)
RETURNS varchar(50)
AS
BEGIN
	DECLARE 
		@res varchar(50),		
		@StartPeriodName varchar(16),
		@StartPeriodNumber int,
		@StartYear varchar(16)
		
	IF(@LangCode IS NULL OR @LangCode NOT IN ('en', 'ru'))
		SET @LangCode = 'ru'	-- set to russian language as default
	
	SET @StartYear = DATENAME(year,@PeriodStart)
	IF(@PeriodType = 0)
	BEGIN
		SET @StartPeriodNumber = DATEPART(month,@PeriodStart)
		SET @StartPeriodName = [dbo].[fnReportGetMonthNameByNumber](@StartPeriodNumber,@LangCode,@Short)
	END
	ELSE IF(@PeriodType = 1)
	BEGIN
		SET @StartPeriodNumber = DATEPART(QUARTER,@PeriodStart)
		SET @StartPeriodName = [dbo].[fnReportGetQuarterNameByNumber](@StartPeriodNumber,@LangCode)
	END
	ELSE IF(@PeriodType = 2)
	BEGIN
		SET @StartPeriodNumber = DATEPART(YEAR,@PeriodStart)
		SET @StartPeriodName = ''
	END

	IF @PeriodEnd IS NULL
	BEGIN
		IF @WithYear = 1	
			SET @res = @StartPeriodName + ' '  + @StartYear
		ELSE
			SET @res = @StartPeriodName
	END
	ELSE
	BEGIN
		DECLARE
			@EndPeriodName varchar(16),
			@EndPeriodNumber int,
			@EndYear varchar(16)
		
		SET @EndYear = DATENAME(year,@PeriodEnd)
		IF(@PeriodType = 0)
		BEGIN
			SET @EndPeriodNumber = DATEPART(month,@PeriodEnd)
			SET @EndPeriodName = [dbo].[fnReportGetMonthNameByNumber](@EndPeriodNumber,@LangCode,@Short)
		END
		ELSE IF(@PeriodType = 1)
		BEGIN
			SET @EndPeriodNumber = DATEPART(QUARTER,@PeriodEnd)
			SET @EndPeriodName = [dbo].[fnReportGetQuarterNameByNumber](@EndPeriodNumber,@LangCode)
		END
		ELSE
		BEGIN
			SET @EndPeriodNumber = DATEPART(YEAR,@PeriodEnd)
			SET @EndPeriodName = ''
		END
		
		SET @res = @StartPeriodName + ' ' + @StartYear + ' - ' + @EndPeriodName + ' ' + @EndYear		
	END


	RETURN @res
END
GO

GRANT EXEC ON fnReportGetPeriodName TO PUBLIC
GO
 