﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnGetCalculationAdvanceDiscount]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnGetCalculationAdvanceDiscount'
		DROP FUNCTION [dbo].[fnGetCalculationAdvanceDiscount]
	END
GO

PRINT 'Creating function fnGetCalculationAdvanceDiscount'
GO

/******************************************************************************
**		File: fnGetCalculationAdvanceDiscount.sql
**		Name: fnGetCalculationAdvanceDiscount
**
**              
**		Return values:
**		Функция рассчитывает значение скидки/наценки по вложенным калькуляциям без НДС
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		
**		
**		Auth: Oleg Blokhin
**		Date: 29.07.15 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		
*******************************************************************************/
CREATE FUNCTION dbo.fnGetCalculationAdvanceDiscount
(
	@DiscountType INT, --Тип дисконта: 1 - скидка, 2 - наценка, 3 - лимит, 4 - фиксированная сумма
	@DiscountPC TAmount, -- скидка в валюте проекта
	@TotalWithoutDiscountPC TMoney -- сумма без применения дисконта в валюте проекта
)
RETURNS TMoney
AS
BEGIN
	DECLARE @AdvanceDiscountPC TMoney
	SET @AdvanceDiscountPC = SUM(
			(CASE 
				WHEN @DiscountType = 0
					THEN 0
				WHEN @DiscountType = 2 OR (@DiscountType = 4 AND @TotalWithoutDiscountPC < @DiscountPC)
					THEN 1
				ELSE -1
			END) * 
				CASE
					WHEN @DiscountType != 3 
						THEN CASE
							WHEN @DiscountType = 1 
								THEN CASE 
										WHEN @TotalWithoutDiscountPC > @DiscountPC
											THEN @DiscountPC
										ELSE 0
									END
							ELSE @DiscountPC END
					WHEN @DiscountType = 3 
						THEN CASE 
							WHEN @TotalWithoutDiscountPC > @DiscountPC
								THEN @TotalWithoutDiscountPC - @DiscountPC
							ELSE 0
						END	
					WHEN @DiscountType = 4
						THEN CASE 
							WHEN @TotalWithoutDiscountPC > @DiscountPC
								THEN @TotalWithoutDiscountPC - @DiscountPC
							WHEN @TotalWithoutDiscountPC < @DiscountPC
								THEN @DiscountPC - @TotalWithoutDiscountPC
							ELSE 0
						END
				END)
	RETURN  @AdvanceDiscountPC
END

GO