﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnGetCalculationLinesVATWithDiscount]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnGetCalculationLinesVATWithDiscount'
		DROP FUNCTION [dbo].[fnGetCalculationLinesVATWithDiscount]
	END
GO

PRINT 'Creating function fnGetCalculationLinesVATWithDiscount'
GO

/******************************************************************************
**		File: fnGetCalculationLinesVATWithDiscount.sql
**		Name: fnGetCalculationLinesVATWithDiscount
**
**              
**		Return values:
**		Функция рассчитывает значение НДС по линиям с учетом скидки
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		
**		
**		Auth: Oleg Blokhin
**		Date: 29.07.15 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		04.09.15	SAP			Исправлена точность аргумента @DiscountPercent
*******************************************************************************/
CREATE FUNCTION dbo.fnGetCalculationLinesVATWithDiscount
(
	@Discount DECIMAL (18,2), --Дисконт.
	@DiscountType INT, --Тип дисконта: 1 - скидка, 2 - наценка, 3 - лимит, 4 - фиксированная сумма
	@DiscountView INT, -- Вид дисконта: 0 - процентный, 1 - суммовой
	@TotalWithoutDiscount DECIMAL (18,2), --  сумма без применения дисконта
	@TotalLinesVATWithoutDiscount DECIMAL (18,2), --  сумма линий с НДС без применения дисконта 
	@VATIsIncluded BIT, -- включен ли НДС
	@VATRate DECIMAL (18,2), -- ставка НДС
	@DiscountPercent DECIMAL (18,4), -- процент дисконта
	@DiscountNotProjectCurrency TMoney -- неясно?! Какой-то дисконт.
)
RETURNS DECIMAL (18,2)
AS
BEGIN
	DECLARE @TotalLinesVAT DECIMAL (18,2)
	SET @TotalLinesVAT = CASE
			WHEN @DiscountType = 3 AND @TotalWithoutDiscount <= @Discount
				THEN @TotalLinesVATWithoutDiscount
			WHEN (@DiscountType = 3 AND @TotalWithoutDiscount > @Discount)  OR @DiscountType = 4
				THEN @Discount * @VATRate / (1 + @VATIsIncluded * @VATRate)
			WHEN @DiscountType = 0
				THEN @TotalLinesVATWithoutDiscount
			ELSE
				(@TotalWithoutDiscount + (CASE
					WHEN @DiscountType = 1 
						THEN -1
					ELSE 1 END) * CASE 
						WHEN @DiscountView = 0
							THEN ROUND(@TotalWithoutDiscount * @DiscountPercent, 2)
						ELSE @DiscountNotProjectCurrency END) 
				* @VATRate / (1 + @VATIsIncluded * @VATRate)
			END
	RETURN  @TotalLinesVAT
END

GO