IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnGetCalculationDiscountPercent]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnGetCalculationDiscountPercent'
		DROP FUNCTION [dbo].[fnGetCalculationDiscountPercent]
	END
GO

PRINT 'Creating function fnGetCalculationDiscountPercent'
GO

/******************************************************************************
**		File: fnGetCalculationDiscountPercent.sql
**		Name: fnGetCalculationDiscountPercent
**
**              
**		Return values:
**		       
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		
**		
**		Auth: Sergey Pelevin
**		Date: 26.06.15 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		
*******************************************************************************/
CREATE FUNCTION dbo.fnGetCalculationDiscountPercent
(
	@TotalWithoutDiscountAndAdvanced DECIMAL (18,2), --   
	@TotalWithVATWithoutDiscountAndAdvanced DECIMAL (18,2), --   
	@Discount DECIMAL (18,2), --.     (RatesWithVAT=1),    .      (RatesWithVAT=0),    .
	@RatesWithVAT BIT, --    . 1    , 0    
	@DiscountType INT -- : 1 - , 2 - , 3 - , 4 -  
)
RETURNS DECIMAL (18,10)
AS
BEGIN
	DECLARE
		@DiscountPercent DECIMAL (18,10),
		@TDA DECIMAL (18,2)

	SELECT
		@TDA = 
			CASE @RatesWithVAT
				WHEN 0 THEN @TotalWithoutDiscountAndAdvanced
               	WHEN 1 THEN @TotalWithVATWithoutDiscountAndAdvanced               	
			END

	IF (@TDA IS NULL OR @TDA = 0)
	BEGIN
		RETURN 0		
	END

	IF @DiscountType = 1
	BEGIN
		SET @DiscountPercent = 1 - ROUND(@Discount/@TDA,10)
	END
	ELSE IF @DiscountType = 2
	BEGIN
		SET @DiscountPercent = 1 + ROUND(@Discount/@TDA,10)
	END
	ELSE IF @DiscountType = 3
	BEGIN
		SELECT @DiscountPercent = 
			CASE 
            	WHEN @Discount >= @TDA THEN 1.0            	
            	ELSE 1 - ROUND((@TDA-@Discount)/@TDA,10)
            END
	END
	ELSE IF @DiscountType = 4
	BEGIN
		SET @DiscountPercent = 1 - ROUND((@TDA-@Discount)/@TDA,10)
	END
	ELSE
	BEGIN
		SET @DiscountPercent = 1.0 
	END



	RETURN @DiscountPercent
END

GO
