IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CompanyAccessibleBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5CompanyAccessibleBrowse'
		DROP  Procedure  pjm5CompanyAccessibleBrowse
	END

GO

PRINT 'Creating Procedure pjm5CompanyAccessibleBrowse'
GO
/******************************************************************************
**		File: 
**		Name: pjm5CompanyAccessibleBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5CompanyAccessibleBrowse
	@Own BIT = 0,
	@Type int = 0
AS
	SET NOCOUNT ON
	DECLARE 
		@date datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()	
	
	IF @Type = 0
	BEGIN
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			COALESCE([FileAs], [LegalName]) as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company]
		WHERE
			[Company].[State] = 1 AND 
			(@Own != 1 OR [Company].[Own] = 1) AND
			(
			EXISTS(
				SELECT * 
				FROM [Project]
				WHERE
					(
						[Project].[SupplierCompanyID] = [Company].[ID] OR
						[Project].[CustomerCompanyID] = [Company].[ID]
					)
				) AND
				(
					@ViewAllFinance = 1 OR
					EXISTS(
						SELECT * 
						FROM [Project]
						WHERE
							[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
							dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
						)
					)
			)
	END
	ELSE IF @Type = 1
	BEGIN
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			COALESCE([FileAs], [LegalName]) as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company]
		WHERE
			[Company].[State] = 1 AND 
			(@Own != 1 OR [Company].[Own] = 1) AND
			(
			EXISTS(
				SELECT * 
				FROM [Project]
				WHERE
					[Project].[SupplierCompanyID] = [Company].[ID]) AND
					(
						@ViewAllFinance = 1 OR
						EXISTS(
							SELECT * 
							FROM [Project]
							WHERE
								[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
								dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
							)
						)
			)
	END
	ELSE IF @Type = 2
	BEGIN
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			COALESCE([FileAs], [LegalName]) as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company]
		WHERE
			[Company].[State] = 1 AND
			(@Own != 1 OR [Company].[Own] = 1) AND
			(
			EXISTS(
				SELECT * 
				FROM [Project]
				WHERE
					[Project].[CustomerCompanyID] = [Company].[ID]
				) AND
				(
					@ViewAllFinance = 1 OR
					EXISTS(
						SELECT * 
						FROM [Project]
						WHERE
							[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
							dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
						)
					)
			)
	END
	RETURN 0
GO

GRANT EXEC ON pjm5CompanyAccessibleBrowse TO PUBLIC
GO
