﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCreateByTemplate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCreateByTemplate'
		DROP PROCEDURE [dbo].[pjm6BudgetCreateByTemplate]
	END
GO

PRINT 'Creating procedure pjm6BudgetCreateByTemplate'
GO

/******************************************************************************
**		File: pjm6BudgetCreateByTemplate.sql
**		Name: pjm6BudgetCreateByTemplate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 24/09/2010 14:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.07.13	SOV				Добавлена передача ассоциированных участников проекта в процедуру
**									копирования линий работ шаблона бюджета
**		05.07.13	SOV				Добавлена возможность перевода бюджета на исполнение
**		02.12.13	SAP				Реализовано создание напоминания при создании бюджета,
**									если известна дата следующего пересчета
**		23.07.15	SAP			Исправление и вынесение логики копирования категорий в процедуру pjm7CategoryCopyFromTemplate
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetCreateByTemplate]
	@ReceiveDocumentID		TIdentifier,
	@SourceBudgetID			TIdentifier,
	@CopyActualAsPlan		TBool,
	@ExecuteFromUser		TBool = 1,
	@StartDate				TDate		= NULL,
	@EndDate				TDate		= NULL,
	@RecurrenceType			TIdentifier = NULL,
	@Occurrences			TCount		= NULL,
	@Interval				TCount		= NULL,
	@CopyDataFromBudget		TBool		= 0,
	@Forced					TBool		= 1,
	@ParticipantsXML		XML			= NULL, -- Список ассоциированных участников проекта шаблона
	@ExecuteBudget			TBool		= 0		-- Перевод бюджета в состояние исполнения
AS
	SET NOCOUNT ON

	DECLARE 
		@State									TState,
		@Class									TClass,
		@BudgetTemplateClass                    TClass,
		@ReceiveDocumentClass					TClass,
		@ReceiveProjectState					TState,
		@ReceiveProjectTypeID					TIdentifier,
		@ReceiveProjectCurrencyCode				TCode3,
		@ReceiveProjectApplyVAT					TBool,
		@ReceiveProjectRatesWithVAT				TBool,
		@ReceiveProjectVATRate					TPercent,
		@ReceiveProjectStartDate				TDate,
		@ReceiveProjectEndDate					TDate,
		@ReceiveBudgetRecurrenceID				TIdentifier,
		@ReceiveProjectNumber					TName,

		
		@BudgetType								TIdentifier,
		@SourceBudgetCurrencyCode				TCode3,
		@SourceBudgetVATRate					TPercent,
		@SourceBudgetRatesWithVAT				TBool,
		@SourceBudgetPlanningActivityTypes		TBool,
		@SourceBudgetPlanningExpenseCodes		TBool,
		@SourceBudgetCalculateBudgetPatternID	TIdentifier,
		@SourceBudgetUseWorkPlanning			TBool,
		@SourceBudgetUseExpensePlanning			TBool,
		@ReceiveBudgetName						TName,
		@NextCalculationDate					TDate,
		@ReceiveBudgetID						TIdentifier,
		@value									TVariant,
		@Lang									TLanguage,
		@rv										int
	
	IF dbo.fnPjm6CanEditBudgetForProject(@ReceiveDocumentID) != 1 AND dbo.adfHasAccessRight(dbo.adfGetRightID('ManageBudgetTemplates')) != 1 
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		

	SET @Class = dbo.adfGetClassByName('Pjm6.Budget')
	SET @BudgetTemplateClass = dbo.adfGetClassByName('Pjm6.BudgetTemplate')
	SET @Lang = dbo.adfGetLanguage()

	SET @State = dbo.adfwfGetInitialState('8E95426E-83B7-4486-8EAD-0191CB63891A')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	IF EXISTS(SELECT *FROM [Task] WHERE ProjectID = @ReceiveDocumentID AND [SubprojectID] = NULL AND [State] = 2)
	BEGIN
		RAISERROR('#projecthastaskplanning', 18, -1)
		RETURN 1
	END

	SELECT
		@SourceBudgetCurrencyCode				= [Budget].[CurrencyCode],
		@SourceBudgetVATRate					= [Budget].[VATRate],
		@SourceBudgetRatesWithVAT				= [Budget].[VATIsIncluded],
		@SourceBudgetCalculateBudgetPatternID	= [Budget].[CalculateBudgetPatternID],
		@BudgetType								= [Budget].[BudgetTypeID],
		@SourceBudgetPlanningActivityTypes		= [Budget].[PlanningActivityForWork],
		@SourceBudgetPlanningExpenseCodes		= [Budget].[PlanningExpenseTypeForExpense],
		@SourceBudgetUseWorkPlanning			= [Budget].[UseWorkPlanning],
		@SourceBudgetUseExpensePlanning			= [Budget].[UseExpensePlanning]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @SourceBudgetID

	SELECT
		@ReceiveDocumentClass				= [Project].[Class],
		@ReceiveProjectState				= [Project].[State],
		@ReceiveProjectNumber				= [Project].[Number],
		@ReceiveProjectTypeID				= [Project].[ProjectTypeID],
		@ReceiveProjectCurrencyCode			= [Project].[CurrencyCode],
		@ReceiveProjectApplyVAT				= [Project].[ApplyVAT],
		@ReceiveProjectRatesWithVAT			= [Project].[RatesWithVAT],
		@ReceiveProjectStartDate			= CASE WHEN @BudgetType = 1 THEN [Project].[Date] ELSE @StartDate END,
		@ReceiveProjectEndDate				= CASE WHEN @BudgetType = 1 THEN [Project].[EndDate] ELSE @EndDate END
	FROM
		[Project]
	WHERE
		[Project].[ID] = @ReceiveDocumentID

	IF @ReceiveProjectApplyVAT = 1
	BEGIN
		EXEC adfParameterGet @Name='VATRate', @Group='CommonBusiness', @Value = @value OUTPUT
		SET @ReceiveProjectVATRate = CAST(@value as decimal(18,4))
	END

	IF @ReceiveProjectTypeID > 1
	BEGIN
		RAISERROR('#wrongprojecttype', 18, -1)
		RETURN 1
	END

	IF @ReceiveProjectState NOT IN (1, 2, 3 ,5, 6)
	BEGIN
		RAISERROR('#ProjectIsNotActive', 18, -1)
		RETURN 1
	END

	IF EXISTS(SELECT *FROM [Budget] 
		INNER JOIN [Document]
			ON [Document].[Class] = [Budget].[Class] AND [Document].[ID] = [Budget].[ID]
		INNER JOIN [RecurrencePattern]
			ON [Document].[RecurrencePatternID] = [RecurrencePattern].[ID] OR [Document].[RecurrencePatternID] IS NULL
		WHERE [DocumentClass] = @ReceiveDocumentClass AND [DocumentID] = @ReceiveDocumentID 
			AND (@BudgetType = 1 OR (@BudgetType > 1 AND [Budget].[State] IN (1, 2))))
	BEGIN
		RAISERROR('#budgetisalreadycreated', 18, -1)
		RETURN 1
	END
	
	IF (@BudgetType = 2 AND EXISTS(SELECT *FROM [Budget] WHERE [DocumentClass] = @ReceiveDocumentClass 
		AND [DocumentID] = @ReceiveDocumentID AND ((@StartDate Between [Budget].[StartDate] AND [Budget].[EndDate])
		OR (@EndDate Between [Budget].[StartDate] AND [Budget].[EndDate]))))
	BEGIN
		RAISERROR('#crossingbudgetperiod', 18, -1)
		RETURN 1
	END

	IF(@Forced = 0)
	BEGIN
	
		IF @SourceBudgetUseWorkPlanning = 1 AND @SourceBudgetPlanningActivityTypes = 1
			IF(EXISTS(SELECT [ActivityTypeID] FROM [BudgetLineWork] WHERE [BudgetID] = @SourceBudgetID AND [ActivityTypeID] NOT IN (SELECT [ActivityTypeID] FROM [ProjectActivityType] WHERE [ProjectID] = @ReceiveDocumentID)))
			BEGIN
				RAISERROR('?AddItemsFromBudget', 18, -1)
				RETURN -5
			END
		IF @SourceBudgetUseExpensePlanning = 1 AND @SourceBudgetPlanningExpenseCodes = 1
		
			IF(EXISTS(SELECT [ExpenseCodeID] FROM [BudgetLineExpense] WHERE [BudgetID] = @SourceBudgetID AND [ExpenseCodeID] NOT IN (SELECT [ExpenseCodeID] FROM [ProjectExpenseCode] WHERE [ProjectID] = @ReceiveDocumentID)))
			BEGIN
				RAISERROR('?AddItemsFromBudget', 18, -1)
				RETURN -5
			END
	END

	IF @Lang = 'ru'
		SET @ReceiveBudgetName = 'Бюджет по проекту ''' + @ReceiveProjectNumber + ''''
	ELSE IF @Lang = 'en'
		SET @ReceiveBudgetName = 'Budget for project ''' + @ReceiveProjectNumber + ''''

	BEGIN TRANSACTION

	IF @RecurrenceType IS NOT NULL AND @BudgetType >= 2
	BEGIN
		INSERT INTO [RecurrencePattern]
			([StartDate], [EndDate], [RecurrenceType], [Occurrences],
			[Interval], [DayOfWeekMask], [Instance], [MonthOfYear], [DayOfMonth])
		VALUES
			(@StartDate, NULL, @RecurrenceType, @Occurrences,
			@Interval, 0, NULL, NULL, NULL)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @ReceiveBudgetRecurrenceID = SCOPE_IDENTITY()
	END

	IF @ReceiveProjectState IN (5, 6)
		SET @State = 6

	INSERT INTO [Budget]
		([Flag],[State], [FileAs], [CurrencyCode], [DocumentClass], [DocumentID], [BudgetTypeID], [StartDate],
		[EndDate], [WorkBudgetBottom], [WorkBudgetHigh], [WorkBudgetBottomEqualsPlan], [WorkBudgetHighEqualsPlan],
		[ExpenseBudgetBottom], [ExpenseBudgetHigh], [ExpenseBudgetBottomEqualsPlan], [ExpenseBudgetHighEqualsPlan],
		[SupervisorEmployeeID], [VATRate], [VATIsIncluded],
		[DiscountViewWork], [DiscountPercentWork], [DiscountTotalWork], [DiscountViewExpense], [DiscountPercentExpense],
		[DiscountTotalExpense], [PlanningActivityForWork], [PlanningEmployeeForWork], [PlanningQualificationForWork],
		[PlanningRateForWork], [PlanningDateForWork], [PlanningExpenseTypeForExpense], [PlanningEmployeeForExpense], [PlanningPriceForExpense],
		[PlanningDateForExpense], [TimeEntryAccount], [TimeEntrySendingForApprovalAccount], [TimeEntryActualTotalsAccount], [PlanProfitability], [ExpenseAccount], 
		[ExpenseSendingForApprovalAccount], [PlanPurchases], [Comments],
		[UseWorkPlanning], [UseExpensePlanning])
	SELECT
		0,
		@State,
		@ReceiveBudgetName,
		[CurrencyCode],
		@ReceiveDocumentClass,
		@ReceiveDocumentID,
		[BudgetTypeID],
		@ReceiveProjectStartDate,
		@ReceiveProjectEndDate,
		[WorkBudgetBottom],
		[WorkBudgetHigh],
		[WorkBudgetBottomEqualsPlan],
		[WorkBudgetHighEqualsPlan],
		[ExpenseBudgetBottom],
		[ExpenseBudgetHigh],
		[ExpenseBudgetBottomEqualsPlan],
		[ExpenseBudgetHighEqualsPlan],
		[SupervisorEmployeeID],
		@ReceiveProjectVATRate,
		@ReceiveProjectRatesWithVAT,
		[DiscountViewWork],
		[DiscountPercentWork],
		[DiscountTotalWork],
		[DiscountViewExpense],
		[DiscountPercentExpense],
		[DiscountTotalExpense],
		[PlanningActivityForWork],
		[PlanningEmployeeForWork],
		[PlanningQualificationForWork],
		[PlanningRateForWork],
		[PlanningDateForWork],
		[PlanningExpenseTypeForExpense],
		[PlanningEmployeeForExpense],
		[PlanningPriceForExpense],
		[PlanningDateForExpense],
		[TimeEntryAccount],
		[TimeEntrySendingForApprovalAccount],
		[TimeEntryActualTotalsAccount],
		[PlanProfitability],
		[ExpenseAccount],
		[ExpenseSendingForApprovalAccount],
		[PlanPurchases],
		[Comments],
		[UseWorkPlanning],
		[UseExpensePlanning]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @SourceBudgetID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	SET @ReceiveBudgetID = SCOPE_IDENTITY()

	--Записать параметры переодичности бюджета
	IF @ReceiveBudgetRecurrenceID IS NOT NULL
	BEGIN
		UPDATE
			[Document]
		SET
			[RecurrencePatternID] = @ReceiveBudgetRecurrenceID
		WHERE
			[Class] = @Class AND [ID] = @ReceiveBudgetID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	--Копирование параметров пересчета бюджета
	IF @SourceBudgetCalculateBudgetPatternID IS NOT NULL
	BEGIN
		DECLARE
			@CRStartDate		TDate,
			@CREndDate			TDate,
			@CROccurrences		TCount,
			@CRRecurrenceType	TIdentifier,
			@CRInterval			TCount,
			@CRDayOfWeekMask	TIdentifier,
			@CRInstance			TIdentifier,
			@CRMonthOfYear		TCount,
			@CRDayOfMonth		TCount,
			@CRDayTransferRule	TCount
		
		SELECT
			@CRStartDate		= [StartDate],
			@CREndDate			= [EndDate],
			@CROccurrences		= [Occurrences],
			@CRRecurrenceType	= [RecurrenceType],
			@CRInterval			= [Interval],
			@CRDayOfWeekMask	= [DayOfWeekMask],
			@CRInstance			= [Instance],
			@CRMonthOfYear		= [MonthOfYear],
			@CRDayOfMonth		= [DayOfMonth],
			@CRDayTransferRule	= [DayTransferRule]
		FROM 
			[AssistantRecurrencePattern]
		WHERE
			[AssistantRecurrencePattern].[ID] = @SourceBudgetCalculateBudgetPatternID

		EXEC @rv = pjm6BudgetCalcRecurrenceInsert @ReceiveBudgetID, 
											@CRStartDate,		
											@CREndDate,		
											@CROccurrences,		
											@CRRecurrenceType,	
											@CRInterval,			
											@CRDayOfWeekMask,	
											@CRInstance,			
											@CRMonthOfYear,		
											@CRDayOfMonth,		
											@CRDayTransferRule,
											0
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	--Расчитать дату следующего пересчета
	DECLARE @CurrenctDate TDate

	SET @CurrenctDate = GETDATE()
	EXEC @rv = pjm6BudgetNextCalcDateGet @ReceiveBudgetID, @CurrenctDate, 0
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	--Создать напоминание. если стоит галка в настройках напоминаний для бюджетов
	DECLARE
		@ReminderSetting bit = 0,
		@ReminderInterval int,
		@CurrentUserID TIdentifier = [dbo].[adfGetCurrentUserID](),
		@NextCalcDate TDate

	SELECT
		@NextCalcDate = [NextCalculationDate]
	FROM
		[Budget]
	WHERE
		[ID] = @ReceiveBudgetID

	SELECT 
		@ReminderSetting = [ReminderSetting].[InitialState],
		@ReminderInterval = [ReminderSetting].[InitialInterval]
	FROM
		[ReminderSetting]		
	WHERE
		[UserID] = @CurrentUserID
		AND
		[ReminderSetting].[Subtype] = 'BC'

	IF @ReminderSetting IS NULL
	BEGIN
		SELECT 
			@ReminderSetting =  [DefaultState], 
			@ReminderInterval = [DefaultInterval]
		FROM 
			[ReminderType]
		WHERE 
			[Class] = dbo.adfGetClassByName('Pjm6.Budget') 
			AND 
			[Subtype] = 'BC'
	END

	IF @ReminderSetting = 1 AND @NextCalcDate IS NOT NULL
	BEGIN
		EXEC @rv = pjm7BudgetReminderCreate @ReceiveBudgetID,
			@NextCalcDate, @ReminderSetting, @ReminderInterval
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN @rv
		END	
	END



	--Вставка стандартных групп
	EXEC @rv = pjm6BudgetSystemGroupsInsert @ReceiveBudgetID
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	--Скопировать группы и линии бюджета
	EXEC @rv = pjm6BudgetLineAndGroupCopy @SourceBudgetID, @ReceiveBudgetID, @ReceiveDocumentID, @CopyActualAsPlan, @CopyDataFromBudget, @ParticipantsXML
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	;
	-- Добавление вложений из шаблона бюджета в бюджет
	WITH [TemplateAttachments](
		[ID],
		[AttachmentTypeID],
		[Name],
		[LinkDocumentClass],
		[LinkDocumentID])
	AS 
	(
		SELECT
			[ID],
			[AttachmentTypeID],
			[Name],
			[LinkDocumentClass],
			[LinkDocumentID]
		FROM
			[Attachment]
		WHERE
			[DocumentClass] = @BudgetTemplateClass
			AND
			[DocumentID] = @SourceBudgetID
    )
    INSERT INTO [Attachment] 
    (
		[DocumentClass],
		[DocumentID],
		[AttachmentTypeID],
		[Name],
		[LinkDocumentClass],
		[LinkDocumentID],
		[Value]
	)
    SELECT 
       	@Class,@ReceiveBudgetID,
		[TemplateAttachments].[AttachmentTypeID],
		[TemplateAttachments].[Name],
		[TemplateAttachments].[LinkDocumentClass],
		[TemplateAttachments].[LinkDocumentID],
		(SELECT [Value] FROM [Attachment] WHERE [ID] = [TemplateAttachments].[ID])
	FROM
		[TemplateAttachments]
	;
	-- Добавление контактов из шаблона проекта в проект
	WITH [TemplateContacts](
		[BusinessCardClass],
		[BusinessCardID])
	AS 
	(
		SELECT
			[BusinessCardClass],
			[BusinessCardID]
		FROM
			[DocumentContact]
		WHERE
			[DocumentClass] = @BudgetTemplateClass
			AND
			[DocumentID] = @SourceBudgetID
    )
    INSERT INTO [DocumentContact] 
    (
		[DocumentClass],
		[DocumentID],
		[BusinessCardClass],
		[BusinessCardID]
	)
    SELECT 
       	@Class,@ReceiveBudgetID,
		[BusinessCardClass],
		[BusinessCardID]
	FROM
		[TemplateContacts]
	;
	-- Добавление категорий из шаблона проекта в проект

	EXEC pjm7CategoryCopyFromTemplate @BudgetTemplateClass, @SourceBudgetID, @Class, @ReceiveBudgetID

	
	;
	-- Добавление полей пользователя из шаблона проекта в проект
	WITH [TemplateNoProjectProperty]
	AS
	(
		SELECT 
			[Name],[Type],[Format]
		FROM 
			[PropertyValue]
		INNER JOIN 
			[Property]
		ON 
			[PropertyValue].[PropertyId] = [Property].[ID]
		WHERE
			[PropertyValue].[DocumentClass] = @BudgetTemplateClass
		AND
			[PropertyValue].[DocumentID] = @SourceBudgetID		
		AND NOT ([Property].[Name] IN (
			SELECT
				[Name]
			FROM
				[Property]
			WHERE
				[Class] = @Class
				))
	)
	INSERT INTO 
		[Property] ([Class],[Name],[Type],[Format])
	SELECT 
		@Class,[Name],[Type],[Format]
	FROM 
		[TemplateNoProjectProperty]
	;
	WITH [TemplateNoProjectPropertyGlobal]
	AS (
		SELECT 
			[Property].[ID],
			[Property].[Name],
			[Property].[Format]
		FROM 
			[Property]
		LEFT OUTER JOIN
			[PropertyGlobal]
		ON 
			[Property].[ID] = [PropertyGlobal].[ID]
		WHERE
			[PropertyGlobal].[Name] IS NULL
	)
	INSERT INTO 
		[PropertyGlobal] ([ID],[Language],[Name],[Format])
	SELECT 
		[ID],
		'ru',
		[Name],
		[Format]
	FROM
		[TemplateNoProjectPropertyGlobal]
	;
	WITH [TemplateProperty]
	AS
	(
		SELECT 
			[ID],
			[Class],
			[Name],
			[Type],
			[Format],
			[Value]
		FROM 
			[PropertyValue]
		INNER JOIN
			[Property]
		ON
			[PropertyId] = [ID]
		WHERE
			[DocumentClass] = @BudgetTemplateClass
			AND
			[DocumentID] = @SourceBudgetID
			AND
			[Value] IS NOT NULL			
	)
	INSERT INTO [PropertyValue] ([DocumentClass],[DocumentID],[PropertyID],[Value])
	SELECT
		@Class,
		@ReceiveBudgetID,
		(SELECT	
			[ID]
		FROM
			[Property]
		WHERE
			[Class] = @Class
			AND
			[Property].[Name] = [TemplateProperty].[Name]
		),
		[TemplateProperty].[Value]
	FROM
		[TemplateProperty]
	;

	-- В случае невозможности перевод бюджета на исполнение сообщения выдаваться не будут, чтобы мастер мог завершить свою работу
	IF @ExecuteBudget = 1
	BEGIN
		BEGIN TRY
			EXEC pjm6BudgetChangeState @ReceiveBudgetID, 2
		END TRY
		BEGIN CATCH
		END CATCH
	END

	COMMIT TRANSACTION

	IF @ExecuteFromUser = 1
		SELECT @ReceiveBudgetID AS [ID]
	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCreateByTemplate TO PUBLIC
GO