﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetHistoryGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetHistoryGet'
		DROP PROCEDURE [dbo].[pjm6BudgetHistoryGet]
	END
GO

PRINT 'Creating procedure pjm6BudgetHistoryGet'
GO

/******************************************************************************
**		File: BudgetHistoryGet.sql
**		Name: pjm6BudgetHistoryGet
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 19/04/2011 13:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		30.09.14	SAP				Добавление возможности выбора бюджета за период
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetHistoryGet]
	@BudgetID		TIdentifier = NULL,
	@DocumentID		TIdentifier = NULL,
	@DateSelector	TIdentifier, --0 - Текущий год, 1 - Прошлый год, 2 - Все время, 3 - За период
	@PeriodStart	TDate,
	@PeriodEnd		TDate
AS
	DECLARE
		@StartDate				TDate,
		@BudgetDocumentID		TIdentifier,
		@Lang					TLanguage


	SELECT
		@PeriodStart = CAST(@PeriodStart as date),
		@PeriodEnd = CAST(@PeriodEnd as date) 
	
	SET @Lang = dbo.adfGetLanguage()

	IF @DocumentID IS NULL AND @BudgetID IS NULL
		RETURN 0

	IF @DocumentID IS NULL AND @BudgetID IS NOT NULL
	BEGIN
		SELECT
			@StartDate = [Budget].[StartDate],
			@BudgetDocumentID = [Budget].[DocumentID]
		FROM
			[Budget]
		WHERE
			[Budget].[ID] = @BudgetID
	END
	SELECT
		[Budget].[ID],
		ISNULL([StateGlobal].[Name], [State].[Name]) AS [State],
		[Budget].[State] AS [StateID],
		dbo.fnPjm6GetBudgetPeriodName([Budget].[StartDate], [Budget].[EndDate], [BudgetTypeID], @Lang, 1) AS [Period],
		[Budget].[PlannedManHour],
		[Budget].[ActualManHour],
		dbo.fnPjm6GetBudgetTotalWithDiscount([VATRate], [VATIsIncluded], [DiscountViewWork], [DiscountPercentWork], [DiscountTotalWork], [TotalPCPlannedManHour], [TotalWithVATPCPlannedManHour])
			AS [TotalWDPlannedManHour],
		dbo.fnPjm6GetBudgetTotalWithDiscount([VATRate], [VATIsIncluded], [DiscountViewWork], [DiscountPercentWork], [DiscountTotalWork], [TotalPCActualManHour], [TotalWithVATPCActualManHour])
			AS [TotalWDActualManHour],
		dbo.fnPjm6GetBudgetTotalWithVATWD([VATRate], [VATIsIncluded], [DiscountViewExpense], [DiscountPercentExpense], [DiscountTotalExpense], [TotalPCPlannedExpense], [TotalPCPlannedExpense] + dbo.fnPjm6GetVATForTotal([TotalPCPlannedExpense], [VATRate], 0, 1))
			AS [TotalWDPlannedExpense],
		dbo.fnPjm6GetBudgetTotalWithVATWD([VATRate], [VATIsIncluded], [DiscountViewExpense], [DiscountPercentExpense], [DiscountTotalExpense], [TotalPCActualExpense], [TotalPCActualExpense] + dbo.fnPjm6GetVATForTotal([TotalPCActualExpense], [VATRate], 0, 1))
			AS [TotalWDActualExpense]
	FROM
		[Budget]
		LEFT OUTER JOIN [State]
			ON [State].[State] = [Budget].[State] AND [State].[Class] = [Budget].[Class]
		LEFT OUTER JOIN [StateGlobal]
			ON [State].[State] = [StateGlobal].[State] AND [State].[Class] = [StateGlobal].[Class] AND
				[StateGlobal].[Language] = @Lang		
	WHERE
		(
			(
				@DocumentID IS NOT NULL 
				AND 
				[Budget].[DocumentID] = @DocumentID
			) 
			OR
			(
				@DocumentID IS NULL 
				AND
				[Budget].[StartDate] < @StartDate 
				AND
				[Budget].[DocumentID] = @BudgetDocumentID
			)
		) 
		AND
		(
			(
				@DateSelector = 0
				AND
				YEAR([Budget].[StartDate]) = YEAR(GETDATE())
			)
			OR
			(
				@DateSelector = 1
				AND
				YEAR([Budget].[StartDate]) = YEAR(DATEADD(year, -1, GETDATE()))
			)
			OR
			(
				@DateSelector = 2
			)
			OR
			(
				@DateSelector = 3
				AND
				[Budget].[StartDate] >= @PeriodStart
				AND
				[Budget].[StartDate] < DATEADD(DAY,1,@PeriodEnd)
			) 			
		)
	ORDER BY [Budget].[StartDate] DESC

	RETURN 0
GO

GRANT EXECUTE ON [pjm6BudgetHistoryGet] TO PUBLIC
GO