﻿IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm7CategoryCopyFromTemplate')
	BEGIN
		PRINT 'Dropping Procedure pjm7CategoryCopyFromTemplate'
		DROP  Procedure  pjm7CategoryCopyFromTemplate
	END

GO

PRINT 'Creating Procedure pjm7CategoryCopyFromTemplate'
GO
/******************************************************************************
**		File: 
**		Name: pjm7CategoryCopyFromTemplate
**		Desc: Процедура копирует категории из шаблона проекта/бюджета в создаваемый документ
**				Если категории нет, она будет создана, если есть - то будет связана с документом
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 23.07.15
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm7CategoryCopyFromTemplate
	@TemplateClass TClass,
	@TemplateID int,
	@DocumentClass TClass,
	@DocumentID int
AS
	SET NOCOUNT ON

	DECLARE @TemplateCategories TABLE
	(
		[CategoryFileAs] TName
	)
	DECLARE
		@TmpCategoryFileAs TName,
		@TmpNewCategoryID int
	;
	WITH [TemplateCategories](
		[CategoryFileAs])
	AS 
	(
		SELECT
			[Category].[FileAs] AS [CategoryFileAs]
		FROM
			[DocumentCategory]
			INNER JOIN [Category]
				ON [DocumentCategory].[DocumentClass] = [Category].[DocumentClass] 
					AND [DocumentCategory].[CategoryID] = [Category].[ID]
		WHERE
			[DocumentCategory].[DocumentClass] = @TemplateClass
			AND
			[DocumentCategory].[DocumentID] = @TemplateID
    )
	INSERT INTO @TemplateCategories
	SELECT
		[CategoryFileAs]
	FROM 
		[TemplateCategories]

	IF EXISTS(SELECT 1 FROM @TemplateCategories)
	BEGIN
		DECLARE categoriesCur CURSOR LOCAL FAST_FORWARD
		FOR (SELECT [CategoryFileAs] FROM @TemplateCategories)
	
		OPEN categoriesCur
		FETCH NEXT FROM categoriesCur INTO @TmpCategoryFileAs

		WHILE(@@FETCH_STATUS = 0)
		BEGIN
			SET @TmpNewCategoryID = -1

			--Ищем существующую категорию для класса документа с аналогичным именем
			SELECT
				@TmpNewCategoryID = ISNULL([ID],-1)
			FROM
				[Category]
			WHERE
				[DocumentClass] = @DocumentClass
				AND
				[FileAs] = @TmpCategoryFileAs

			--Если ее нет - создаем
			IF @TmpNewCategoryID = -1
			BEGIN
				INSERT INTO [Category] ([State],[Flag],[DocumentClass],[FileAs])
				VALUES(1,0,@DocumentClass,@TmpCategoryFileAs)

				SET @TmpNewCategoryID = SCOPE_IDENTITY()
			END
			
			-- Связываем документ с категорией
			INSERT INTO [DocumentCategory] ([DocumentClass],[DocumentID],[CategoryID])
			VALUES(@DocumentClass, @DocumentID, @TmpNewCategoryID)

			FETCH NEXT FROM categoriesCur INTO @TmpCategoryFileAs
		END
		CLOSE categoriesCur
		DEALLOCATE categoriesCur
	END	

RETURN 0
GO

GRANT EXEC ON pjm7CategoryCopyFromTemplate TO PUBLIC
GO
