IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trDocumentItemCreate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trDocumentItemCreate'
		DROP  Trigger pjm5trDocumentItemCreate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trDocumentItemCreate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trDocumentItemCreate'
GO
CREATE Trigger pjm5trDocumentItemCreate 
ON [DocumentItem] FOR INSERT
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
		
	DECLARE @UserID TIdentifier
	SET @UserID = dbo.adfGetCurrentUserID()
	IF EXISTS (SELECT * FROM [inserted] WHERE dbo.fnFolderHasRightAccess([inserted].[FolderID], @UserID, 'CreateItems') = 0)
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	IF EXISTS(SELECT * FROM [inserted] WHERE dbo.fnDocumentItemExtensionValidate([inserted].[FolderID], [inserted].[FileName]) = 0)
	BEGIN
		RAISERROR('#wrongfileextension', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trDocumentItemUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trDocumentItemUpdate'
		DROP  Trigger pjm5trDocumentItemUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trDocumentItemUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trDocumentItemUpdate'
GO
CREATE Trigger pjm5trDocumentItemUpdate 
ON [DocumentItem] FOR UPDATE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	IF UPDATE([Flag])
	BEGIN
		UPDATE
			[DocumentCard]
		SET
			[Flag] = [inserted].[Flag]
		FROM
			[DocumentCard]
			INNER JOIN [inserted]
				ON [inserted].[DocumentCardID] = [DocumentCard].[ID]
		WHERE			
			[DocumentCard].[Flag] != [inserted].[Flag]
	END
	
	DECLARE 
		@id TIdentifier, 
		@folderID TIdentifier, 
		@fileName TName,
		@rv int
		
	DECLARE updated_items CURSOR FAST_FORWARD FOR
		SELECT 
			[inserted].[ID], [inserted].[FolderID], [inserted].[FileName] 
		FROM 
			[inserted]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID]
		WHERE
			[inserted].[State] = [deleted].[State]
		
	OPEN updated_items
	FETCH NEXT FROM updated_items INTO @id, @folderID, @fileName
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC @rv = pjm5DocumentItemCheckEditAccess @id
		IF @@error != 0 OR @rv != 0 
		BEGIN
			CLOSE updated_items
			DEALLOCATE updated_items
			RAISERROR('#accessdenied', 18, -1)
			ROLLBACK TRANSACTION
			RETURN
		END
		IF dbo.fnDocumentItemExtensionValidate(@folderID, @fileName) = 0
		BEGIN
			CLOSE updated_items
			DEALLOCATE updated_items
			RAISERROR('#wrongfileextension', 18, -1)
			ROLLBACK TRANSACTION
			RETURN
		END
		FETCH NEXT FROM updated_items INTO @id, @folderID, @fileName
	END
	
	CLOSE updated_items
	DEALLOCATE updated_items
END

GO
 
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trDocumentItemDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trDocumentItemDelete'
		DROP  Trigger pjm5trDocumentItemDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trDocumentItemDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trDocumentItemDelete'
GO
CREATE Trigger pjm5trDocumentItemDelete 
ON [DocumentItem] FOR DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	
	/*DECLARE @UserID TIdentifier
	SET @UserID = dbo.adfGetCurrentUserID()
	IF EXISTS (
		SELECT * FROM [deleted] WHERE 
		[deleted].[FolderID] != -1 AND
		(
		dbo.fnFolderHasRightAccess([deleted].[FolderID], @UserID, 'DeleteAll') = 0 AND
		dbo.fnFolderHasRightAccess([deleted].[FolderID], @UserID, 'DeleteOwn') = 0
		) OR 
		(
		dbo.fnFolderHasRightAccess([deleted].[FolderID], @UserID, 'DeleteAll') = 0 AND
		[deleted].[CreatedBy] != @UserID
		)
	)
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END*/
END

GO
