﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7EmployeeNormGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7EmployeeNormGet'
		DROP PROCEDURE [dbo].[pjm7EmployeeNormGet]
	END
GO

PRINT 'Creating procedure pjm7EmployeeNormGet'
GO

/******************************************************************************
**		File: pjm7EmployeeNormGet.sql
**		Name: pjm7EmployeeNormGet
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 20.07.14
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		21.07.14	SAP			Переработка процедуры (из-за создания документа "Норматив сотрудника")
**		24.07.14	GNV			Изменение [NormFileAs] на [FileAs]
**		24.07.14	GNV			Добавление поля [BaseCurrency]
**		13.08.14	BAO			Нормативы с пустыми значениями должны попадать в выборку
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7EmployeeNormGet]
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	SELECT
		[ENE].[Class],
		[ENE].[ID],
		[ENE].[State],
		[ENE].[Flag],
		[ENE].[EmployeeID],
		[ENE].[StartDate],
		[ENE].[NormID],		
		[N].[FileAs] AS [FileAs],
		[ENE].[Created],
		[ENE].[CreatedBy],
		[ENE].[Modified],
		[ENE].[ModifiedBy],
		[ENE].[Timestamp],
		[dbo].[fnPjm5GetBaseCurrency]() as [BaseCurrency],
		[ENE].[Comments]
	FROM
		[EmployeeNormEntry] AS [ENE]
		INNER JOIN [Norm] AS [N]
			ON [N].[ID] = [ENE].[NormID]
		LEFT OUTER JOIN (
			SELECT 
				[NormID], MAX([YEAR]) AS [Year]
			FROM [NormValue]
			GROUP BY [NormID]
		) AS [NVY]
			ON [ENE].[NormID] = [NVY].[NormID]
		LEFT OUTER JOIN [NormValue] AS [NV]
			ON [NVY].[NormID] = [NV].[NormID]
			AND [NVY].[Year] = [NV].[Year]
	WHERE 
		[ENE].[ID] = @ID
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm7EmployeeNormGet] TO PUBLIC
GO
