IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ExpenseBrowseByEmployee]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ExpenseBrowseByEmployee'
		DROP PROCEDURE [dbo].[pjm5ExpenseBrowseByEmployee]
	END
GO

PRINT 'Creating procedure pjm5ExpenseBrowseByEmployee'
GO

/******************************************************************************
**		File: ExpenseBrowseByEmployee.sql
**		Name: pjm5ExpenseBrowseByEmployee
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5ExpenseBrowseByEmployee]
	@EmployeeID TIdentifier,
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier,
	@StateSelector INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime
AS
	SET NOCOUNT ON
	
	DECLARE 
		@date datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@RestrictedView TBool,
		@ExpenseSecretary TBool
		
	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')
	SET @RestrictedView = dbo.adfHasAccessRight(dbo.adfGetRightID('RestrictedView'))	
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
		
	SELECT 
			@date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)

	IF @DateSelector = 1 -- last seven days
		SELECT
			@PeriodEnd = DATEADD(day, 1, @date),
			@PeriodStart = DATEADD(day, -6, @date)

	IF @DateSelector = 2 -- current month
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @date, 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)

	IF @DateSelector = 3 -- last month
		SELECT
			@PeriodEnd = DATEADD(day, 1 - DATEPART(day, @date), @date),
			@PeriodStart = DATEADD(month, -1, @PeriodEnd)
			
	IF @DateSelector = 4 -- arbitrary period
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd)

	SELECT
		[Expense].[Class],
		[Expense].[ID],
		[Expense].[State],
		[Expense].[Flag],
		[Expense].[FileAs],
		[Expense].[ProjectID],
		[Expense].[TaskID],
		[Expense].[EmployeeID],
		[Expense].[ExpenseCodeID],
		[Expense].[Date],
		[Expense].[Amount],
		[Expense].[Billable],
		[Expense].[Price],
		[Expense].[FromCurrencyCode],
		[Expense].[ToCurrencyCode],
		[Expense].[CurrencyRate],
		[Expense].[VATRate],
		[Expense].[VAT],
		[Expense].[Comments],
		[Expense].[Created],
		[Expense].[CreatedBy],
		[Expense].[Modified],
		[Expense].[ModifiedBy],
		[Expense].[Timestamp],
		[Expense].[SumExpense],
		[Expense].[SumProjectCurrency],
		[Expense].[TotalSumExpense],
		[Expense].[TotalSumProjectCurrency]
	FROM
		[pjm5vwExpense] AS [Expense]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]	
	WHERE
		( 
			dbo.fnPjm5HasFinansDataAccess([Project].[ID], @CurrentEmployeeID, NULL, NULL) = 1 OR 
			dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], [Expense].[EmployeeID]) = 1 OR
			(dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1 AND @RestrictedView = 0) OR
			@ExpenseSecretary = 1
		) AND
		[Expense].[EmployeeID] = @EmployeeID AND 
		(
			(@ProjectSelector = 0) OR
			(
				@ProjectSelector = 1 AND 
				(
					(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
					(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
				)
			) OR
			(
				@ProjectSelector = 2 AND 
				(
					(@NotActiveProjectID IS NULL AND [Project].[State] != 2) OR
					(@NotActiveProjectID IS NOT NULL AND [Project].[ID] = @NotActiveProjectID)
				)
			)
		) AND
		(
			(@StateSelector = 0) OR										--  
			(@StateSelector = 1 AND [Expense].[State] IN (1, 5)) OR		-- / 
			(@StateSelector = 2 AND [Expense].[State] = 2) OR			-- .  
			(@StateSelector = 3 AND [Expense].[State] = 3) OR			-- 
			(@StateSelector = 4 AND [Expense].[State] = 6) OR			--   
			(@StateSelector = 5 AND [Expense].[State] = 4)				-- 
		) AND
		(
			@DateSelector = 0 OR
			[Expense].[Date] >= @PeriodStart AND 
			[Expense].[Date] < @PeriodEnd
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5ExpenseBrowseByEmployee] TO PUBLIC
GO
  