IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trFactureInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trFactureInsert'
		DROP  Trigger pjm5trFactureInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trFactureInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trFactureInsert'
GO
CREATE Trigger pjm5trFactureInsert 
ON [Facture] FOR INSERT
AS
BEGIN
	IF EXISTS(
		SELECT * 
		FROM 
			[inserted]
			INNER JOIN [Project]
				ON [Project].[ID] = [inserted].[ProjectID]
		WHERE 
			[Project].[CustomerCompanyID] IS NULL
	)
	BEGIN
		RAISERROR('#CustomerCannotBeNull', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trFactureUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trFactureUpdate'
		DROP  Trigger pjm5trFactureUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trInvoiceUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trFactureUpdate'
GO
CREATE Trigger pjm5trFactureUpdate 
ON [Facture] FOR UPDATE
AS
BEGIN
	IF EXISTS (SELECT * FROM [inserted] WHERE ([CurrencyRate] IS NULL OR [CurrencyRate] <= 0) AND [State] = 2)
	BEGIN
		RAISERROR('#CurrencyRateCannotBeNull', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	IF EXISTS (SELECT * FROM [inserted] WHERE ISNULL([inserted].[Number], '') = '' AND [inserted].[State] = 2)
	BEGIN
		RAISERROR('#InvalidDocumentNumber', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE
		@calculationClass TClass
	SET @calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] = 1 AND 
					inserted.[State] = 2
			INNER JOIN [FactureLine]
				ON inserted.[ID] = [FactureLine].[FactureID]
			INNER JOIN [Calculation]
				ON [FactureLine].[DocumentClass] = @calculationClass AND 
					[Calculation].[ID] = [FactureLine].[DocumentID] 		
		WHERE
			[Calculation].[State] NOT IN (2, 3)
		)
	BEGIN
		RAISERROR('#CannotApproveInvoiceNotApprovedCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE
		@serviceRequestClass TClass,
		@serviceAssignmentClass TClass
	SET @serviceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
	SET @serviceAssignmentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] = 1 AND 
					inserted.[State] = 2
			INNER JOIN [FactureLine]
				ON [FactureLine].[FactureID] = inserted.[ID]
			INNER JOIN [Document]
				ON [Document].[Class] = [FactureLine].[DocumentClass] AND 
					[Document].[ID] = [FactureLine].[DocumentID]
			WHERE
				[FactureLine].[DocumentClass] != @calculationClass AND
				(
				[FactureLine].[DocumentClass] = @serviceRequestClass AND [Document].[State] NOT IN (4, 5) OR
				[FactureLine].[DocumentClass] NOT IN (@serviceRequestClass, @serviceAssignmentClass) AND [Document].[State] NOT IN (3, 6)
				)
			)
	BEGIN
		RAISERROR('#CannotApproveInvoiceNotApprovedRecords', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] = 1 AND 
					inserted.[State] = 2
			INNER JOIN [FactureLine]
				ON [FactureLine].[FactureID] = inserted.[ID]
			LEFT OUTER JOIN [TimeEntry]
				ON [TimeEntry].[Class] = [FactureLine].[DocumentClass] AND 
					[TimeEntry].[ID] = [FactureLine].[DocumentID]
			LEFT OUTER JOIN [Expense]
				ON [Expense].[Class] = [FactureLine].[DocumentClass] AND 
					[Expense].[ID] = [FactureLine].[DocumentID]
			LEFT OUTER JOIN [ServiceRequest]
				ON [ServiceRequest].[Class] = [FactureLine].[DocumentClass] AND 
					[ServiceRequest].[ID] = [FactureLine].[DocumentID]
		WHERE
			(ISNULL([TimeEntry].[ID], 0) + 
				ISNULL([Expense].[ID], 0) +
				ISNULL([ServiceRequest].[ID], 0)) != 0
			AND		
			(ISNULL(CAST([TimeEntry].[Billable] AS int), 0) + 
				ISNULL(CAST([Expense].[Billable] AS int), 0) +
				ISNULL(CAST([ServiceRequest].[Billable] AS int), 0)) = 0
		)
	BEGIN
		RAISERROR('#CannotApproveNotBillableRecords', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	--- REJECT 
	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = 2,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [FactureLine]
			ON [Calculation].[Class] = [FactureLine].[DocumentClass] AND 
				[Calculation].[ID] = [FactureLine].[DocumentID]
		INNER JOIN inserted
			ON [FactureLine].[FactureID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 3 AND inserted.[State] = 3
	WHERE
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			)
		
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [FactureLine]
			ON [TimeEntry].[Class] = [FactureLine].[DocumentClass] AND 
				[TimeEntry].[ID] = [FactureLine].[DocumentID]
		INNER JOIN inserted
			ON [FactureLine].[FactureID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 3 AND inserted.[State] = 3
	WHERE
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [FactureLine]
			ON [Expense].[Class] = [FactureLine].[DocumentClass] AND 
				[Expense].[ID] = [FactureLine].[DocumentID]
		INNER JOIN inserted
			ON [FactureLine].[FactureID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 3 AND inserted.[State] = 3
	WHERE
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [FactureLine]
			ON [ServiceRequest].[Class] = [FactureLine].[DocumentClass] AND 
				[ServiceRequest].[ID] = [FactureLine].[DocumentID]
		INNER JOIN inserted
			ON [FactureLine].[FactureID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 3 AND inserted.[State] = 3
	WHERE
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	--- REJECT 
	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [inserted]
			ON ([inserted].[Class] = [Attachment].[LinkDocumentClass] AND 
				[inserted].[ID] = [Attachment].[LinkDocumentID])
		INNER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	WHERE
		[inserted].[State] = 3 AND
		[deleted].[State] != 3 AND
		[Attachment].[AttachmentTypeID] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRejectInvoice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trFactureDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm6trFactureDelete'
		DROP  Trigger pjm6trFactureDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trFactureDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: KOV
**		Date: 28.06.10
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trFactureDelete'
GO
CREATE Trigger pjm6trFactureDelete 
ON [Facture] FOR DELETE
AS
BEGIN
	IF EXISTS(SELECT * FROM [deleted] INNER JOIN [SuperTimer] 
				ON [SuperTimer].[DocumentClass] = [deleted].[Class] AND [SuperTimer].[DocumentID] = [deleted].[ID] AND 
				([SuperTimer].[State] in (1,2) OR ([SuperTimer].[State] = 3 AND [SuperTimer].[Persistent] = 1)))
	BEGIN
		RAISERROR('#CannotDeleteDocumentWithActiveTimer', 18, -1)
		ROLLBACK TRANSACTION
	END
END

GO