IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5FolderCopyTo]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5FolderCopyTo'
		DROP PROCEDURE [dbo].[pjm5FolderCopyTo]
	END
GO

PRINT 'Creating procedure pjm5FolderCopyTo'
GO

/******************************************************************************
**		File: pjm5FolderCopyTo.sql
**		Name: pjm5FolderCopyTo
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 06/13/2006 16:59:46
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5FolderCopyTo]
	@ID TIdentifier,
	@FolderID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE 
		@UserID TIdentifier,
		@NewFolderID TIdentifier,
		@CompanyID TIdentifier,
		@NewCompanyID TIdentifier
		
	IF @ID = @FolderID
	BEGIN
		RAISERROR('#foldercannotcopyormovetoitself', 18, -1)
		RETURN 1
	END

	IF dbo.fnFolderIsSubfolder(@FolderID, @ID) = 1
	BEGIN
		RAISERROR('#foldercannotcopyormovetoitself', 18, -1)
		RETURN 1
	END
	
	SELECT @CompanyID = [CompanyID] FROM [Folder] WHERE [ID] = @ID
	SELECT @NewCompanyID = [CompanyID] FROM [Folder] WHERE [ID] = @FolderID
	
	IF @CompanyID IS NOT NULL AND @CompanyID != @NewCompanyID
	BEGIN
		RAISERROR('#foldercannotcopyormovetoothercompany', 18, -1)
		RETURN 1
	END
	
	BEGIN TRANSACTION
	INSERT INTO [Folder] ([State], [Flag], [CompanyID], [FolderID], [FileAs], [VersionControl], [PublicationControl], [Parameters], [FileTemplate])
	SELECT
		[State], [Flag], @NewCompanyID, @FolderID, [FileAs], [VersionControl], [PublicationControl], [Parameters], [FileTemplate]
	FROM
		[Folder]
	WHERE
		[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @NewFolderID = SCOPE_IDENTITY()
	
	INSERT INTO [FolderAccessControl] ([FolderID], [TrusteeID], [AccessRights])
	SELECT @NewFolderID, [TrusteeID], [AccessRights] FROM [FolderAccessControl] WHERE [FolderID] = @FolderID
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	INSERT INTO [CaseOfFolder] ([FolderID], [CaseID], [Allowed], [MandatoryFields], [DefaultValues])
	SELECT
		@NewFolderID, 
		CASE [Case].[State] WHEN 1 THEN [CaseOfFolder].[CaseID] ELSE 0 END, 
		[CaseOfFolder].[Allowed], [CaseOfFolder].[MandatoryFields], [CaseOfFolder].[DefaultValues]
	FROM
		[CaseOfFolder]
		INNER JOIN [Case]
			ON [Case].[ID] = [CaseOfFolder].[CaseID]
	WHERE
		[CaseOfFolder].[FolderID] = @FolderID
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	INSERT INTO [FolderNotificationSettings]
		([FolderID], [TrusteeID], [FolderSettings], [CardSettings], [FileSettings])
	SELECT
		@NewFolderID, [TrusteeID], [FolderSettings], [CardSettings], [FileSettings]
	FROM
		[FolderNotificationSettings]
	WHERE
		[FolderNotificationSettings].[FolderID] = @FolderID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	EXEC pjm5FolderCreateSubfolderNotification @NewFolderID
	COMMIT TRANSACTION

	EXEC pjm5FolderGet @NewFolderID
	RETURN 0
GO

GRANT EXECUTE ON [pjm5FolderCopyTo] TO PUBLIC
GO

 