﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7MeetingRequestAutoSyncExchange]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7MeetingRequestAutoSyncExchange'
		DROP PROCEDURE [dbo].[pjm7MeetingRequestAutoSyncExchange]
	END
GO

PRINT 'Creating procedure pjm7MeetingRequestAutoSyncExchange'
GO

/******************************************************************************
**		File: pjm7MeetingRequestAutoSyncExchange.sql
**		Name: pjm7MeetingRequestAutoSyncExchange
**		Desc: Установка автоматической синхронизации встречь у пользователя
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAB
**		Date: 23.07.13
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		21.08.13	SAP				Исправлена некорректная работа процедуры, если
**									настройка SyncExchangeMeetingsInFuture равна NULL
*******************************************************************************/
CREATE PROCEDURE pjm7MeetingRequestAutoSyncExchange
	@ID			TIdentifier,
	@Class		TClass,
	@UserID		TIdentifier,
	@EmployeeID	TIdentifier
AS
	SET NOCOUNT ON

	DECLARE
		@value						TVariant,
		@value1						TVariant,
		@UserSyncMeetings			bit = 0,
		@UserSyncMeetingsInFuture	int = 0,
		@rv							INT
	
	--берем настройку синхронизации встречь пользователя
	SELECT 
		@value = [Value] 
	FROM 
		[UserParameter] 
	WHERE 
		[Name] = 'SyncExchangeMeetings' AND 
		[UserID] = @UserID

	SET @UserSyncMeetings = ISNULL(CAST(@value AS bit), 0)

	--Если у пользователся установлена сихронизация встречь
	IF @UserSyncMeetings = 1
	BEGIN
		--Берем пользовательскую настроку автоматичской установки синхронизации встречь
		SELECT 
			@value1 = [Value] 
		FROM 
			[UserParameter] 
		WHERE 
			[Name] = 'SyncExchangeMeetingsInFuture' AND 
			[UserID] = @UserID

		SET @UserSyncMeetingsInFuture = ISNULL(CAST(@value1 AS int), 0)

		--Устанавливаем автоматическую синхронизацию встречи
		IF @UserSyncMeetingsInFuture = 1
		BEGIN
			
			EXEC @rv = pjm7ExchangeSyncStateUpdate @ID, @Class, @UserSyncMeetingsInFuture, @EmployeeID
			IF @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 2
			END
		END
	END
	RETURN @UserSyncMeetingsInFuture
GO

GRANT EXECUTE ON pjm7MeetingRequestAutoSyncExchange TO PUBLIC
GO