﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ActiveReminderForDocumentGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ActiveReminderForDocumentGet'
		DROP PROCEDURE [dbo].[pjm7ActiveReminderForDocumentGet]
	END
GO

PRINT 'Creating procedure pjm7ActiveReminderForDocumentGet'
GO

/******************************************************************************
**		File: pjm7ActiveReminderForDocumentGet.sql
**		Name: pjm7ActiveReminderForDocumentGet
**		Desc: Процедура возвращает ближайшее напоминание по документу
**				для пользователя
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 15.05.2012 17:05:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**
*******************************************************************************/
CREATE PROCEDURE [pjm7ActiveReminderForDocumentGet]
@DocumentID		TIdentifier,
@DocumentClass	TClass,
@UserID			TIdentifier = NULL
AS
	SET NOCOUNT ON

	IF @UserID IS NULL
		SET @UserID = dbo.adfGetCurrentUserID()

	SELECT TOP 1
		[Reminder].[ID],
		[Reminder].[DocumentClass],
		[Reminder].[DocumentID],
		[UserReminder].[UserID],
		[Reminder].[EventTime],
		[UserReminder].[State],
		[UserReminder].[NextInterval],
		[UserReminder].[OriginalInterval],
		[Reminder].[Subtype],
		[ReminderType].[IsTimeFormat],
		[UserReminder].[Description]		
	FROM
		[Reminder]
		INNER JOIN [UserReminder]
			ON [UserReminder].[ReminderID] = [Reminder].[ID]
		INNER JOIN [ReminderType]
			ON [Reminder].[Subtype] = [ReminderType].[Subtype]
	WHERE
		[Reminder].[DocumentID] = @DocumentID
		AND
		[Reminder].[DocumentClass] = @DocumentClass
		AND
		[UserReminder].[UserID] = @UserID
		AND
		[UserReminder].[State] = 1
	ORDER BY
		DATEADD(minute, - [UserReminder].[OriginalInterval], [Reminder].[EventTime]) ASC,
		[Reminder].[Modified] ASC

	RETURN 0
GO

GRANT EXECUTE ON [pjm7ActiveReminderForDocumentGet] TO PUBLIC
GO
