﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ReminderForUserDismissFirstActive]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ReminderForUserDismissFirstActive'
		DROP PROCEDURE [dbo].[pjm7ReminderForUserDismissFirstActive]
	END
GO

PRINT 'Creating procedure pjm7ReminderForUserDismissFirstActive'
GO

/******************************************************************************
**		File: pjm7ReminderForUserDismissFirstActive.sql
**		Name: pjm7ReminderForUserDismissFirstActive
**		Desc: Процедура удаляет первое (по дате и времени) активное напоминание
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 06.08.2012 12:15:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm7ReminderForUserDismissFirstActive]
	@DocumentID		TIdentifier,
	@DocumentClass	TClass,
	@UserID			TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@ReminderID			TIdentifier,
		@ReminderSubtype	TCode2,
		@RemindersCount		int

	IF @UserID IS NULL
		SET @UserID = dbo.adfGetCurrentUserID()

	SELECT TOP 1
		@ReminderID = [Reminder].[ID],
		@ReminderSubtype = [Reminder].[Subtype]
	FROM
		[Reminder]
		INNER JOIN [UserReminder]
			ON [UserReminder].[ReminderID] = [Reminder].[ID]
	WHERE
		[Reminder].[DocumentID] = @DocumentID
		AND
		[Reminder].[DocumentClass] = @DocumentClass
		AND
		[UserReminder].[UserID] = @UserID
		AND
		[UserReminder].[State] = 1
	ORDER BY
		DATEADD(minute, - [UserReminder].[OriginalInterval], [Reminder].[EventTime]) ASC,
		[Reminder].[Modified] ASC
	
	--Общее кол-во напоминаний
	SELECT 
		@RemindersCount = COUNT([Reminder].[ID])		
	FROM
		[Reminder]
		INNER JOIN [UserReminder]
			ON [UserReminder].[ReminderID] = [Reminder].[ID]
	WHERE
		[Reminder].[DocumentID] = @DocumentID
		AND
		[Reminder].[DocumentClass] = @DocumentClass
		AND
		[UserReminder].[UserID] = @UserID
		AND
		[UserReminder].[State] = 1


	IF @ReminderID IS NOT NULL
		
		UPDATE [UserReminder]
		SET [State] = 0,
			[Modified] = GETDATE()
		WHERE
			[ReminderID] = @ReminderID AND [UserID] = @UserID
		IF @@ERROR != 0
			RETURN  1

		--IF (@ReminderSubtype != 'UR')
		--BEGIN
		--	UPDATE [UserReminder]
		--	SET [State] = 0
		--	WHERE
		--		[ReminderID] = @ReminderID AND [UserID] = @UserID
		--	IF @@ERROR != 0
		--		RETURN  1
		--END
		--ELSE
		--BEGIN
		--	DELETE FROM [Reminder]
		--	WHERE [ID] = @ReminderID
		--	IF @@ERROR != 0
		--		RETURN  1
		--END
	ELSE IF @RemindersCount = 0
	BEGIN
		RAISERROR('#ThereIsNoActiveReminders', 18, -1)
		RETURN 1
	END
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ReminderForUserDismissFirstActive] TO PUBLIC
GO 