IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5SubscriptionRuleUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5SubscriptionRuleUpdate'
		DROP PROCEDURE [dbo].[pjm5SubscriptionRuleUpdate]
	END
GO

PRINT 'Creating procedure pjm5SubscriptionRuleUpdate'
GO

/******************************************************************************
**		File: pjm5SubscriptionRuleUpdate.sql
**		Name: pjm5SubscriptionRuleUpdate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 20/12/2005 13:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		11.03.13	MAB				  OPENXML
*******************************************************************************/
CREATE PROCEDURE [pjm5SubscriptionRuleUpdate]
	@UserID TIdentifier,
	@Xml XML
AS
	SET NOCOUNT ON
	
	IF @UserID IS NULL
	BEGIN
		SET @UserID = dbo.adfGetCurrentUserID()
	END
	
	IF @UserID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE 
		@State				TState,
		@FileAs				TName,
		@XmlRuleID			int,
		@RuleID				TIdentifier
	
	BEGIN TRANSACTION
	
	DELETE FROM [SubscriptionRule] WHERE [UserID] = @UserID AND [ExternalInitiator] = 0
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DECLARE 
		@Subscription table
		(
			[SubscriptionRuleIndex] int, 
			[SubscriptionType] int
		)
	DECLARE
		@Document table
		(
			[SubscriptionRuleIndex] int, 
			[DocumentClass] int, 
			[DocumentID] int
		)
	DECLARE
		@NotificationWay table
		(
			[SubscriptionRuleIndex] int, 
			[NotificationWayID] int
		)

	INSERT INTO @Subscription([SubscriptionRuleIndex], [SubscriptionType])
	SELECT
		DENSE_RANK() OVER(ORDER BY SubscriptionRule_Node),
		Subscription_Node.value('@Type','int')
	FROM
		@Xml.nodes('pjm5SubscriptionRuleUpdate/SubscriptionRule') AS SubscriptionRule(SubscriptionRule_Node)
		CROSS APPLY SubscriptionRule.SubscriptionRule_Node.nodes('./Subscription') AS Subscription(Subscription_Node)

	INSERT INTO @Document([SubscriptionRuleIndex], [DocumentClass], [DocumentID])
	SELECT
		DENSE_RANK() OVER(ORDER BY SubscriptionRule_Node),
		Document_Node.value('@Class','smallint'),
		Document_Node.value('@ID','int')
	FROM
		@Xml.nodes('pjm5SubscriptionRuleUpdate/SubscriptionRule') AS SubscriptionRule(SubscriptionRule_Node)
		OUTER APPLY SubscriptionRule.SubscriptionRule_Node.nodes('./Document') AS Document(Document_Node)

	INSERT INTO @NotificationWay([SubscriptionRuleIndex], [NotificationWayID])
	SELECT
		DENSE_RANK() OVER(ORDER BY SubscriptionRule_Node),
		NotificationWay_Node.value('@ID','int')
	FROM
		@Xml.nodes('pjm5SubscriptionRuleUpdate/SubscriptionRule') AS SubscriptionRule(SubscriptionRule_Node)
		CROSS APPLY SubscriptionRule.SubscriptionRule_Node.nodes('./NotificationWay') AS NotificationWay(NotificationWay_Node)

	DECLARE rules CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
	SELECT
		T.c.value('@State','int'),
		T.c.value('@Name','nvarchar(512)'),
		DENSE_RANK() OVER(ORDER BY T.c)
	FROM
		@Xml.nodes('pjm5SubscriptionRuleUpdate/SubscriptionRule') AS T(c)
	WHERE
		T.c IS NOT NULL

	OPEN rules

	FETCH NEXT FROM rules INTO @State, @FileAs, @XmlRuleID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		INSERT INTO [SubscriptionRule] ([State], [FileAs], [UserID], [Created], [Modified])	
			VALUES (@State, @FileAs, @UserID, GETDATE(), GETDATE())
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @RuleID = SCOPE_IDENTITY()
		
		INSERT INTO [Subscription] ([SubscriptionTypeID], [SubscriptionRuleID])
		SELECT
			[Subscription].[SubscriptionType],
			@RuleID
		FROM
			@Subscription AS [Subscription]	
		WHERE 
			[Subscription].[SubscriptionRuleIndex] = @XmlRuleID

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		INSERT INTO [DocumentSubscriptionRule] ([DocumentClass], [DocumentID], [SubscriptionRuleID])
		SELECT
			[Document].[DocumentClass],
			[Document].[DocumentID],
			@RuleID
		FROM
			@Document AS [Document]
		WHERE 
			[Document].[DocumentClass] IS NOT NULL AND 
			[Document].[DocumentID] IS NOT NULL AND
			[Document].[SubscriptionRuleIndex] = @XmlRuleID

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		INSERT INTO [SubscriptionRuleNotificationWay] ([NotificationWayID], [SubscriptionRecurrencePatternID], [SubscriptionRuleID])
		SELECT
			[NotificationWay].[NotificationWayID],
			NULL,
			@RuleID
		FROM
			@NotificationWay AS [NotificationWay]
		WHERE
			[NotificationWay].[SubscriptionRuleIndex] = @XmlRuleID

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		FETCH NEXT FROM rules INTO @State, @FileAs, @XmlRuleID
	END

	CLOSE rules
	DEALLOCATE rules

	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm5SubscriptionRuleUpdate] TO PUBLIC
GO
  