IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfPaymentBrowseByCompany]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfPaymentBrowseByCompany'
		DROP PROCEDURE [dbo].[adfPaymentBrowseByCompany]
	END
GO

PRINT 'Creating procedure adfPaymentBrowseByCompany'
GO

/******************************************************************************
**		File: PaymentBrowseByCompany.sql
**		Name: adfPaymentBrowseByCompany
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/21/2005 17:11:09
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      20.10.10    BVY             Added data for the column Total without VAT 
**									of grid in the SELECT area
**		09.08.11	SYV				
*******************************************************************************/
CREATE PROCEDURE [adfPaymentBrowseByCompany]
	@StateSelector INT,
	@DateSelector INT,
	@PeriodStart datetime,
	@PeriodEnd datetime,
	@CompanyID INT
AS
	SET NOCOUNT ON
	DECLARE
		@BaseCurrencyCode TCode3,
		@value TVariant,
		@Date TDate,
		@ViewAllFinance TBool
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))

	IF @ViewAllFinance = 1
	BEGIN
		EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
		SET @BaseCurrencyCode = CAST(@value as varchar(3))
	
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	
		IF @DateSelector = 1 -- last 7 days
			SELECT
				@PeriodStart = DATEADD(day, -7, @Date),
				@PeriodEnd = @Date

		IF @DateSelector = 2 -- this month
			SELECT
				@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))
	
		IF @DateSelector = 3 -- last month
			SELECT
				@PeriodStart = DATEADD(month, -1, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))

		IF @DateSelector = 4 -- 3 month
			SELECT
				@PeriodStart = DATEADD(month, -2, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
			
		IF @DateSelector = 5 -- arbitrary period
			SELECT
				@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
				@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
				@PeriodEnd = DATEADD(day, 1, @PeriodEnd),
				@PeriodEnd = DATEADD(millisecond, -5, @PeriodEnd)
			
		SET NOCOUNT ON
		SELECT
			[Payment].[Class],
			[Payment].[ID],
			[Payment].[State],
			[Payment].[Flag],
			[Payment].[FileAs],
			[Payment].[Date],
			[Payment].[Number],
			[Payment].[PaymentTypeID],
			[Payment].[CurrencyCode],
			[Payment].[PayeeCompanyID],
			[Payment].[PayeeBankAccountID],
			[Payment].[PayerCompanyID],
			[Company].[ManagerEmployeeID] AS [ManagerEmployeeID],
			[Payment].[Value],
			[Payment].[VAT],
			[Payment].[TotalWithVATBC] AS [BaseTotal],
			@BaseCurrencyCode AS [BaseCurrencyCode],
			[Payment].[Comments],
			[Payment].[Created],
			[Payment].[CreatedBy],
			[Payment].[Modified],
			[Payment].[ModifiedBy],
			[Payment].[Timestamp],
			[Payment].[Value]-[Payment].[VAT] AS [TotalBC],
			([Payment].[Value] - ISNULL((SELECT SUM([PaymentValue]) FROM [PaymentDetail] WHERE [PaymentID] = [Payment].[ID]), 0)) AS [TotalNotAssigned]
		FROM
			[Payment]
			LEFT OUTER JOIN [Company]
				ON [Company].[ID] = [Payment].[PayerCompanyID]
		WHERE
			--@ViewAllFinance = 1 AND
			([Payment].[PayerCompanyID] = @CompanyID OR [Payment].[PayeeCompanyID] = @CompanyID) AND 
			(
				(@StateSelector = 0) OR 
				(@StateSelector = 5 AND [Payment].[State] != 4) OR
				(@StateSelector != 0 AND [Payment].[State] = @StateSelector)
			) AND
			((@DateSelector = 0) OR ([Payment].[Date] BETWEEN @PeriodStart AND @PeriodEnd))
	END

	RETURN 0
GO

GRANT EXECUTE ON [adfPaymentBrowseByCompany] TO PUBLIC
GO
  