IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trPaymentUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trPaymentUpdate'
		DROP  Trigger pjm5trPaymentUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trPaymentUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trPaymentUpdate'
GO
CREATE Trigger pjm5trPaymentUpdate 
ON [Payment] FOR INSERT, UPDATE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	
    IF EXISTS (
		SELECT *
		FROM [inserted]
		WHERE 
			[inserted].[Value] < [inserted].[VAT]
	)
	BEGIN
		RAISERROR('#wrongvatvalue', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT * 
		FROM
			[inserted]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID]
		WHERE
			[deleted].[State] = 2 AND
			[inserted].[State] = 3 AND
			[inserted].[BaseCurrencyRate] IS NULL 
	)
	BEGIN
		RAISERROR('#BaseCurrencyRateCannotBeNull', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT * 
		FROM
			[inserted]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID]
		WHERE
			[deleted].[State] = 1 AND
			[inserted].[State] = 2 AND
			[inserted].[BaseCurrencyRate] IS NULL 
	)
	BEGIN
		RAISERROR('#BaseCurrencyRateCannotBeNull', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE
		@value TVariant,
		@NationalCurrency varchar(8)
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(8))
	
	UPDATE
		[Payment]
	SET
		[TotalBC] = ROUND(CASE 
						WHEN [inserted].[CurrencyCode] = @NationalCurrency AND [inserted].[BaseCurrencyRate] !=0
							THEN (ISNULL([inserted].[Value], 0) - ISNULL([inserted].[VAT], 0)) / [inserted].[BaseCurrencyRate]
						ELSE (ISNULL([inserted].[Value], 0) - ISNULL([inserted].[VAT], 0)) * [inserted].[BaseCurrencyRate]
					END, 2),
		[TotalWithVATBC]= ROUND(CASE 
						WHEN [inserted].[CurrencyCode] = @NationalCurrency AND [inserted].[BaseCurrencyRate] !=0
							THEN ISNULL([inserted].[Value], 0) / [inserted].[BaseCurrencyRate]
						ELSE ISNULL([inserted].[Value], 0) * [inserted].[BaseCurrencyRate]
					END, 2)
	FROM
		[inserted]
		INNER JOIN [Payment]
			ON 	[Payment].[ID] = [inserted].[ID]
		LEFT OUTER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	WHERE
		[inserted].[State] = ISNULL([deleted].[State], [inserted].[State])
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trPaymentReject')
	BEGIN
		PRINT 'Dropping Trigger pjm5trPaymentReject'
		DROP  Trigger pjm5trPaymentReject
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trPaymentReject
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trPaymentReject'
GO
CREATE Trigger pjm5trPaymentReject 
ON [Payment] FOR UPDATE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	
	DELETE 
		[PaymentDetail]
	FROM
		[PaymentDetail]
		INNER JOIN [inserted]
			ON [inserted].[ID] = [PaymentDetail].[PaymentID]
		INNER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	WHERE
		[inserted].[State] = 4 AND [deleted].[State] != 4
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trPaymentDetailModified')
	BEGIN
		PRINT 'Dropping Trigger pjm6trPaymentDetailModified'
		DROP  Trigger pjm6trPaymentDetailModified
	END
GO


/******************************************************************************
**		File: 
**		Name: pjm6trPaymentDetailModified
**		Desc: trigger for automatical changing state of invoices 
**		within modifying
**
**		This template can be customized:
**              
**
**		Auth: pavel.svintsov
**		Date: 15.04.2010
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------	--------			---------------------------------------
**		16.04.10	SPV					first version
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trPaymentDetailModified'
GO
CREATE Trigger pjm6trPaymentDetailModified
ON [PaymentDetail] FOR UPDATE, DELETE, INSERT
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	
	DECLARE
		@ID TIdentifier,
		@State TState,
		@Dif TMoney
	
	DECLARE @ModifiedInvoices TABLE
	(
		[ID] TIdentifier,
		[State] TState,
		[Dif] TMoney
	)
	
	INSERT INTO @ModifiedInvoices
	SELECT
		[Invoice].[ID],
		[Invoice].[State],
		[Invoice].[TotalWithVAT] - 
		(
			SELECT SUM([PaymentValue]) FROM [PaymentDetail]
			WHERE [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		)
	FROM
		[inserted]
		INNER JOIN [Invoice]
			ON [inserted].[InvoiceID] = [Invoice].[ID]
	WHERE
		[inserted].[InvoiceID] NOT IN
			(SELECT [ID] FROM @ModifiedInvoices)
	UNION
	SELECT
		[Invoice].[ID],
		[Invoice].[State],
		[Invoice].[TotalWithVAT] - 
		ISNULL((
			SELECT SUM([PaymentValue]) FROM [PaymentDetail]
			WHERE [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		), 0) as [Dif]
	FROM
		[deleted]
		INNER JOIN [Invoice]
			ON [deleted].[InvoiceID] = [Invoice].[ID]
	WHERE
		[deleted].[InvoiceID] NOT IN
			(SELECT [ID] FROM @ModifiedInvoices)
		
	DECLARE invoices CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
	SELECT
		[ID],
		[State],
		[Dif]
	FROM
		@ModifiedInvoices
		
	OPEN invoices
	
	FETCH NEXT FROM invoices
	INTO @ID, @State, @Dif
	
	WHILE @@FETCH_STATUS = 0
	BEGIN
		
		IF @State = 2 AND @Dif <= 0
			exec pjm5InvoiceChangeState @ID, 5, 1
			
		IF @State = 5 AND @Dif > 0
			exec pjm5InvoiceChangeState @ID, 2, 1
		
		FETCH NEXT FROM invoices
		INTO @ID, @State, @Dif
		
	END
	
	CLOSE invoices
	DEALLOCATE invoices
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trPaymentDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm6trPaymentDelete'
		DROP  Trigger pjm6trPaymentDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trPaymentDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: KOV
**		Date: 28.06.10
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trPaymentDelete'
GO
CREATE Trigger pjm6trPaymentDelete 
ON [Payment] FOR DELETE
AS
BEGIN
	IF EXISTS(SELECT * FROM [deleted] INNER JOIN [SuperTimer] 
				ON [SuperTimer].[DocumentClass] = [deleted].[Class] AND [SuperTimer].[DocumentID] = [deleted].[ID] AND 
				([SuperTimer].[State] in (1,2) OR ([SuperTimer].[State] = 3 AND [SuperTimer].[Persistent] = 1)))
	BEGIN
		RAISERROR('#CannotDeleteDocumentWithActiveTimer', 18, -1)
		ROLLBACK TRANSACTION
	END
END

GO