IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ProjectBalanceGet')
	BEGIN
		PRINT 'Dropping Procedure pjm5ProjectBalanceGet'
		DROP  Procedure  pjm5ProjectBalanceGet
	END

GO

PRINT 'Creating Procedure pjm5ProjectBalanceGet'
GO
/******************************************************************************
**		File: 
**		Name: pjm5ProjectBalanceGet
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5ProjectBalanceGet
	@CompanyID TIdentifier,
	@ProjectID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE @ID TIdentifier
	SET @ID = ISNULL(@ProjectID, @CompanyID)
	
	DECLARE @Date TDateTime
	SET @Date = GETDATE()

	DECLARE 
		@NationalCurrency TCode3,
		@value TVariant
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(3))
	
	DECLARE
		@BadDebtInvoices TMoney,
		@BadDebtPayments TMoney
		
	DECLARE @balance TABLE (
		[ID] int,
		[d30] money,
		[d60] money,
		[d90] money,
		[Over90] money,
		[Total] money,
		[AverageDaysToPay] int,
		[AverageDaysToPayYTD] int,
		[SalesMTD] money,
		[SalesYTD] money,
		[SalesLY] money,
		[PaymentMTD] money,
		[PaymentYTD] money,
		[PaymentLY] money,
		[LifetimeSales] money,
		[LifetimeStatements] money,
		[BadDebt] money
		)

	DECLARE @invoice TABLE (
		[ID] int,
		[DimensionID] int,
		[State] int,
		[Date] datetime,
		[DueDate] datetime,
		[CurrencyRate] money,
		[Total] money,
		[PaymentDate] datetime null,
		[Payment] money
		)
	IF @ProjectID IS NOT NULL
	BEGIN
		INSERT INTO @balance ([ID],
			[d30], [d60], [d90], [Over90], [Total],
			[AverageDaysToPay], [AverageDaysToPayYTD],
			[SalesMTD], [SalesYTD], [SalesLY],
			[PaymentMTD], [PaymentYTD], [PaymentLY],
			[LifetimeSales], [LifetimeStatements], [BadDebt])
		SELECT [ID],0,0,0,0,[InitialBalance],0,0,0,0,0,0,0,0,0,0,0 FROM [Project] WHERE [ID] = @ID
		
		INSERT INTO @invoice ([ID], [DimensionID], [State], [Date], [DueDate], [CurrencyRate], [Total], [PaymentDate], [Payment])
		SELECT
			[Invoice].[ID],
			[Invoice].[ProjectID],
			[Invoice].[State],
			[Invoice].[Date],
			[Invoice].[DueDate],
			[Invoice].[CurrencyRate],
			ISNULL([Invoice].[TotalWithVATPC], 0) - 
				ISNULL((SELECT 
					SUM(i.[TotalWithVATPC]) 
				FROM [AdvanceInvoice] INNER JOIN [Invoice] i
					ON i.[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
				WHERE
					[AdvanceInvoice].[InvoiceID] = [Invoice].[ID])
				, 0),
			MAX([Payment].[Date]),
			ISNULL(SUM([PaymentDetail].[Value]), 0)
		FROM
			[Invoice]
			LEFT OUTER JOIN [PaymentDetail]
				ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
			LEFT OUTER JOIN [Payment]
				ON [PaymentDetail].[PaymentID] = [Payment].[ID]
		WHERE
			[Invoice].[ProjectID] = @ID AND
			[Invoice].[State] IN (2, 5, 7)
		GROUP BY
			[Invoice].[ID],
			[Invoice].[ProjectID],
			[Invoice].[State],
			[Invoice].[Date],
			[Invoice].[DueDate],
			[Invoice].[TotalWithVATPC],
			[Invoice].[CurrencyRate]
			
		UPDATE
			@balance
		SET
			[LifetimeStatements] = ISNULL((
				SELECT SUM([Statement].[TotalWithVATPC])
				FROM [Statement]
				WHERE
					[Statement].[ProjectID] = [balance].[ID] AND
					[Statement].[State] IN (2, 3)
				), 0),
			[Total] = [Total] + ISNULL((
				SELECT SUM([CreditMemo].[TotalWithVATPC])
				FROM [CreditMemo]
				WHERE
					[CreditMemo].[ProjectID] = [balance].[ID] AND
					[CreditMemo].[State] = 2
				), 0)
		FROM
			@balance AS [balance]
		
		UPDATE
			@balance
		SET
			[PaymentMTD] = ISNULL(-[creditmemo].[PaymentMTD], 0),
			[PaymentYTD] = ISNULL(-[creditmemo].[PaymentYTD], 0),
			[PaymentLY] = ISNULL(-[creditmemo].[PaymentLY], 0)
		FROM
			@balance AS [balance]
			INNER JOIN (
				SELECT
					[CreditMemo].[ProjectID],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date) AND MONTH([CreditMemo].[Date]) = MONTH(@Date)
							THEN [CreditMemo].[TotalWithVATPC]
							ELSE 0.0
						END) AS [PaymentMTD],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date)
							THEN [CreditMemo].[TotalWithVATPC]
						ELSE 0.0
						END) AS [PaymentYTD],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date) - 1
							THEN [CreditMemo].[TotalWithVATPC]
						ELSE 0.0
						END) AS [PaymentLY]
				FROM
					[CreditMemo]
				WHERE
					[CreditMemo].[ProjectID] = @ID AND
					[CreditMemo].[State] = 2			
				GROUP BY
					[CreditMemo].[ProjectID]
				) AS [creditmemo]
				ON [creditmemo].[ProjectID] = [balance].[ID]

		UPDATE
			@balance
		SET
			[PaymentMTD] = [balance].[PaymentMTD] + [payment].[PaymentMTD],
			[PaymentYTD] = [balance].[PaymentYTD] + [payment].[PaymentYTD],
			[PaymentLY] = [balance].[PaymentLY] + [payment].[PaymentLY]
		FROM
			@balance AS [balance]
			INNER JOIN (
				SELECT
					[invoice].[DimensionID],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date) AND MONTH([Payment].[Date]) = MONTH(@Date)
							THEN [PaymentDetail].[Value]
						ELSE 0.0
						END) AS [PaymentMTD],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date)
							THEN [PaymentDetail].[Value]
						ELSE 0.0
						END) AS [PaymentYTD],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date) - 1
							THEN [PaymentDetail].[Value]
						ELSE 0.0
						END) AS [PaymentLY]
				FROM
					[Payment]
					INNER JOIN [PaymentDetail]
						ON [PaymentDetail].[PaymentID] = [Payment].[ID]
					INNER JOIN @invoice AS [invoice]
						ON [PaymentDetail].[InvoiceID] = [invoice].[ID]
				WHERE
					[Payment].[State] IN (2,3)			
				GROUP BY
					[invoice].[DimensionID]
				) AS [payment]
				ON [payment].[DimensionID] = [balance].[ID]
				
		SET @BadDebtInvoices = (SELECT SUM([TotalWithVATPC])
								FROM [Invoice] WHERE [ProjectID] = @ID AND [Invoice].[State] = 7)
								
		SET @BadDebtPayments = (SELECT
							SUM([PaymentDetail].[Value])
						FROM
							[PaymentDetail]
							INNER JOIN [Invoice]
								ON [Invoice].[ID] = [PaymentDetail].[InvoiceID]
						WHERE
							[Invoice].[ProjectID] = @ID AND [Invoice].[State] = 7)
		
		
		
		
		
	END
	ELSE
	BEGIN
		INSERT INTO @balance ([ID],
			[d30], [d60], [d90], [Over90], [Total],
			[AverageDaysToPay], [AverageDaysToPayYTD],
			[SalesMTD], [SalesYTD], [SalesLY],
			[PaymentMTD], [PaymentYTD], [PaymentLY],
			[LifetimeSales], [LifetimeStatements])
		SELECT [CustomerCompanyID], 0,0,0,0,SUM([Project].[BaseInitialBalance]),0,0,0,0,0,0,0,0,0,0 
		FROM 
			[Project] 
		WHERE 
			[CustomerCompanyID] = @ID AND 
			[State] IN (2, 3, 4)
		GROUP BY 
			[CustomerCompanyID]

		INSERT INTO @invoice ([ID], [DimensionID], [State], [Date], [DueDate], [CurrencyRate], [Total], [PaymentDate], [Payment])
		SELECT
			[Invoice].[ID],
			[Project].[CustomerCompanyID],
			[Invoice].[State],
			[Invoice].[Date],
			[Invoice].[DueDate],
			[Invoice].[BaseCurrencyRate],
			ISNULL([Invoice].[TotalWithVATBC], 0) - 
				ISNULL((SELECT 
					SUM(i.[TotalWithVATBC]) 
				FROM [AdvanceInvoice] INNER JOIN [Invoice] i
					ON i.[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
				WHERE
					[AdvanceInvoice].[InvoiceID] = [Invoice].[ID])
				, 0),
			MAX([Payment].[Date]),
			ISNULL( SUM([PaymentDetail].[Value]) *
				CASE 
					WHEN [Project].[CurrencyCode] = @NationalCurrency
						THEN  1 / [Invoice].[BaseCurrencyRate]
					ELSE [Invoice].[BaseCurrencyRate]
				END
			, 0)
		FROM
			[Invoice]
			INNER JOIN [Project]
				ON [Project].[ID] = [Invoice].[ProjectID]
			LEFT OUTER JOIN [PaymentDetail]
				ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
			LEFT OUTER JOIN [Payment]
				ON [PaymentDetail].[PaymentID] = [Payment].[ID]
		WHERE
			[Project].[CustomerCompanyID] = @ID AND
			[Invoice].[State] IN (2, 5, 7)
		GROUP BY
			[Invoice].[ID],
			[Project].[CustomerCompanyID],
			[Project].[CurrencyCode],
			[Invoice].[State],
			[Invoice].[Date],
			[Invoice].[DueDate],
			[Invoice].[TotalWithVATBC],
			[Invoice].[BaseCurrencyRate]
		
		UPDATE
			@balance
		SET
			[LifetimeStatements] = ISNULL((
				SELECT SUM([Statement].[TotalWithVATBC])
				FROM 
					[Statement]
					INNER JOIN [Project]
						ON [Project].[ID] = [Statement].[ProjectID]
				WHERE
					[Project].[CustomerCompanyID] = [balance].[ID] AND
					[Statement].[State] IN (2, 3)
				), 0),
			[Total] = [Total] + ISNULL((
				SELECT SUM([CreditMemo].[TotalWithVATBC])
				FROM [CreditMemo]
				WHERE
					[CreditMemo].[PayerCompanyID] = @ID AND
					[CreditMemo].[State] = 2
				), 0)
		FROM
			@balance AS [balance]
		UPDATE
			@balance
		SET
			[PaymentMTD] = -[creditmemo].[PaymentMTD],
			[PaymentYTD] = -[creditmemo].[PaymentYTD],
			[PaymentLY] = -[creditmemo].[PaymentLY]
		FROM
			@balance AS [balance]
			INNER JOIN (
				SELECT
					[CreditMemo].[PayerCompanyID],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date) AND MONTH([CreditMemo].[Date]) = MONTH(@Date)
							THEN [CreditMemo].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentMTD],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date)
							THEN [CreditMemo].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentYTD],
					SUM(CASE 
						WHEN YEAR([CreditMemo].[Date]) = YEAR(@Date) - 1
							THEN [CreditMemo].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentLY]
				FROM
					[CreditMemo]
				WHERE
					[CreditMemo].[PayerCompanyID] = @ID AND
					[CreditMemo].[State] = 2			
				GROUP BY
					[CreditMemo].[PayerCompanyID]
				) AS [creditmemo]
				ON [creditmemo].[PayerCompanyID] = [balance].[ID]

		UPDATE
			@balance
		SET
			[PaymentMTD] = [balance].[PaymentMTD] + [payment].[PaymentMTD],
			[PaymentYTD] = [balance].[PaymentYTD] + [payment].[PaymentYTD],
			[PaymentLY] = [balance].[PaymentLY] + [payment].[PaymentLY]
		FROM
			@balance AS [balance]
			INNER JOIN (
				SELECT
					[b].[ID],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date) AND MONTH([Payment].[Date]) = MONTH(@Date)
							THEN [Payment].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentMTD],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date)
							THEN [Payment].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentYTD],
					SUM(CASE 
						WHEN YEAR([Payment].[Date]) = YEAR(@Date) - 1
							THEN [Payment].[TotalWithVATBC]
						ELSE 0.0
						END) AS [PaymentLY]
				FROM
					[Payment]
					INNER JOIN @balance AS [b]
						ON [Payment].[PayerCompanyID] = [b].[ID]
				WHERE
					[Payment].[State] IN (2,3)			
				GROUP BY
					[b].[ID]
				) AS [payment]
				ON [payment].[ID] = [balance].[ID]
				
		
			
		SET @BadDebtInvoices = (SELECT SUM([TotalWithVATBC])
								FROM [Invoice] WHERE [CustomerCompanyID] = @ID AND [Invoice].[State] = 7)
								
		SET @BadDebtPayments = (SELECT
							SUM([PaymentDetail].[Value] / [Payment].[BaseCurrencyRate])
						FROM
							[PaymentDetail]
							INNER JOIN [Invoice]
								ON [Invoice].[ID] = [PaymentDetail].[InvoiceID]
							INNER JOIN [Payment]
								ON [PaymentDetail].[PaymentID] = [Payment].[ID]
						WHERE
							[Invoice].[CustomerCompanyID] = @ID AND [Invoice].[State] = 7)
	END
		
	UPDATE
		@balance
	SET
		[d30] = [invoice].[d30],
		[d60] = [invoice].[d60],
		[d90] = [invoice].[d90],
		[Over90] = [invoice].[Over90],
		[Total] = [balance].[Total] + [invoice].[Total]
	FROM
		@balance AS [balance]
		INNER JOIN (
			SELECT
				[DimensionID],
				SUM(CASE 
					WHEN [DueDate] < @Date AND [DueDate] >= DATEADD(day, -30, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d30],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -30, @Date) AND [DueDate] >= DATEADD(day, -60, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d60],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -60, @Date) AND [DueDate] >= DATEADD(day, -90, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d90],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -90, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [Over90],
				SUM(ROUND([Total], 2) - ROUND([Payment], 2)) AS [Total]
			FROM
				@invoice
			WHERE
				[Total] > [Payment]
				AND
				[@invoice].[ID] NOT IN
				(
					SELECT
						[Invoice].[ID]
					FROM
						[Invoice]
					WHERE
						[Invoice].[State] = 7 AND 
						CASE
							WHEN @ProjectID IS NULL THEN
								[Invoice].[CustomerCompanyID]
							ELSE
								[Invoice].[ProjectID]
						END = @ID
				)
			GROUP BY
				[DimensionID]
			) AS [invoice]
			ON [invoice].[DimensionID] = [balance].[ID]

	UPDATE
		@balance
	SET
		[AverageDaysToPay] = ISNULL([invoice].[AverageDaysToPay], 0),
		[AverageDaysToPayYTD] = ISNULL([invoice].[AverageDaysToPayYTD], 0),
		[SalesMTD] = [invoice].[SalesMTD],
		[SalesYTD] = [invoice].[SalesYTD],
		[SalesLY] = [invoice].[SalesLY],
		[LifetimeSales] = [invoice].[LifetimeSales]
	FROM
		@balance AS [balance]
		INNER JOIN (
			SELECT
				[DimensionID],
				CAST(AVG(DATEDIFF(day, [Date], [PaymentDate])) AS int) AS [AverageDaysToPay],
				CAST(
					SUM(CASE YEAR([Date]) WHEN YEAR(@Date) THEN DATEDIFF(day, [Date], [PaymentDate]) ELSE 0 END) / 
					CASE 
						WHEN SUM(CASE YEAR([Date]) WHEN YEAR(@Date) THEN 1 ELSE 0 END) = 0 THEN 1
						ELSE SUM(CASE YEAR([Date]) WHEN YEAR(@Date) THEN 1 ELSE 0 END)
					END
					AS int) AS [AverageDaysToPayYTD],
				SUM(CASE 
					WHEN MONTH([Date]) = MONTH(@Date) AND YEAR([Date]) = YEAR(@Date) THEN [Total]
					ELSE 0 END) AS [SalesMTD],
				SUM(CASE 
					WHEN YEAR([Date]) = YEAR(@Date) THEN [Total]
					ELSE 0 END) AS [SalesYTD],
				SUM(CASE 
					WHEN YEAR([Date]) = YEAR(@Date) - 1 THEN [Total]
					ELSE 0 END) AS [SalesLY],
				SUM([Total]) AS [LifetimeSales]
			FROM
				@invoice
			GROUP BY
				[DimensionID]
			) AS [invoice]
			ON [invoice].[DimensionID] = [balance].[ID]
			
	UPDATE @balance
		SET [BadDebt] = ISNULL(@BadDebtInvoices - ISNULL(@BadDebtPayments, 0), 0)
	
	SELECT 
		[ID],
		[d30] + [d60] + [d90] + [Over90] AS [Overdue],
		[d30],
		[d60],
		[d90],
		[Over90],
		[Total],
		[AverageDaysToPay],
		[AverageDaysToPayYTD],
		[SalesMTD],
		[SalesYTD],
		[SalesLY],
		[PaymentMTD],
		[PaymentYTD],
		[PaymentLY],
		[LifetimeSales],
		[LifetimeStatements],
		[BadDebt]
	FROM
		@balance
		
		
		
	RETURN 0
GO

GRANT EXEC ON pjm5ProjectBalanceGet TO PUBLIC
GO
