IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ProjectBrowseStoped')
	BEGIN
		PRINT 'Dropping Procedure pjm5ProjectBrowseStoped'
		DROP  Procedure  pjm5ProjectBrowseStoped
	END

GO

PRINT 'Creating Procedure pjm5ProjectBrowseStoped'
GO
/******************************************************************************
**		File: ProjectBrowseStoped.sql
**		Name: pjm5ProjectBrowseStoped
**		Desc:     ""   
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      31.03.09	ENB				 ,    
**									:     .
**									    
**		29.04.13	SOV				    
**		07.05.13	SOV				    - - 
**									        ?
**		07.05.13	SOV				  ID . -  . - 
**		05.05.14	BAO				    
*******************************************************************************/
CREATE Procedure pjm5ProjectBrowseStoped

AS
	SET NOCOUNT ON
	
--         
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 0 BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ProjectStageID],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		[Project].[Budget],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[Budgets].[PlannedManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1
			THEN [Budgets].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[ExchangeSystemName],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[Projects].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForBrowse (
			NULL,	--  
			3,		-- 
			1		--   
		) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]	

	RETURN 0
GO

GRANT EXEC ON pjm5ProjectBrowseStoped TO PUBLIC
GO   

