IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectByMarketing')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectByMarketing'
		DROP  Procedure  ReportProjectByMarketing
	END

GO

PRINT 'Creating Procedure ReportProjectByMarketing'
GO

--------------------------------------------------------------------------------------
CREATE Procedure ReportProjectByMarketing
			@DateSelector int,
			@StartDate TDate,
			@EndDate TDate,
			@CompanyID TIdentifier,
			@DivisionID TIdentifier,
			@ManagerID TIdentifier, 
			@CostCenterSelector int,
			@CostCenterID TIdentifier 
AS
	SET NOCOUNT ON

------------------------------------------------
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END

	IF @DivisionID IS NULL 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
 
	SET DATEFIRST 1	
	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@DivisionFileAs TName

	SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	
	IF @DateSelector = 0 -- today
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@EndDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
		END
		ELSE IF @DateSelector = 1 -- last month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@StartDate = DATEADD(month, -1, @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END
		ELSE IF @DateSelector = 2 -- current month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END
		ELSE -- Period
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
				@EndDate = CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime)
		END

	DECLARE @CostCenterClass Int
	SET @CostCenterClass = dbo.adfGetClassByName('adf.CostCenter')

	DECLARE @CuratorIndex Int
	SELECT @CuratorIndex = [ID] FROM [Property] 
						WHERE [Property].[Name] = ''

	DECLARE @CuratorFileAs TName
	SELECT @CuratorFileAs = [Initials] FROM [Employee]
	WHERE [Employee].[ID] = @ManagerID

	DECLARE @CostCenterFileAs TName
	SELECT @CostCenterFileAs = [FileAs] FROM [CostCenter]
						WHERE [CostCenter].[ID] = @CostCenterID  AND @CostCenterSelector != 0

	SELECT 
		@UserName AS [UserName],
		GETDATE() AS [Date],
		@StartDate AS [PeriodStart],
		@EndDate AS [PeriodEnd],
		[Company].[FileAs] AS [Company],
		[Division].[FileAs] AS [Division],
		ISNULL(@CostCenterFileAs, '( )') AS [Bank],
		ISNULL(@CuratorFileAs, '()') AS [Curator]
	FROM 
		[Company]
		LEFT OUTER JOIN [Division]
			ON [Division].[ID] = @DivisionID
		LEFT OUTER JOIN [CostCenter]
			ON [CostCenter].[ID] = @CostCenterID

	SELECT 
		ISNULL([PropertyValue].[Value], '   ') AS [Curator],
		[Company].[FileAs] AS [Customer],
		[CostCenter].[Code] AS [Bank],
		[Project].[ContractNumber] AS [ReportNumber],
		[ServiceType].[Code] AS [Object],
		[Address].[City] + ', ' + [Address].[Street] AS [Address],
		[ProjectDetail].[DueDate] AS [DueDate],
		ISNULL([InvoiceLine].[Price], 0) AS [Summ]
	FROM 
		[CostCenter]
		LEFT OUTER JOIN [PropertyValue]
			ON [PropertyValue].[DocumentClass] = @CostCenterClass
			AND [PropertyValue].[DocumentID] = [CostCenter].[ID]
			AND [PropertyValue].[PropertyID] = @CuratorIndex
		INNER JOIN	[Employee]
			ON [Employee].[Initials] = [PropertyValue].[Value]
			AND [Employee].[DivisionID] = @DivisionID
		INNER JOIN [Project]
			ON [Project].[CostCenterID] = [CostCenter].[ID]
			AND [Project].[State] IN (4)
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
			AND CAST(CONVERT(varchar(8), [ProjectDetail].[DueDate], 112) AS datetime) >= @StartDate
			AND CAST(CONVERT(varchar(8), [ProjectDetail].[DueDate], 112) AS datetime) <= @EndDate
		LEFT OUTER JOIN [Company]
			ON [Company].[ID] = [Project].[CustomerCompanyID]
		LEFT OUTER JOIN [Address]
			ON [Address].[BusinessCardClass] = [Company].[Class]
			AND [Address].[BusinessCardID] = [Company].[ID]
			AND [Address].[AddressTypeID] = 3
		INNER JOIN [Invoice]
			ON [Invoice].[ProjectID] = [Project].[ID]
			AND [Invoice].[State] IN (2, 5)	
		LEFT OUTER JOIN [InvoiceLine]
			ON [InvoiceLine].[InvoiceID] = [Invoice].[ID] 
		LEFT OUTER JOIN [ServiceType]
			ON [ServiceType].[ID] = [InvoiceLine].[ServiceTypeID] 
	WHERE
		((@CostCenterSelector = 0)
			OR
		(@CostCenterSelector = 1 AND @CostCenterFileAs IS NULL)
			OR 
		([CostCenter].[ID] = @CostCenterID AND @CostCenterSelector = 1 AND
					@CostCenterID != 0))
	AND
		((@ManagerID IS NULL)
			OR
		(@ManagerID IS NOT NULL) AND ([PropertyValue].[Value] = @CuratorFileAS))
	ORDER BY
		[PropertyValue].[Value],
		[ProjectDetail].[DueDate],
		[CostCenter].[FileAS],
		[Project].[ContractNumber]
	
	RETURN 0
GO

GRANT EXEC ON ReportProjectByMarketing TO PUBLIC
GO 