IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7CalculationTotalReport]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7CalculationTotalReport'
		DROP PROCEDURE [dbo].[pjm7CalculationTotalReport]
	END
GO

PRINT 'Creating procedure pjm7CalculationTotalReport'
GO

/******************************************************************************
**		File: pjm7CalculationTotalReport.sql
**		Name: pjm7CalculationTotalReport
**		Desc:    .  -> .
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey.Averkiev
**		Date: 12.04.2012 11:11:11
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		
*******************************************************************************/

CREATE PROCEDURE [pjm7CalculationTotalReport]
	@ParentProjectID	TIdentifier,
	@DateSelector		INT,
    @PeriodStart		TDate,
    @PeriodEnd			TDate,
    @FlagID				INT,
    @StateSelector		INT
AS
	--   
	IF dbo.adfHasAccessRightByName('ViewCalculationTotalReport') = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ParentProjectID IS NULL
	BEGIN
		RETURN 1
	END 

	DECLARE
		@timeClass			TClass,
		@expenseClass		TClass,
		@phoneClass			TClass,
		@requestClass		TClass,
		@companyClass		TClass,
		@employeeClass		TClass,
		@positionClass		TClass,
		@expenseCodeClass	TClass,
		@language			TLanguage,
		@Date				TDate,
		@PeriodStartDisplay TDate,
		@PeriodEndDisplay	TDate
	SELECT
		@timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry'),
		@expenseClass = dbo.adfGetClassByName('Pjm5.Expense'),
		@phoneClass = dbo.adfGetClassByName('Pjm5.PhoneCall'),
		@requestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest'),
		@companyClass = dbo.adfGetClassByName('Adf.Company'),
		@employeeClass = dbo.adfGetClassByName('Adf.Employee'),
		@positionClass = dbo.adfGetClassByName('Adf.Position'),
		@expenseCodeClass = dbo.adfGetClassByName('Pjm5.ExpenseCode'),
		@language = dbo.adfGetLanguage()
	
	-- 
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	IF @DateSelector = 1				--current month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodStart = DATEADD(month, -1, @PeriodStart),
		@PeriodEnd = DATEADD(month, 1, @PeriodStart),
		@PeriodEnd = DATEADD(day, -1, @PeriodEnd)
	ELSE IF @DateSelector = 0			--previous month
	SELECT
		@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@PeriodEnd = DATEADD(month, 1, @PeriodStart),
		@PeriodEnd = DATEADD(day, -1, @PeriodEnd)
	ELSE
	SELECT
		@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
		@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime)
		
	DECLARE @SubProjects TABLE 
	(
		[ProjectID]				TIdentifier, 
        [ParentProjectID]		TIdentifier, 
        [FileAs]				TName,
        [Level]					int,
        [HasTime]				bit,
        [HasExpense]			bit,
        [Date]					TDate
	)

	DECLARE @InnerCalculationSums TABLE 
	(
		[CalculationID]			TIdentifier, 
        [InnerSum]				TMoney
	)
	
	DECLARE @Period TABLE 
	(
		[PeriodStartDisplay]	TDate,	
		[PeriodEndDisplay]		TDate
	)

	DECLARE @temp TABLE --         (           )
	(
		[InvoiceNumber]			TCode,	
		[InvoiceDate]			TDate
	) 

;	
	WITH SubProjects ([ProjectID], [ParentProjectID], [FileAs], [Level]) AS
	(
	SELECT [ID], NULL, [FileAs], 1
	FROM
		[Project]
	WHERE
		[ID] = @ParentProjectID
	UNION ALL
	SELECT [Task].[SubProjectID], [Task].[ProjectID], [Task].[FileAs], [Level] + 1
	FROM [Task]
		INNER JOIN SubProjects
			ON [Task].[ProjectID] = SubProjects.[ProjectID]
	WHERE
		[Task].[SubProjectID] IS NOT NULL
	)
	
	-- ,  
	INSERT INTO @SubProjects ([ProjectID], [ParentProjectID], [FileAs], [Level], [HasTime], [HasExpense], [Date])
	SELECT 
		[SP].[ProjectID], 
		[SP].[ParentProjectID], 
		[SP].[FileAs], 
		[SP].[Level],
		CASE 
			WHEN EXISTS (SELECT * FROM [Calculation] WHERE [ProjectID] = [SP].[ProjectID] 
											AND [Calculation].[DocumentClass] = @timeClass) THEN 1
			ELSE 0
		END
								AS [HasTime],
		CASE 
			WHEN EXISTS (SELECT * FROM [Calculation] WHERE [ProjectID] = [SP].[ProjectID] 
											AND [Calculation].[DocumentClass] = @expenseClass) THEN 1
			ELSE 0
		END						AS [HasExpense],
		[Project].[Date]
	FROM
		SubProjects AS [SP] JOIN [Project] ON [SP].[ProjectID] = [Project].[ID]

	INSERT INTO @temp ([InvoiceNumber], [InvoiceDate])
	SELECT
		TOP 1 
		[Calculation].[Number],
		[Calculation].[Date]
	FROM [Calculation] 
		INNER JOIN @SubProjects AS [SP] ON [Calculation].[ProjectID] = [SP].[ProjectID]

	--SELECT * FROM @temp
	
	-- 
	INSERT INTO @Period ([PeriodStartDisplay], [PeriodEndDisplay])
	SELECT
		MIN([Calculation].[PeriodStart]),
		MAX([Calculation].[PeriodEnd])
	FROM
		[Calculation]
		INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
		INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [CalculationAdvance] ON [Calculation].[ID] = [CalculationAdvance].[CalculationID]
		LEFT OUTER JOIN [Calculation] AS [InnerCalculation] ON [CalculationAdvance].[AdvanceCalculationID] = [InnerCalculation].[ID]
	WHERE
		[SubProjects].[Level] <> 1		--   
		AND								--  
		(
			@FlagID = 0
			OR
			[Calculation].[Flag] <> @FlagID
		)
		AND
		(
			[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		AND 
		(
			@StateSelector = 0
			OR
			(@StateSelector = 1 AND [Calculation].[State] = 1)
			OR
			(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
		)
	
	SET @PeriodStartDisplay = (SELECT [PeriodStartDisplay] FROM @Period)
	SET @PeriodEndDisplay = (SELECT [PeriodEndDisplay] FROM @Period)
	
	INSERT INTO @InnerCalculationSums ([CalculationID],[InnerSum])
	SELECT 
	[Calculation].[ID],
	SUM([InnerCalculation].[TotalPC])
	FROM
	[Calculation]
		INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
		INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [CalculationAdvance] ON [Calculation].[ID] = [CalculationAdvance].[CalculationID]
		LEFT OUTER JOIN [Calculation] AS [InnerCalculation] ON [CalculationAdvance].[AdvanceCalculationID] = [InnerCalculation].[ID]
	WHERE
		[SubProjects].[Level] <> 1		--   
		AND								--  
		(
			@FlagID = 0
			OR
			[Calculation].[Flag] <> @FlagID
		)
		AND
		(
			[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		AND 
		(
			@StateSelector = 0
			OR
			(@StateSelector = 1 AND [Calculation].[State] = 1)
			OR
			(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
		)
	GROUP BY
	[Calculation].[ID]

	-->SELECT * FROM @InnerCalculationSums -->debug

	--SELECT * FROM @SubProjects -->debug
	-- 
	SELECT 
		[Calculation].[ID]				AS [ID],
		[Calculation].[Class]			AS [Class],
		[Calculation].[Flag]			AS [Flag],
		[Calculation].[State]			AS [State],
		[Project].[Number]				AS [ProjectNumber],
		[Project].[FileAs]				AS [ProjectFileAs],
		CASE 
			WHEN [Calculation].[DocumentClass] = @timeClass AND @language = 'ru' THEN ''
			WHEN [Calculation].[DocumentClass] = @expenseClass AND @language = 'ru' THEN ''
			WHEN [Calculation].[DocumentClass] = @phoneClass AND @language = 'ru' THEN ' '
			WHEN [Calculation].[DocumentClass] = @timeClass AND @language = 'en' THEN 'Time'
			WHEN [Calculation].[DocumentClass] = @expenseClass AND @language = 'en' THEN 'Expenses'
			WHEN [Calculation].[DocumentClass] = @phoneClass AND @language = 'en' THEN 'Phone Calls'
			ELSE 'Unknown'
		END								AS [Type],
		[Calculation].[Number]			AS [Number],
		[Calculation].[Date]			AS [Date],
		[Calculation].[PeriodStart]		AS [PeriodStart],
		[Calculation].[PeriodEnd]		AS [PeriodEnd],
		([Calculation].[Total] - ISNULL([InnerCalculation].[InnerSum], 0.0))
										AS [Total],
		CASE 
			WHEN [Calculation].[DiscountType] = 2 THEN [Calculation].[Discount]
			ELSE 0.0
		END								AS [Markup],
		[Calculation].[CurrencyCode]	AS [CurrencyCode],
		[Calculation].[Created]			AS [Created],
		[Calculation].[CreatedBy]		AS [CreatedBy],
		[Calculation].[Modified]		AS [Modified],
		[Calculation].[ModifiedBy]		AS [ModifiedBy],
		[Calculation].[TimeStamp]		AS [Timestamp],
		[Calculation].[FileAs]			AS [FileAs],
		[Project].[Date]				AS [ProjectDate],
		ISNULL([StateGlobal].[Name], [State].[Name]) AS [StateName]
	FROM
		[Calculation]
		INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
		INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN @InnerCalculationSums AS [InnerCalculation] ON [Calculation].[ID] = [InnerCalculation].[CalculationID]
		LEFT OUTER JOIN [State]
			ON [State].[Class] = [Calculation].[Class] AND [State].[State] = [Calculation].[State]
		LEFT OUTER JOIN [StateGlobal]
			ON [StateGlobal].[Class] = [Calculation].[Class] AND [StateGlobal].[State] = [Calculation].[State] AND [StateGlobal].[Language] = @language
	WHERE
		[SubProjects].[Level] <> 1		--   
		AND								--  
		(
			@FlagID = 0
			OR
			[Calculation].[Flag] <> @FlagID
		)
		AND
		(
			[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		AND 
		(
			@StateSelector = 0
			OR
			(@StateSelector = 1 AND [Calculation].[State] = 1)
			OR
			(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
		)
	
	--Invoice
	SELECT 
		(SELECT [LegalName] FROM [Company] 
			WHERE [ID] = [CustomerCompanyID])				AS [CustomerLegalName],
		(	SELECT 
				ISNULL([PropertyValue].[Value],'') 
			FROM [PropertyValue] 
				JOIN [Property] ON [PropertyValue].[PropertyID] = [Property].[ID]
			WHERE [Property].[Class] = @companyClass
				AND [PropertyValue].[DocumentID] = [CustomerCompanyID]
				AND [Property].[Guid] like '%00000001-0000-0000-0000-000000000000%')
															AS [CustomerLegalNameOtherLang],
		@PeriodStartDisplay									AS [PeriodStart],
		@PeriodEndDisplay									AS [PeriodEnd],
		[Project].[CurrencyCode]							AS [CurrencyCode],
		(	SELECT ISNULL(SUM([Calculation].[Discount]), 0.0) 
			FROM @SubProjects AS [SubProjects]
				JOIN [Calculation] ON [SubProjects].[ProjectID] = [Calculation].[ProjectID]
			WHERE [Calculation].[DocumentClass] = @timeClass 
				AND [Calculation].[DiscountType] = 2
				AND
				(
					[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
				)
						AND								--  
				(
					@FlagID = 0
					OR
					[Calculation].[Flag] <> @FlagID
				)
				AND
				(
					[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
				)
				AND 
				(
					@StateSelector = 0
					OR
					(@StateSelector = 1 AND [Calculation].[State] = 1)
					OR
					(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
				)
		)													AS [Markup],
		CAST(DAY(@PeriodStartDisplay) AS varchar(2)) + ' ' + dbo.fnPjm7GetMonthName(MONTH(@PeriodStartDisplay),'ru',1) + 
		' ' + CAST(YEAR(@PeriodStartDisplay) AS varchar(4)) 
															AS [PeriodStartRu],
		CAST(DAY(@PeriodEndDisplay) AS varchar(2)) + ' ' + dbo.fnPjm7GetMonthName(MONTH(@PeriodEndDisplay),'ru',1) + 
		' ' + CAST(YEAR(@PeriodEndDisplay) AS varchar(4)) 
															AS [PeriodEndRu],
		CAST(DAY(@PeriodStartDisplay) AS varchar(2)) + ' ' + dbo.fnPjm7GetMonthName(MONTH(@PeriodStartDisplay),'en',1) + 
		' ' + CAST(YEAR(@PeriodStartDisplay) AS varchar(4))
															AS [PeriodStartEn],
		CAST(DAY(@PeriodEndDisplay) AS varchar(2)) + ' ' + dbo.fnPjm7GetMonthName(MONTH(@PeriodEndDisplay),'en',1) + 
		' ' + CAST(YEAR(@PeriodEndDisplay) AS varchar(4)) 
															AS [PeriodEndEn],
		(SELECT [InvoiceNumber] FROM @temp)				AS [InvoiceNumber],
		CAST(DAY((SELECT [InvoiceDate] FROM @temp)) AS varchar(2)) + ' ' + dbo.fnPjm7GetMonthName(MONTH((SELECT [InvoiceDate] FROM @temp)),'en',1) + 
		' ' + CAST(YEAR((SELECT [InvoiceDate] FROM @temp)) AS varchar(4)) 
															AS [InvoiceDate]
	FROM 
		[Project]
	WHERE
		[ID] = @ParentProjectID
	
	--Orders
	SELECT 
	[SubProjects].[ProjectID]		AS [ProjectID],
	[Project].[Date]				AS [ProjectDate],
	[Project].[Number]				AS [ProjectNumber],
	[Project].[FileAs]				AS [ProjectFileAs],
	[SubProjects].[HasTime]			AS [HasTime],
	[SubProjects].[HasExpense]		AS [HasExpense]
	FROM
	@SubProjects AS [SubProjects]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [Calculation] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	WHERE 
		[SubProjects].[Level] <> 1
		AND								--  
		(
			@FlagID = 0
			OR
			[Calculation].[Flag] <> @FlagID
		)
		AND
		(
			[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		AND 
		(
			@StateSelector = 0
			OR
			(@StateSelector = 1 AND [Calculation].[State] = 1)
			OR
			(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
		)
	GROUP BY 
		[Project].[ID],[SubProjects].[ProjectID], [Project].[Date], [Project].[Number], [Project].[FileAs], [SubProjects].[HasTime], [SubProjects].[HasExpense]
	ORDER BY 
		[Project].[ID]
	
	--TimeEntry
	SELECT 
		[Project].[ID]					AS [ProjectID],
		[Employee].[Initials]			AS [Initials],
		SUM([EntryAmount].[Amount])		AS [Hours],
		[EntryAmount].[Price]			AS [Rate],
		SUM([EntryAmount].[Amount]
			* [EntryAmount].[Price])	AS [Total]
	FROM
	[Calculation]
	INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [CalculationLine] ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	INNER JOIN [TimeEntry] ON [CalculationLine].[DocumentID] = [TimeEntry].[ID] AND [TimeEntry].[Class] = [CalculationLine].[DocumentClass]
	INNER JOIN [Employee] ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [EntryAmount] ON [TimeEntry].[ID] = [EntryAmount].[ID]
	WHERE
	[SubProjects].[Level] <> 1	--   
	AND							--  
	(
		@FlagID = 0
		OR
		[Calculation].[Flag] <> @FlagID
	)
	AND
	(
		[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
	)
	AND 
	(
		@StateSelector = 0
		OR
		(@StateSelector = 1 AND [Calculation].[State] = 1)
		OR
		(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
	)
	GROUP BY
	[Project].[ID], [Employee].[Initials], [EntryAmount].[Price]
	
	--Expense
	SELECT
		[Project].[ID]					AS [ProjectID],
		[Employee].[Initials]			AS [Initials],
		SUM([Expense].[Amount])			AS [Amount],
		[ExpenseCode].[FileAs]			AS [ExpenseType],
		SUM([Expense].[TotalPC])		AS [Total],
		(SELECT 
				ISNULL([PropertyValue].[Value],'') 
			FROM [PropertyValue] 
				JOIN [Property] ON [PropertyValue].[PropertyID] = [Property].[ID]
			WHERE [Property].[Class] = @expenseCodeClass
				AND [PropertyValue].[DocumentID] = [ExpenseCode].[ID]
				AND [Property].[Name] like '%   %')	AS [ExpenseTypeOtherLang]
	FROM
	[Calculation]
	INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [CalculationLine] ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	INNER JOIN [Expense] ON [CalculationLine].[DocumentID] = [Expense].[ID] AND [Expense].[Class] = [CalculationLine].[DocumentClass]
	INNER JOIN [Employee] ON [Expense].[EmployeeID] = [Employee].[ID]
	LEFT OUTER JOIN [ExpenseCode] ON [Expense].[ExpenseCodeID] = [ExpenseCode].[ID]
	WHERE
	[SubProjects].[Level] <> 1	--   
	AND							--  
	(
		@FlagID = 0
		OR
		[Calculation].[Flag] <> @FlagID
	)
	AND
	(
		[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
	)
	AND 
	(
		@StateSelector = 0
		OR
		(@StateSelector = 1 AND [Calculation].[State] = 1)
		OR
		(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
	)
	GROUP BY
	[Project].[ID], [Employee].[Initials], [ExpenseCode].[FileAs], [ExpenseCode].[ID]

	--Employee
		--        
	SELECT DISTINCT
		ISNULL([TEmployee].[Initials], [EEmployee].[Initials])				AS [Initials],
		CASE 
			WHEN [EEmployee].[ID] IS NULL THEN ISNULL([TEmployee].[FirstName],' ') + ' ' + ISNULL([TEmployee].[LastName], ' ')
			ELSE ISNULL([EEmployee].[FirstName],' ') + ' ' + ISNULL([EEmployee].[LastName], ' ')
		END
																			AS [FileAs],	-- , 
		(SELECT [FileAs] FROM [Position] WHERE [ID] = 
			ISNULL([TEmployee].[PositionID], [EEmployee].[PositionID]))		AS [Position],
		(SELECT 
				ISNULL([PropertyValue].[Value],'') 
			FROM [PropertyValue] 
				JOIN [Property] ON [PropertyValue].[PropertyID] = [Property].[ID]
			WHERE [Property].[Class] = @positionClass
				AND [PropertyValue].[DocumentID] = ISNULL([TEmployee].[PositionID], [EEmployee].[PositionID])
				AND [Property].[Name] like '%   %')	AS [PositionOtherLang],
		(SELECT 
				ISNULL([PropertyValue].[Value],'') 
			FROM [PropertyValue] 
				JOIN [Property] ON [PropertyValue].[PropertyID] = [Property].[ID]
			WHERE [Property].[Class] = @employeeClass
				AND [PropertyValue].[DocumentID] = ISNULL([TEmployee].[ID], [EEmployee].[ID])
				AND [Property].[Name] like '%   %')				AS [FileAsOtherLang]
	FROM
	[Calculation]
	INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [CalculationLine] ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	LEFT OUTER JOIN [TimeEntry] ON [CalculationLine].[DocumentID] = [TimeEntry].[ID] AND [TimeEntry].[Class] = [CalculationLine].[DocumentClass]
	LEFT OUTER JOIN [Expense] ON [CalculationLine].[DocumentID] = [Expense].[ID] AND [Expense].[Class] = [CalculationLine].[DocumentClass]
	LEFT OUTER JOIN [Employee] [TEmployee] ON [TimeEntry].[EmployeeID] = [TEmployee].[ID] 
	LEFT OUTER JOIN [Employee] [EEmployee] ON [Expense].[EmployeeID] = [EEmployee].[ID] 
	WHERE 
	[SubProjects].[Level] <> 1	--    
	AND
	(
		@FlagID = 0
		OR
		[Calculation].[Flag] <> @FlagID
	)
	AND
	(
		[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
	)
	AND 
	(
		@StateSelector = 0
		OR
		(@StateSelector = 1 AND [Calculation].[State] = 1)
		OR
		(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
	)
	
	--TimeEntryDetails
	SELECT 
		[Project].[Number]						AS [ProjectNumber],
		[TimeEntry].[StartTime]					AS [Date],
		[Employee].[Initials]					AS [Initials],
		[TimeEntry].[FileAs]					AS [FileAs],
		[EntryAmount].[Amount]					AS [Hours]
	FROM
	[Calculation]
	INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [CalculationLine] ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	INNER JOIN [TimeEntry] ON [CalculationLine].[DocumentID] = [TimeEntry].[ID] AND [TimeEntry].[Class] = [CalculationLine].[DocumentClass]
	INNER JOIN [Employee] ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [EntryAmount] ON [TimeEntry].[ID] = [EntryAmount].[ID]
	WHERE
	[SubProjects].[Level] <> 1	--   
	AND							--  
	(
		@FlagID = 0
		OR
		[Calculation].[Flag] <> @FlagID
	)
	AND
	(
		[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
	)
	AND 
	(
		@StateSelector = 0
		OR
		(@StateSelector = 1 AND [Calculation].[State] = 1)
		OR
		(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
	)
	ORDER BY
	[TimeEntry].[StartTime]
	
	--ExpenseDetail
	SELECT
		[Project].[Number]				AS [ProjectNumber],
		[Expense].[Date]				AS [Date],
		[ExpenseCode].[FileAs]			AS [ExpenseType],
		[Expense].[Amount]				AS [Amount],
		[Employee].[Initials]			AS [Initials],
		[Expense].[FileAs]				AS [ExpenseFileAs],
		[Expense].[TotalPC]				AS [Total],
		(SELECT 
				ISNULL([PropertyValue].[Value],'') 
			FROM [PropertyValue] 
				JOIN [Property] ON [PropertyValue].[PropertyID] = [Property].[ID]
			WHERE [Property].[Class] = @expenseCodeClass
				AND [PropertyValue].[DocumentID] = [ExpenseCode].[ID]
				AND [Property].[Name] like '%   %')	AS [ExpenseTypeOtherLang]
	FROM
	[Calculation]
	INNER JOIN @SubProjects AS [SubProjects] ON [Calculation].[ProjectID] = [SubProjects].[ProjectID]
	INNER JOIN [Project] ON [SubProjects].[ProjectID] = [Project].[ID]
	INNER JOIN [CalculationLine] ON [Calculation].[ID] = [CalculationLine].[CalculationID]
	INNER JOIN [Expense] ON [CalculationLine].[DocumentID] = [Expense].[ID] AND [Expense].[Class] = [CalculationLine].[DocumentClass]
	INNER JOIN [Employee] ON [Expense].[EmployeeID] = [Employee].[ID]
	LEFT OUTER JOIN [ExpenseCode] ON [Expense].[ExpenseCodeID] = [ExpenseCode].[ID]
	WHERE
	[SubProjects].[Level] <> 1	--   
	AND							--  
	(
		@FlagID = 0
		OR
		[Calculation].[Flag] <> @FlagID
	)
	AND
	(
		[Calculation].[Date] BETWEEN @PeriodStart AND @PeriodEnd
	)
	AND 
	(
		@StateSelector = 0
		OR
		(@StateSelector = 1 AND [Calculation].[State] = 1)
		OR
		(@StateSelector = 2 AND [Calculation].[State] IN (2,3,5))
	)
	ORDER BY
		[Project].[Number], [ExpenseCode].[FileAs]

	RETURN 0
GO

GRANT EXECUTE ON [pjm7CalculationTotalReport] TO PUBLIC
GO