IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeActivityResult')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeActivityResult'
		DROP  Procedure  ReportEmployeeActivityResult
	END
GO

PRINT 'Creating Procedure ReportEmployeeActivityResult'
GO
/******************************************************************************
**		File: ReportEmployeeActivityResult.sql
**		Name: ReportEmployeeActivityResult
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		08.08.2013	BAO				    
**									  
**		14.08.2013	BAO				     
**									
**		28.08.2013	BAO				    [Duration]
**									 
*******************************************************************************/
CREATE Procedure [dbo].[ReportEmployeeActivityResult]
	@EmployeeID		TIdentifier,
	@DateSelector	int = 1,
	@PeriodStart	Tdatetime,
	@PeriodEnd		Tdatetime
AS
	SET NOCOUNT ON
	DECLARE 
		@Date			datetime,
		@ProjectName	TName,
		@ProjectNumber	TName,
		@value			TVariant,
		@WorkTime		decimal(18,2),
		@WorkingDays	decimal(18,2)
		
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
	SET @WorkTime = @WorkTime / 60.00
	
	SET DATEFIRST 1
	
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	
	SELECT 
		@EmployeeID = [ID]
	FROM 
		[Employee] 
	WHERE 
		([Employee].[ID] = @EmployeeID) OR
		(@EmployeeID IS NULL AND [UserID] = dbo.adfGetCurrentUserID())
			
	IF @DateSelector = 0 -- week
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(weekday, @Date), @Date),
			@PeriodEnd = DATEADD(day, 1, @Date)

	IF @DateSelector = 1 -- prev week
		SELECT
			@PeriodStart = DATEADD(day, 1-7-DATEPART(weekday, @Date), @Date),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 2 -- month
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, 1, @Date)

	IF @DateSelector = 3 -- prev month
		SELECT
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@PeriodStart = DATEADD(month, -1, @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)

	IF @DateSelector = 5
		SELECT
			@PeriodStart = [StartDate],
			@PeriodEnd = [EndDate]
		FROM	
			dbo.adfGetDateInterval(3, GETDATE(), GETDATE(), GETDATE())

	IF @DateSelector = 4
		SELECT
			@PeriodStart = [StartDate],
			@PeriodEnd = [EndDate]
		FROM	
			dbo.adfGetDateInterval(4, GETDATE(), GETDATE(), GETDATE())

	IF @DateSelector = 6 
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))
			
	IF @PeriodStart >= @PeriodEnd
	BEGIN
		RAISERROR('#InvalidPeriod', 16, -1)
		RETURN 1
	END
	
	SET DATEFIRST 7
	SET @WorkingDays = dbo.fnPjm5GetWorkingDays(@PeriodStart, DATEADD(day, -1, @PeriodEnd))
	SET DATEFIRST 1
		
	EXECUTE ReportEmployeeActivityResultHeader @EmployeeID,	@PeriodStart, @PeriodEnd, @DateSelector, @WorkTime, @WorkingDays
	
	-- ActiveTypes
	SELECT
		ISNULL([ActivityType].[ID], -1) AS [DimensionID],
		ISNULL([ActivityType].[FileAs], '( )') AS [ActivityTypeName],
		SUM([TimeEntry].[RoundedDuration] / 60.00) AS [Duration]
	INTO #table
	FROM
		[TimeEntry]
		LEFT OUTER JOIN [ActivityType] 
			ON [TimeEntry].[ActivityTypeID] = [ActivityType].[ID]
			
	WHERE
		[TimeEntry].[EmployeeID] = @EmployeeID AND
		[TimeEntry].[StartTime] >= @PeriodStart AND
		[TimeEntry].[StartTime] < @PeriodEnd AND
		[TimeEntry].[State]in(2,3,6)
	GROUP BY
		ISNULL([ActivityType].[ID], -1),
		ISNULL([ActivityType].[FileAs], '( )')
		
	SELECT
		0 AS [Type],
		[DimensionID],
		[ActivityTypeName] AS [ActivityTypeName],
		[Duration] AS [Duration]
	INTO #result
	FROM #table
	WHERE [DimensionID] = -1
	DELETE #table WHERE [DimensionID] = -1
	
	DECLARE 
		@Sum	decimal(12, 2),
		@Count int,
		@Limit int,
		@Index int,
		@ID int,
		@Name varchar(256),
		@Duration decimal(12, 2)
		
	SELECT 
		@Sum = SUM([Duration]),
		@Limit = 3,
		@Index = 1
	FROM 
		#table
	IF @Sum != 0
		SELECT
			@Limit = COUNT(*)
		FROM
			#table
		WHERE
			100.0 * ([Duration] / @Sum)  >= 5.0

	IF @Limit < 3 
		SET @Limit = 3
		
		
	SELECT @Count = COUNT(*) FROM #table
	IF EXISTS (SELECT * FROM #result)
	BEGIN
		SELECT 
			@Index = 2,
			@Limit = @Limit + 1
		
	END

	WHILE @Index <= @Count AND @Index <= @Limit
	BEGIN
		SELECT
			@ID = [DimensionID],
			@Name = [ActivityTypeName],
			@Duration = [Duration]
		FROM
			#table
		WHERE 
			[Duration] = (SELECT MAX([Duration]) FROM #table)
		ORDER BY
			[Duration] DESC
			
		INSERT INTO #result VALUES (1, @ID, @Name, @Duration)
		DELETE FROM #table WHERE [DimensionID] = @ID
		SET @Index = @Index + 1
	END
	
	SELECT @Count = COUNT(*) FROM #table
	IF @Count > 1
		INSERT INTO #result 
		SELECT 
			1, 
			0, 
			'()', 
			SUM([Duration])
		FROM #table
	ELSE
		INSERT INTO #result 
		SELECT 
			1, 
			[DimensionID], 
			[ActivityTypeName], 
			[Duration]
		FROM #table
	
	DECLARE @Result TABLE ([DimensionID] int, [ActivityTypeName] nvarchar(max), [Duration] decimal(12, 2), [Percent] decimal(12, 3))
	INSERT INTO @Result
	SELECT 
		[DimensionID],
		[ActivityTypeName],
		[Duration],
		NULL
	FROM
		#result
			
	INSERT INTO @Result	
	SELECT 
		-1,
		' ',
		CASE
			WHEN (((@WorkTime * @WorkingDays) - SUM([Duration])) < 0)
			THEN 0
			ELSE ((@WorkTime * @WorkingDays) - ISNULL(SUM([Duration]), 0))
		END AS [Duration],
		NULL
	FROM
		#result
		
	SELECT @Sum = SUM([Duration])
	FROM @Result	
	
	UPDATE @Result
	SET [Percent] = [Duration]/@Sum
	
	SELECT * FROM @Result	
		
RETURN 0
GO

GRANT EXEC ON ReportEmployeeActivityResult TO PUBLIC
GO