IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportFMEL')
	BEGIN
		PRINT 'Dropping Procedure ReportFMEL'
		DROP  Procedure  ReportFMEL
	END

GO

PRINT 'Creating Procedure ReportFMEL'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE PROCEDURE [dbo].[ReportFMEL]
        @EmployeeID		TIdentifier,
        @DateSelector	int,
        @StartDate		TDate,
        @EndDate		TDate
	AS

	SET NOCOUNT ON

	--PERMISIONS
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFMELReport')) = 0 
	BEGIN
		  RAISERROR('#NotEnoughPermissions', 18, -1)
		  RETURN 1
	END

	DECLARE
		@FirstDayOfWeek TINYINT

	SET @FirstDayOfWeek = @@DATEFIRST
	SET DATEFIRST 7	

	SELECT 
		@EmployeeID = [ID]
	FROM 
		[Employee] 
	WHERE 
		([Employee].[ID] = @EmployeeID) OR
		(@EmployeeID IS NULL AND [UserID] = dbo.adfGetCurrentUserID())
	
	--HEADER
	EXEC ReportFMELHeader @EmployeeID, @DateSelector, @StartDate = @StartDate OUTPUT, @EndDate = @EndDate OUTPUT

	--GETTING WORKING DAYS FROM DB
	DECLARE
		@DayMask Int,
		@value TVariant
	SELECT
		@value = Value
	FROM
		[F41AB0F8-FDF0-4FAD-9B71-8F17B4A51B53]
	WHERE
		[Name]='WorkDaysOfWeek'
			AND
		[Group]='Pjm5'
	SET @daymask = CAST(@value as int)

	--TIME TABLE
	DECLARE @TimeTable TABLE
	(
		[Day]			Int,
		[ProjectID]		TIdentifier,
		[OverAllTime]	decimal(18,2),
		[MassTime]		decimal(18,2),
		[Planned]		TBool
	)
	--PROJECTS TABLE
	DECLARE @ProjectTable TABLE
	(
		[ProjectID]		TIdentifier,
		[ProjectTypeID]	TIdentifier,
		[ProjectFileAs]	TName,
		[ProjectCode]   TCode
	)
	--MONTH TABLE
	DECLARE @MonthTable TABLE
	(
		[DayOfMonth]	Int,
		[DayOfWeek]		Int,
		[Date]			TDate,
		[IsHoliday]		TBool
	)

	--FILL TIME TABLE
	INSERT INTO @TimeTable
	(
		[Day],
		[ProjectID],
		[OverAllTime],
		[MassTime],
		[Planned]
	)
	SELECT
		DAY([TimeEntry].[StartTime]),
		[TimeEntry].[ProjectID],
		SUM([TimeEntry].[Duration]),
		NULL,
		0
	FROM
		[TimeEntry]
	WHERE
		[TimeEntry].[EmployeeID] = @EmployeeID
		AND
		YEAR([TimeEntry].[StartTime]) = Year(@StartDate)
		AND
		MONTH([TimeEntry].[StartTime]) = MONTH(@StartDate)
		AND CAST([TimeEntry].[State] AS Int) IN (2,3,6)
	GROUP BY
		[TimeEntry].[ProjectID],
		DAY([TimeEntry].[StartTime])--,
		--CAST([TimeEntry].[State] AS Int)
	UNION ALL
	SELECT
		DAY([TimeEntry].[StartTime]),
		-1,
		SUM([TimeEntry].[Duration]),
		NULL,
		0
	FROM
		[TimeEntry]
	WHERE
		[TimeEntry].[EmployeeID] = @EmployeeID
		AND
		YEAR([TimeEntry].[StartTime]) = Year(@StartDate)
		AND
		MONTH([TimeEntry].[StartTime]) = MONTH(@StartDate)
		AND CAST([TimeEntry].[State] AS Int) = 2
	GROUP BY
		[TimeEntry].[ProjectID],
		DAY([TimeEntry].[StartTime]),
		CAST([TimeEntry].[State] AS Int)
	UNION ALL
	SELECT
		DAY([BusyEntry].[Date]) AS [Day],
		[BusyEntry].[ProjectID] AS [ProjectID],
		SUM([BusyEntry].[Planned]) AS [OverAllTime],
		NULL,
		1
	FROM
		[BusyEntry]
	WHERE
		[BusyEntry].[EmployeeID] = @EmployeeID
		AND	
		YEAR([BusyEntry].[Date]) = YEAR(@StartDate)
		AND
		MONTH([BusyEntry].[Date]) = MONTH(@StartDate)
	GROUP BY
		[BusyEntry].[ProjectID],
		DAY([BusyEntry].[Date])
		
	--FILL MASSTIME FIELD
	UPDATE tt
	SET
		tt.[MassTime] =
			(SELECT
				CASE
					WHEN SUM(tmp.[OverAllTime]) = 0 THEN NULL
					ELSE tt.[OverAllTime]/SUM(tmp.[OverAllTime])
				END
			FROM
				@TimeTable tmp
			WHERE
				tmp.[Day] = tt.[Day]
				AND
				tmp.[Planned] = 0
				AND tmp.[ProjectID] <> -1)
	FROM
		@TimeTable tt

	--FILL PROJECTS TABLE
	INSERT INTO @ProjectTable
	(
		[ProjectID],
		[ProjectTypeID],
		[ProjectFileAs],
		[ProjectCode]
	)
	SELECT
		[Project].[ID],
		[Project].[ProjectTypeID],
		[Project].[FileAs],
		[Project].[Number]
	FROM
		[Project]
	WHERE
		[Project].[ID] IN (SELECT [ProjectID] FROM @TimeTable)
	ORDER BY
		[Project].[ProjectTypeID] ASC

	INSERT INTO @ProjectTable
	(
		[ProjectID],
		[ProjectTypeID],
		[ProjectFileAs],
		[ProjectCode]
	)
	SELECT
		-1,
		-1,
		'  ',
		'  '

	--FILL MONTH TABLE
	--SET DATEFIRST 1
	DECLARE 
		@date			datetime,
		@start			datetime,
		@finish			datetime
	SELECT 
		@date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
		@StartDate = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1-DAY(@date), @date)
			WHEN 1 THEN DATEADD(month, -1, DATEADD(day, 1-DAY(@date), @date))
			ELSE CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime)
		END,
		@EndDate = CASE @DateSelector
		WHEN 0 THEN @date
		ELSE DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END,
		@start = CAST(CONVERT(varchar(8), DATEADD(day, 1 - DATEPART(weekday, @StartDate), @StartDate), 112) AS datetime),
		@finish = CAST(CONVERT(varchar(8), DATEADD(day, 7 - DATEPART(weekday, DATEADD(day, -1, DATEADD(month, 1, @StartDate))), DATEADD(day, -1, DATEADD(month, 1, @StartDate))), 112) AS datetime)

	DECLARE @period TABLE([Date] datetime)

	WHILE @start <= @finish
	BEGIN
		INSERT INTO @period VALUES(@start)
		SET @start = DATEADD(day, 1, @start)
	END	
	
	INSERT INTO @MonthTable
	(
		[DayOfMonth],
		[DayOfWeek],
		[Date],
		[IsHoliday]
	)
	SELECT
		CASE
			WHEN tp.[Date] BETWEEN @StartDate AND DATEADD(day, -1, DATEADD(month, 1, @StartDate))
				THEN DAY(tp.[Date])
			ELSE NULL
		END,
		DATEPART(weekday, tp.[Date]),
		tp.[Date],
		CASE
			WHEN dbo.fnPjm5NonWorkingTime(tp.[Date]) = 1 OR dbo.fnPjm5IsWorkingDayByMask(tp.[Date], @daymask) = 0
				THEN 1
			ELSE 0
		END
	FROM
		@period tp
	WHERE 
		tp.[Date] >= @StartDate AND tp.[Date] < DATEADD(month, 1, @StartDate)
	GROUP BY
		CASE
			WHEN tp.[Date] BETWEEN @StartDate AND DATEADD(day, -1, DATEADD(month, 1, @StartDate))
				THEN DAY(tp.[Date])
			ELSE NULL
		END,
		YEAR(tp.[Date]),
		DATEPART(week, tp.[Date]),
		DATEPART(weekday, tp.[Date]),
		tp.[Date]
	ORDER BY
		tp.[Date]

	--MONTH TIME TABLE	
	SELECT
		DISTINCT pt.[ProjectID],
		pt.[ProjectTypeID],
		pt.[ProjectFileAs],
		pt.[ProjectCode],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 1 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 1 AND tmp.[Planned] = 0)
		END AS [Day1],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 2 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 2 AND tmp.[Planned] = 0)
		END AS [Day2],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 3 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 3 AND tmp.[Planned] = 0)
		END AS [Day3],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 4 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 4 AND tmp.[Planned] = 0)
		END AS [Day4],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 5 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 5 AND tmp.[Planned] = 0)
		END AS [Day5],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 6 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 6 AND tmp.[Planned] = 0)
		END AS [Day6],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 7 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 7 AND tmp.[Planned] = 0)
		END AS [Day7],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 8 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 8 AND tmp.[Planned] = 0)
		END AS [Day8],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 9 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 9 AND tmp.[Planned] = 0)
		END AS [Day9],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 10 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 10 AND tmp.[Planned] = 0)
		END AS [Day10],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 11 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 11 AND tmp.[Planned] = 0)
		END AS [Day11],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 12 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 12 AND tmp.[Planned] = 0)
		END AS [Day12],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 13 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 13 AND tmp.[Planned] = 0)
		END AS [Day13],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 14 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 14 AND tmp.[Planned] = 0)
		END AS [Day14],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 15 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 15 AND tmp.[Planned] = 0)
		END AS [Day15],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 16 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 16 AND tmp.[Planned] = 0)
		END AS [Day16],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 17 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 17 AND tmp.[Planned] = 0)
		END AS [Day17],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 18 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 18 AND tmp.[Planned] = 0)
		END AS [Day18],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 19 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 19 AND tmp.[Planned] = 0)
		END AS [Day19],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 20 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 20 AND tmp.[Planned] = 0)
		END AS [Day20],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 21 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 21 AND tmp.[Planned] = 0)
		END AS [Day21],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 22 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 22 AND tmp.[Planned] = 0)
		END AS [Day22],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 23 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 23 AND tmp.[Planned] = 0)
		END AS [Day23],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 24 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 24 AND tmp.[Planned] = 0)
		END AS [Day24],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 25 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 25 AND tmp.[Planned] = 0)
		END AS [Day25],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 26 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 26 AND tmp.[Planned] = 0)
		END AS [Day26],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 27 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 27 AND tmp.[Planned] = 0)
		END AS [Day27],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 28 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 28 AND tmp.[Planned] = 0)
		END AS [Day28],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 29 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 29 AND tmp.[Planned] = 0)
		END AS [Day29],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 30 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 30 AND tmp.[Planned] = 0)
		END AS [Day30],
		CASE WHEN pt.[ProjectID] <> -1 THEN 
		(SELECT TOP(1) tmp.[OverAllTime] / 60.0 FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 31 AND tmp.[Planned] = 0)
		ELSE
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Day] = 31 AND tmp.[Planned] = 0)
		END AS [Day31],
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Planned] = 1) AS [Planned],
		(SELECT SUM(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Planned] = 0) AS [Fact],
		--(SELECT COUNT(tmp.[OverAllTime] / 60.0) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Planned] = 0) AS [Days]
		(SELECT SUM(tmp.[MassTime]) FROM @TimeTable tmp WHERE tmp.[ProjectID] = pt.[ProjectID] AND tmp.[Planned] = 0) AS [Days]
	FROM
		@TimeTable tt
	LEFT OUTER JOIN @ProjectTable pt
	ON
		tt.[ProjectID] = pt.[ProjectID]
	ORDER BY
		pt.[ProjectTypeID] ASC

	--MONTH HOLYDAYS TABLE
	SELECT TOP(1)
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=1) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=1)
			ELSE 1
		END AS [Day1],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=2) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=2)
			ELSE 1
		END AS [Day2],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=3) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=3)
			ELSE 1
		END AS [Day3],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=4) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=4)
			ELSE 1
		END AS [Day4],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=5) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=5)
			ELSE 1
		END AS [Day5],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=6) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=6)
			ELSE 1
		END AS [Day6],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=7) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=7)
			ELSE 1
		END AS [Day7],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=8) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=8)
			ELSE 1
		END AS [Day8],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=9) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=9)
			ELSE 1
		END AS [Day9],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=10) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=10)
			ELSE 1
		END AS [Day10],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=11) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=11)
			ELSE 1
		END AS [Day11],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=12) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=12)
			ELSE 1
		END AS [Day12],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=13) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=13)
			ELSE 1
		END AS [Day13],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=14) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=14)
			ELSE 1
		END AS [Day14],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=15) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=15)
			ELSE 1
		END AS [Day15],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=16) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=16)
			ELSE 1
		END AS [Day16],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=17) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=17)
			ELSE 1
		END AS [Day17],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=18) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=18)
			ELSE 1
		END AS [Day18],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=19) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=19)
			ELSE 1
		END AS [Day19],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=20) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=20)
			ELSE 1
		END AS [Day20],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=21) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=21)
			ELSE 1
		END AS [Day21],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=22) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=22)
			ELSE 1
		END AS [Day22],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=23) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=23)
			ELSE 1
		END AS [Day23],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=24) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=24)
			ELSE 1
		END AS [Day24],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=25) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=25)
			ELSE 1
		END AS [Day25],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=26) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=26)
			ELSE 1
		END AS [Day26],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=27) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=27)
			ELSE 1
		END AS [Day27],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=28) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=28)
			ELSE 1
		END AS [Day28],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=29) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=29)
			ELSE 1
		END AS [Day29],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=30) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=30)
			ELSE 1
		END AS [Day30],
		CASE
			WHEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=31) IS NOT NULL THEN (SELECT [IsHoliday] FROM @MonthTable WHERE [DayOfMonth]=31)
			ELSE 1
		END AS [Day31]
	FROM
		@MonthTable

	--MONTH DATE TABLE
	SELECT TOP(1)
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=1) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=1)
			ELSE NULL
		END AS [Day1],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=2) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=2)
			ELSE NULL
		END AS [Day2],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=3) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=3)
			ELSE NULL
		END AS [Day3],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=4) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=4)
			ELSE NULL
		END AS [Day4],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=5) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=5)
			ELSE NULL
		END AS [Day5],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=6) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=6)
			ELSE NULL
		END AS [Day6],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=7) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=7)
			ELSE NULL
		END AS [Day7],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=8) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=8)
			ELSE NULL
		END AS [Day8],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=9) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=9)
			ELSE NULL
		END AS [Day9],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=10) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=10)
			ELSE NULL
		END AS [Day10],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=11) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=11)
			ELSE NULL
		END AS [Day11],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=12) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=12)
			ELSE NULL
		END AS [Day12],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=13) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=13)
			ELSE NULL
		END AS [Day13],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=14) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=14)
			ELSE NULL
		END AS [Day14],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=15) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=15)
			ELSE NULL
		END AS [Day15],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=16) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=16)
			ELSE NULL
		END AS [Day16],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=17) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=17)
			ELSE NULL
		END AS [Day17],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=18) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=18)
			ELSE NULL
		END AS [Day18],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=19) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=19)
			ELSE NULL
		END AS [Day19],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=20) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=20)
			ELSE NULL
		END AS [Day20],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=21) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=21)
			ELSE NULL
		END AS [Day21],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=22) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=22)
			ELSE NULL
		END AS [Day22],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=23) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=23)
			ELSE NULL
		END AS [Day23],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=24) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=24)
			ELSE NULL
		END AS [Day24],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=25) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=25)
			ELSE NULL
		END AS [Day25],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=26) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=26)
			ELSE NULL
		END AS [Day26],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=27) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=27)
			ELSE NULL
		END AS [Day27],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=28) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=28)
			ELSE NULL
		END AS [Day28],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=29) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=29)
			ELSE NULL
		END AS [Day29],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=30) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=30)
			ELSE NULL
		END AS [Day30],
		CASE
			WHEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=31) IS NOT NULL THEN (SELECT [Date] FROM @MonthTable WHERE [DayOfMonth]=31)
			ELSE NULL
		END AS [Day31]
	FROM
		@MonthTable

	SET DATEFIRST @FirstDayOfWeek
RETURN 0
GO

GRANT EXEC ON ReportFMEL TO PUBLIC

GO

