IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportMovementOfFinancialDocuments')
	BEGIN
		PRINT 'Dropping Procedure ReportMovementOfFinancialDocuments'
		DROP  Procedure  ReportMovementOfFinancialDocuments
	END
GO
PRINT 'Creating Procedure ReportMovementOfFinancialDocuments'
GO

/******************************************************************************
**		File: ReportMovementOfFinancialDocuments.sql
**		Name: ReportMovementOfFinancialDocuments /   
**				
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 14/10/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		14.10.2010	MAN				First Version
*******************************************************************************/
CREATE PROCEDURE ReportMovementOfFinancialDocuments
	@CompanyID				TIdentifier, -- 
	@CostCenterSelector     TIdentifier,
	@CostCenterID			TIdentifier, --  
	@ProjectManagerID		TIdentifier, -- 
	@ProjectID				TIdentifier, -- 
	@DateTypeSelector		TIdentifier, --  :  
	@PeriodStart			TDateTime,	 --  : 
	@PeriodEnd				TDateTime	 --  : 
AS
	SET NOCOUNT ON

--  
IF  dbo.adfHasAccessRightByName('ViewMovementOfFinancilaDocuments') = 0 
BEGIN
	  RAISERROR('#NotEnoughPermissions', 18, -1)
	  RETURN 1
END

DECLARE
	@ProjectXML		  XML,    --   
	@PeriodName		  TName,  --  
	@CalculationClass TClass, --  
	@StatementClass	  TClass, --  
	@InvoiceClass	  TClass, --  
	@TimeEntryClass	  TClass, --  
	@ExpenseClass	  TClass,  --  	
	@NationalCurrency TCode
SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation') 
SET	@StatementClass	  = dbo.adfGetClassByName('Pjm5.Statement')
SET	@InvoiceClass	  = dbo.adfGetClassByName('Pjm5.Invoice')
SET	@TimeEntryClass	  = dbo.adfGetClassByName('Pjm5.TimeEntry')
SET	@ExpenseClass	  = dbo.adfGetClassByName('Pjm5.Expense')
SET @NationalCurrency = dbo.fnPjm5GetNationalCurrency()

--
DECLARE @Calculation TABLE ( ID TIdentifier )
-- 
DECLARE @Statement TABLE ( ID TIdentifier )
-- 
DECLARE @Invoice TABLE ( ID TIdentifier )
--     
DECLARE @CalculationStatement  TABLE (	CalculationID TIdentifier, 	StatementID	TIdentifier )
--    
DECLARE @CalculationInvoice TABLE ( CalculationID TIdentifier, InvoiceID  TIdentifier )
--    
DECLARE @StatementInvoice TABLE ( StatementID TIdentifier, InvoiceID	TIdentifier )
--     .     
DECLARE @DocumentGroup TABLE( DocumentClass TIdentifier, DocumentID TIdentifier, GroupID TIdentifier )
--       .
DECLARE @Matrix TABLE(GroupID TIdentifier, CalculationID TIdentifier, StatementID	TIdentifier, InvoiceID TIdentifier)
--  
DECLARE @AvailableProjects TABLE (ProjectID TIdentifier)
-- 
EXEC ReportGetPeriod 
	@DateTypeSelector,		--   
	0,
	@PeriodStart OUTPUT,	--  
	@PeriodEnd	 OUTPUT,	--  
	@PeriodName  OUTPUT		--  
	
--   
EXEC ReportMovementOfFinancialDocumentsHeader
	  @CompanyID, -- 
	  @CostCenterID, --  
	  @ProjectManagerID,  --  
	  @ProjectID, -- 
	  @PeriodName --  
	  
IF @CostCenterSelector = 0
	SET @CostCenterID = -1
	
INSERT INTO @AvailableProjects( ProjectID )
SELECT
	[ProjectID]
FROM
	fnReportGetAvailableProjects 
	(
		@CompanyID,		   -- 
		@CostCenterID,	   --  
		@ProjectManagerID, --  
		@ProjectID,		   -- 
		@PeriodStart,	   --  			
		@PeriodEnd,		   --  
		0, --   
		0 -- 
	)	
--       
--         . .
INSERT INTO @DocumentGroup(DocumentClass, DocumentID, GroupID)
SELECT
	@CalculationClass,
	[Calculation].[ID],
	CASE [Calculation].[State]
		WHEN 1 THEN -1 -- 
		WHEN 2 THEN -2 -- 
	END
FROM
	[Calculation]
WHERE
(
	(
		[Calculation].[PeriodEnd] >= @PeriodStart
		AND
		[Calculation].[PeriodStart] <= @PeriodStart
	)
	OR
	(
		[Calculation].[PeriodEnd] > @PeriodEnd
		AND
		[Calculation].[PeriodStart] < @PeriodEnd
	)
	OR
	(
		[Calculation].[PeriodEnd] < @PeriodEnd
		AND
		[Calculation].[PeriodStart] >= @PeriodStart
	)
)
AND
[Calculation].[State] IN  ( 1,2 ) -- , 
AND
[Calculation].[ProjectID] IN
(
	SELECT
		[@AvailableProjects].[ProjectID]
	FROM
		@AvailableProjects
)

--    ,      ""
INSERT INTO @Calculation ( ID )
SELECT
	[Calculation].[ID]
FROM
	[Calculation]
WHERE
(	
	--   
	(
		[Calculation].[PeriodEnd] >= @PeriodStart
		AND
		[Calculation].[PeriodStart] <= @PeriodStart
	)
	OR
	(
		[Calculation].[PeriodEnd] > @PeriodEnd
		AND
		[Calculation].[PeriodStart] < @PeriodEnd
	)
	OR
	(
		[Calculation].[PeriodEnd] < @PeriodEnd
		AND
		[Calculation].[PeriodStart] >= @PeriodStart
	)
)
AND
[Calculation].[State] = 3 --  
AND
--    
[Calculation].[ProjectID] IN
(
	SELECT
		[@AvailableProjects].[ProjectID]
	FROM
		@AvailableProjects
)
--    -   
INSERT INTO @CalculationStatement  ( CalculationID, StatementID )
SELECT DISTINCT
	[@Calculation].[ID],
	[StatementLine].[StatementID]
FROM
	[StatementLine]
	INNER JOIN @Calculation 
		ON [@Calculation].[ID] = [StatementLine].[DocumentID] AND [StatementLine].[DocumentClass] = @CalculationClass
WHERE
	[StatementLine].[StatementID] IN
	(
		SELECT
			[Statement].[ID]
		FROM
			[Statement]
		WHERE
			[Statement].[ID] = [StatementLine].[StatementID]
			AND
			[Statement].[State] IN (1,2,3) -- ,  
	)
--      
INSERT INTO @Statement( ID )
SELECT DISTINCT
	[@CalculationStatement ].[StatementID]
FROM
	@CalculationStatement 
--    - 
INSERT INTO @CalculationInvoice( CalculationID, InvoiceID )
SELECT DISTINCT
	[@Calculation].[ID],
	[InvoiceLine].[InvoiceID]
FROM
	[InvoiceLine]
	INNER JOIN @Calculation 
		ON [@Calculation].[ID] = [InvoiceLine].[DocumentID] AND [InvoiceLine].[DocumentClass] = @CalculationClass
WHERE
	[InvoiceLine].[InvoiceID] IN
	(
		SELECT
			[Invoice].[ID]
		FROM
			[Invoice]
		WHERE
			[Invoice].[ID] = [InvoiceLine].[InvoiceID]
			AND
			[Invoice].[State] IN (1,2,4,5,6,7) -- ,  
	)
--      
INSERT INTO @Invoice ( ID )
SELECT DISTINCT
	[@CalculationInvoice].[InvoiceID]
FROM
	@CalculationInvoice
	
--    - 
INSERT INTO @StatementInvoice ( StatementID, InvoiceID )
SELECT
	[Attachment].[DocumentID],
	[@Invoice].[ID]
FROM
	[Attachment]
	INNER JOIN @Invoice 
		ON [Attachment].[LinkDocumentID] = [@Invoice].[ID] AND [Attachment].[LinkDocumentClass] = @InvoiceClass
WHERE
	[Attachment].[DocumentClass] = @StatementClass
	AND
	[Attachment].[DocumentID] IN --
	(
		SELECT
			[Statement].[ID]
		FROM
			[Statement]
		WHERE
			[Statement].[ID] = [Attachment].[DocumentID]
			AND
			[Statement].[State] IN (1,2,3) -- ,  
	)
UNION
SELECT
	[StatementAdvanceInvoice].[StatementID],
	[StatementAdvanceInvoice].[AdvanceInvoiceID]
FROM
	[StatementAdvanceInvoice]
WHERE
	[StatementAdvanceInvoice].[AdvanceInvoiceID] IN
	(
		SELECT
			[@Invoice].[ID]
		FROM
			@Invoice 
	)
	AND
	[StatementAdvanceInvoice].[AdvanceInvoiceID] NOT IN
	(
		SELECT 
			[@StatementInvoice].[InvoiceID]
		FROM 
			@StatementInvoice
	)
--      
INSERT INTO @Statement (ID)
SELECT DISTINCT
	[@StatementInvoice].[StatementID]
FROM
	@StatementInvoice
--    - 
INSERT INTO @StatementInvoice ( StatementID, InvoiceID )
SELECT DISTINCT
	[@Statement].[ID],
	[Attachment].[DocumentID]
FROM
	[Attachment]
	INNER JOIN @Statement
		ON [Attachment].[LinkDocumentID] = [@Statement].[ID] AND [Attachment].[LinkDocumentClass] = @StatementClass
WHERE
	[Attachment].[DocumentClass] = @InvoiceClass
	AND
	[Attachment].[DocumentID] IN
	(
		SELECT
			[Invoice].[ID]
		FROM
			[Invoice]
		WHERE
			[Invoice].[ID] = [Attachment].[DocumentID]
			AND
			[Invoice].[State] IN (1,2,4,5,6,7) -- ,  
	)
UNION
--  
SELECT
	[StatementAdvanceInvoice].[StatementID],
	[StatementAdvanceInvoice].[AdvanceInvoiceID]
FROM
	[StatementAdvanceInvoice]
WHERE
	[StatementAdvanceInvoice].[StatementID] IN
	(
		SELECT
			[@Statement].[ID]
		FROM
			@Statement
	)
	AND
	[StatementAdvanceInvoice].[AdvanceInvoiceID] NOT IN
	(
		SELECT 
			[@StatementInvoice].[InvoiceID]
		FROM 
			@StatementInvoice
	)

--      
INSERT INTO @Invoice (ID)
SELECT DISTINCT
	[@StatementInvoice].[InvoiceID]
FROM
	@StatementInvoice
	
--   . 
DECLARE 
	@GroupID TIdentifier,
	@StatementID TIdentifier
SET @GroupID = 0

--    
DECLARE statement_cursor CURSOR
	FOR SELECT DISTINCT [@Statement].[ID] FROM @Statement
--       
OPEN statement_cursor
FETCH NEXT FROM statement_cursor INTO @StatementID

WHILE @@FETCH_STATUS = 0
BEGIN
	--  
	SET @GroupID = @GroupID + 1
	--   DG 
	INSERT INTO	@DocumentGroup( DocumentClass, DocumentID, GroupID )
	SELECT
		@StatementClass,
		@StatementID,
		@GroupID
	--   DG     
	INSERT INTO @DocumentGroup( DocumentClass, DocumentID, GroupID )
	SELECT
		@CalculationClass,
		[@CalculationStatement ].[CalculationID],
		@GroupID
	FROM
		@CalculationStatement 
	WHERE
		[@CalculationStatement ].[StatementID] = @StatementID
	--   DG    
	INSERT INTO @DocumentGroup( DocumentClass, DocumentID, GroupID )
	SELECT
		@InvoiceClass,
		[@StatementInvoice].[InvoiceID],
		@GroupID
	FROM
		@StatementInvoice
	WHERE
		[@StatementInvoice].[StatementID] = @StatementID
	FETCH NEXT FROM statement_cursor INTO @StatementID
END
CLOSE statement_cursor
DEALLOCATE statement_cursor

--        ,      DG		
DELETE FROM @CalculationInvoice
WHERE 
	[@CalculationInvoice].[InvoiceID] IN
	(
		SELECT
			[@DocumentGroup].[DocumentID]
		FROM
			@DocumentGroup
		WHERE
			[@DocumentGroup].[DocumentClass] = @InvoiceClass
	)
--    .      
DECLARE
	@InvoiceID TIdentifier
--    
DECLARE invoice_cursor CURSOR
	FOR SELECT DISTINCT [@CalculationInvoice].[InvoiceID] FROM @CalculationInvoice
--       		
OPEN invoice_cursor
FETCH NEXT FROM invoice_cursor INTO @InvoiceID
WHILE @@FETCH_STATUS = 0
BEGIN
	--   
	SET @GroupID = @GroupID + 1
	--   DG 
	INSERT INTO	@DocumentGroup( DocumentClass, DocumentID, GroupID )
	SELECT
		@InvoiceClass,
		@InvoiceID,
		@GroupID
	--    DG   
	INSERT INTO @DocumentGroup( DocumentClass, DocumentID, GroupID )
	SELECT
		@CalculationClass,
		[@CalculationInvoice].[CalculationID],
		@GroupID
	FROM
		@CalculationInvoice
	WHERE
		[@CalculationInvoice].[InvoiceID] = @InvoiceID
	--  
	FETCH NEXT FROM invoice_cursor INTO @InvoiceID
END
CLOSE invoice_cursor
DEALLOCATE invoice_cursor

DECLARE
	@NMax TAmount,
	@CalculationCount TAmount,
	@InvoiceCount TAmount,
	@Counter TAmount
--    
DECLARE group_cursor CURSOR
	FOR SELECT DISTINCT [@DocumentGroup].[GroupID] FROM @DocumentGroup
--       		
OPEN group_cursor
FETCH NEXT FROM group_cursor INTO @GroupID
WHILE @@FETCH_STATUS = 0
BEGIN
		SET @Counter = 0
		--      
		SET @CalculationCount =
		(
			SELECT 
				 COUNT(DISTINCT [@DocumentGroup].[DocumentID])
			FROM
				@DocumentGroup
			WHERE
				[@DocumentGroup].[GroupID] = @GroupID
				AND
				[@DocumentGroup].[DocumentClass] = @CalculationClass
		)
		--      
		SET @InvoiceCount =
		(
			SELECT  
				 COUNT(DISTINCT [@DocumentGroup].[DocumentID])
			FROM
				@DocumentGroup
			WHERE
				[@DocumentGroup].[GroupID] = @GroupID
				AND
				[@DocumentGroup].[DocumentClass] = @InvoiceClass
		)
	--        . 
	--     .     0  1.
	IF ISNULL(@CalculationCount,0) < ISNULL(@InvoiceCount,0)
		SET @NMax =  @InvoiceCount
	ELSE
		SET @Nmax = @CalculationCount
	--         	
	WHILE(@Counter < @NMax)
	BEGIN
		--       
		INSERT INTO @Matrix ( GroupID, CalculationID, StatementID, InvoiceID )
		SELECT 
			@GroupID,
			(	
				-- 
				SELECT TOP(1)
					[@DocumentGroup].[DocumentID]
				FROM
					@DocumentGroup
				WHERE
					[@DocumentGroup].[GroupID] = @GroupID
					AND
					[@DocumentGroup].[DocumentClass] = @CalculationClass
					AND
					[@DocumentGroup].[DocumentID] NOT IN
					(
						SELECT
							[@Matrix].[CalculationID]
						FROM
							@Matrix
						WHERE
							[@Matrix].[GroupID] = @GroupID
					)
			)
			,
			(
				-- 
				SELECT TOP(1)
					[@DocumentGroup].[DocumentID]
				FROM
					@DocumentGroup
				WHERE
					[@DocumentGroup].[GroupID] = @GroupID
					AND
					[@DocumentGroup].[DocumentClass] = @StatementClass
					AND
					[@DocumentGroup].[DocumentID] NOT IN
					(
						SELECT
							[@Matrix].[StatementID]
						FROM
							@Matrix
						WHERE
							[@Matrix].[GroupID] = @GroupID
					)
			)
			,
			(
				-- 
				SELECT TOP(1)
					[@DocumentGroup].[DocumentID]
				FROM
					@DocumentGroup
				WHERE
					[@DocumentGroup].[GroupID] = @GroupID
					AND
					[@DocumentGroup].[DocumentClass] = @InvoiceClass
					AND
					[@DocumentGroup].[DocumentID] NOT IN
					(
						SELECT
							[@Matrix].[InvoiceID]
						FROM
							@Matrix
						WHERE
							[@Matrix].[GroupID] = @GroupID
					)
			)
			SET @Counter = @Counter + 1
		END
	FETCH NEXT FROM group_cursor INTO @GroupID
END
CLOSE group_cursor
DEALLOCATE group_cursor

--   ------------------------------------------------------
	;WITH [AdvanceInvoices] ([InvoiceID], [AdvanceValue]) AS
	(
		SELECT
			[AdvanceInvoice].[InvoiceID],
			SUM([Invoice].[TotalWithVAT])
		FROM
			[AdvanceInvoice]
			INNER JOIN [Invoice]
				ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		GROUP BY
			[AdvanceInvoice].[InvoiceID]
	)
SELECT
	[@Matrix].[GroupID] AS [GroupID], -- 
	--------  --------------
	[Project].[Number] AS [ProjectNumber],	--  
	[Project].[FileAs] AS [ProjectFileAs],  --  
	[Currency].[FileAs] AS [ProjectCurrency], --  
	--------  ----------
	[Calculation].[Date] AS [CalculationDate], --  : 
	[Calculation].[Number] AS [CalculationNumber], --  : 
	dbo.adfGetClassName( [Calculation].[DocumentClass]) AS [CalculationClass], --  : 
	[Calculation].[PeriodStart] AS [CalculationPeriodStart],
	[Calculation].[PeriodEnd] AS [CalculationPeriodEnd],
	[Calculation].[State] AS [CalculationState],
	(
		ISNULL
			(
				(
					SELECT
						SUM
						(
							CASE
								WHEN [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 1 
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] / ( 1 + [vwTimeEntry].[VATRate] )
								WHEN
									( [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 0  )
									OR
									( [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 1  )
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate]
								WHEN [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 0 
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] * ( 1 + [vwTimeEntry].[VATRate] )
							END
						)
					FROM
						[vwTimeEntry]
						INNER JOIN [Project] ON [vwTimeEntry].[ProjectID] = [Project].[ID]
					WHERE
						[vwTimeEntry].[StartTime] > @PeriodStart
						AND
						[vwTimeEntry].[StartTime] < @PeriodEnd
						AND
						[vwTimeEntry].[ID] IN
						(
							SELECT
								[CalculationLine].[DocumentID]
							FROM
								[CalculationLine]
							WHERE
								[CalculationLine].[CalculationID] = [Calculation].[ID]
								AND
								[CalculationLine].[DocumentClass] =  @TimeEntryClass
						)
			),0)
			+
			ISNULL
			(
				(
					SELECT
						SUM
						(		
							CASE 
								WHEN [Project].[ApplyVat] = 0
									THEN  [Expense].[TotalPC]
								ELSE
									[Expense].[TotalWithVATPC]						
							END	
						)
					FROM
						[Expense]
						INNER JOIN [Project] ON [Expense].[ProjectID] = [Project].[ID]
					WHERE
						[Expense].[Date] >= @PeriodStart 
						AND 
						[Expense].[Date] < @PeriodEnd --  
						AND
						[Expense].[ID] IN
						(
							SELECT
								[CalculationLine].[DocumentID]
							FROM
								[CalculationLine]
							WHERE
								[CalculationLine].[CalculationID] = [Calculation].[ID]
								AND
								[CalculationLine].[DocumentClass] =  @ExpenseClass
						)
				),0)
			
	)	AS [CalculationTotalPeriod], --  :   
	[Calculation].[TotalWithVATPC] AS [CalculationTotal],	--  :  
	(
		CASE [Calculation].[State]
			WHEN 1 THEN 
			ISNULL
			(
				(
					SELECT
						SUM
						(
							CASE
								WHEN [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 1 
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] / ( 1 + [vwTimeEntry].[VATRate] )
								WHEN
									( [Project].[ApplyVAT] = 0 AND [Project].[RatesWithVAT] = 0  )
									OR
									( [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 1  )
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate]
								WHEN [Project].[ApplyVAT] = 1 AND [Project].[RatesWithVAT] = 0 
									THEN [vwTimeEntry].[BillableHour] * [vwTimeEntry].[Rate] * ( 1 + [vwTimeEntry].[VATRate] )
							END
						)
					FROM
						[vwTimeEntry]
						INNER JOIN [Project] ON [vwTimeEntry].[ProjectID] = [Project].[ID]
					WHERE
						[vwTimeEntry].[StartTime] > @PeriodStart
						AND
						[vwTimeEntry].[StartTime] < @PeriodEnd
						AND
						[vwTimeEntry].[ID] IN
						(
							SELECT
								[CalculationLine].[DocumentID]
							FROM
								[CalculationLine]
							WHERE
								[CalculationLine].[CalculationID] = [Calculation].[ID]
								AND
								[CalculationLine].[DocumentClass] =  @TimeEntryClass
						)
			),0)
			+
			ISNULL
			(
				(
					SELECT
						SUM
						(		
							CASE 
								WHEN [Project].[ApplyVat] = 0
									THEN  [Expense].[TotalPC]
								ELSE
									[Expense].[TotalWithVATPC]						
							END	
						)
					FROM
						[Expense]
						INNER JOIN [Project] ON [Expense].[ProjectID] = [Project].[ID]
					WHERE
						[Expense].[Date] >= @PeriodStart 
						AND 
						[Expense].[Date] < @PeriodEnd --  
						AND
						[Expense].[ID] IN
						(
							SELECT
								[CalculationLine].[DocumentID]
							FROM
								[CalculationLine]
							WHERE
								[CalculationLine].[CalculationID] = [Calculation].[ID]
								AND
								[CalculationLine].[DocumentClass] =  @ExpenseClass
						)
				),0)
		END
	) AS [CalculationTotalPeriodDraft],	--  : 
	(
		CASE [Calculation].[State]
			WHEN 1 THEN [Calculation].[TotalWithVATPC]	
			ELSE 0
		END
	) AS [CalculationTotalDraft], --  :    
	----  --------
	[Statement].[Date] AS [StatementDate], --  : 
	[Statement].[Number] AS [StatementNumber], --  : 
	[Statement].[State] AS [StatementState], --  : 
	[Statement].[TotalWithVATPC] AS [StatementTotal], --  : 
	(
		CASE [Statement].[State]
			WHEN 1 THEN [Statement].[TotalWithVATPC]
			ELSE 0
		END
	) AS [StatementTotalDraft], --  
	---  -------------
	[Invoice].[Date] AS [InvoiceDate],			-- 
	[Invoice].[Number] AS [InvoiceNumber],			-- 
	[Invoice].[State]  AS [InvoiceState],			-- 
	(
		CASE [Invoice].[Advance]											-->(!)	
			WHEN 1 THEN (
							SELECT [StatementPaymentValuePC] 
							FROM [StatementAdvanceInvoice] 
							WHERE [AdvanceInvoiceID] = [Invoice].[ID] 
							AND [StatementID] = [Statement].[ID]
						)										--[Statement].[TotalWithVATPC]
			ELSE [Invoice].[TotalWithVATPC] 	
		END
	) AS [InvoiceTotal] , --   
	
	(
		CASE [Invoice].[State]
			WHEN 1 THEN 
				CASE [Invoice].[Advance]									-->(!)
					WHEN 1 THEN 
					(
						SELECT [StatementPaymentValuePC] 
						FROM [StatementAdvanceInvoice] 
						WHERE [AdvanceInvoiceID] = [Invoice].[ID]
						AND [StatementID] = [Statement].[ID]
					)											--[Statement].[TotalWithVATPC]
					ELSE [Invoice].[TotalWithVATPC] 	
				END
		END
	) AS [InvoiceTotalDraft], --  
	
		CASE 
			WHEN [Invoice].[Advance] = 1		--  ,    
				THEN 0
			WHEN
				[Invoice].[CurrencyCode] = @nationalCurrency
				THEN
					CASE [Invoice].[Advance]
						WHEN 1 THEN [Statement].[TotalWithVATPC]
						ELSE [Invoice].[TotalWithVATPC] 	
					END - 
					ISNULL([pjm5vwInvoicePayment].[PaymentValue] / [Invoice].[CurrencyRate], 0) -
					ISNULL([AdvanceInvoices].[AdvanceValue] / [Invoice].[CurrencyRate], 0)
			WHEN
				[Invoice].[CurrencyCode] = [Project].[CurrencyCode]
				THEN
					CASE [Invoice].[Advance]
						WHEN 1 THEN [Statement].[TotalWithVATPC]
						ELSE [Invoice].[TotalWithVATPC] 	
					END - 
					ISNULL([pjm5vwInvoicePayment].[PaymentValue] , 0) -
					ISNULL([AdvanceInvoices].[AdvanceValue], 0)
			ELSE
				CASE [Invoice].[Advance]
					WHEN 1 THEN [Statement].[TotalWithVATPC]
					ELSE [Invoice].[TotalWithVATPC] 	
				END - 
				ISNULL([pjm5vwInvoicePayment].[PaymentValue] * [Invoice].[CurrencyRate], 0) -
				ISNULL([AdvanceInvoices].[AdvanceValue] * [Invoice].[CurrencyRate], 0)
		END
		 AS [InvoiceTotalToPayment],
	(
		CASE [Invoice].[State]
			WHEN 1 THEN 
				(
					CASE 
			WHEN
				[Invoice].[CurrencyCode] = @nationalCurrency
				THEN
					CASE [Invoice].[Advance]
						WHEN 1 THEN [Statement].[TotalWithVATPC]
						ELSE [Invoice].[TotalWithVATPC] 	
					END - 
					ISNULL([pjm5vwInvoicePayment].[PaymentValue] / [Invoice].[CurrencyRate], 0) -
					ISNULL([AdvanceInvoices].[AdvanceValue] / [Invoice].[CurrencyRate], 0)
			WHEN
				[Invoice].[CurrencyCode] = [Project].[CurrencyCode]
				THEN
					CASE [Invoice].[Advance]
						WHEN 1 THEN [Statement].[TotalWithVATPC]
						ELSE [Invoice].[TotalWithVATPC] 	
					END - 
					ISNULL([pjm5vwInvoicePayment].[PaymentValue] , 0) -
					ISNULL([AdvanceInvoices].[AdvanceValue], 0)
			ELSE
				CASE [Invoice].[Advance]
					WHEN 1 THEN [Statement].[TotalWithVATPC]
					ELSE [Invoice].[TotalWithVATPC] 	
				END - 
				ISNULL([pjm5vwInvoicePayment].[PaymentValue] * [Invoice].[CurrencyRate], 0) -
				ISNULL([AdvanceInvoices].[AdvanceValue] * [Invoice].[CurrencyRate], 0)
		END
				)
		END
	) AS [InvoiceTotalToPaymentDraft] --   
FROM
	@Matrix
	LEFT OUTER JOIN [Calculation]
		ON [Calculation].[ID] = [@Matrix].[CalculationID]
	LEFT OUTER JOIN [Statement]
		ON [Statement].[ID] = [@Matrix].[StatementID]
	LEFT OUTER JOIN [Invoice]
		ON [Invoice].[ID] = [@Matrix].[InvoiceID]
	INNER JOIN [Project]
		ON [Project].[ID] = ISNULL([Calculation].[ProjectID],[Invoice].[ProjectID])
	INNER JOIN [Currency]
		ON [Currency].[Code] = [Project].[CurrencyCode]
	LEFT OUTER JOIN [pjm5vwInvoicePayment]
		ON [pjm5vwInvoicePayment].[InvoiceID] = [Invoice].[ID]
	LEFT OUTER JOIN [AdvanceInvoices]
		ON [AdvanceInvoices].[InvoiceID] = [Invoice].[ID]


		
RETURN 0
GO
GRANT EXEC ON ReportMovementOfFinancialDocuments TO PUBLIC
GO