IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectUtilization')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectUtilization'
		DROP  Procedure  ReportProjectUtilization
	END

GO

PRINT 'Creating Procedure ReportProjectUtilization'
GO

SET QUOTED_IDENTIFIER ON
GO
--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/

CREATE Procedure ReportProjectUtilization
	@StartDate		TDateTime,
	@EndDate		TDateTime,
	@DateSelector	int,
	@ProjectID		TIdentifier,
	@ProjectType	int,
	@CompanyID		TIdentifier,
	@DivisionSelector int,
	@DivisionID		TIdentifier,
	@EmployeeSelector int,
	@EmployeeXml	xml,
	@VocationSelector  int
AS
	SET NOCOUNT ON
	DECLARE	@employees TABLE ([ID] int, [FileAs] TName, [QualificationID] TIdentifier)
	IF(@ProjectID IS NULL)
		INSERT INTO @employees
			SELECT
				[Employee].[ID],
				[Employee].[FileAs],
				[Employee].[QualificationID]
			FROM
				[Employee]
					INNER JOIN [Company]
						ON [Employee].[CompanyID] = [Company].[ID]
							AND [Company].[Own] = 1
				LEFT OUTER JOIN
					@EmployeeXml.nodes('/Employees/ID') T(c)
						ON T.c.value('.[1]', 'int') = [Employee].[ID]
			WHERE
				([Employee].[CompanyID] = @CompanyID OR @CompanyID IS NULL)
				AND
				(
					@DivisionSelector = 0 OR 
					(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
					(@DivisionSelector = 2 AND ([Employee].[DivisionID] = @DivisionID 
						OR (@DivisionID IS NULL AND [Employee].[DivisionID] IS NOT NULL)))
				)
				AND (
					@EmployeeSelector = 0 
					OR @EmployeeSelector = 1 AND T.c.value('.[1]', 'int') IS NOT NULL
					OR @EmployeeSelector = 2 AND T.c.value('.[1]', 'int') IS NULL)
	ELSE
		INSERT INTO @employees
			SELECT
				[Employee].[ID],
				[Employee].[FileAs],
				[Assignment].[QualificationID]
			FROM
				[Project]
					INNER JOIN [vwAssignment] as [Assignment]
						ON [Assignment].[ProjectID] = [Project].[ID]
					INNER JOIN [Employee]
						ON [Assignment].[EmployeeID] = [Employee].[ID]
			WHERE 
				[Project].[ID] = @ProjectID
				AND [Assignment].[State] = 1
		
	DECLARE
		@DayCount		int,
		@TodayDate		datetime,
		@LastSymbol		char(8),
		@ProjectNumber  TName,
		@WorkTime		decimal(18,2),
		@WorkDays		TCount,
		@value			TVariant,
		@EmployeesFileAs	varchar(max),
		@Employee			TName,
		@CompanyFileAs		TName,
		@DivisionFileAs		TName,
		@ProjectFileAs		TName,
		@WorkingMinutes		decimal(18, 2),
		@Type1 int,
		@Type2 int,
		@Type3 int

	SELECT
		@Type1 = CASE WHEN @ProjectType & 1 = 0 THEN NULL ELSE 1 END,
		@Type2 = CASE WHEN @ProjectType & 2 = 0 THEN NULL ELSE 2 END,
		@Type3 = CASE WHEN @ProjectType & 4 = 0 THEN NULL ELSE 3 END
	
	SET @TodayDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)	
	SET @DayCount = DATEPART(day, GETDATE())
	SET @Startdate = CASE	@DateSelector
		WHEN 0 THEN CAST(CONVERT(varchar(8), DATEADD(day, 1-@DayCount, GETDATE()), 112) AS datetime)
		WHEN 1 THEN CAST(CONVERT(varchar(8), DATEADD(month, -1, DATEADD(day, 1-@DayCount, GETDATE())), 112) AS datetime)
		ELSE CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime)
	END
	SET @EndDate = CASE @DateSelector
		WHEN 0 THEN @TodayDate
		WHEN 1 THEN DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		ELSE CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime)
	END	

	SET @WorkDays = dbo.fnPjm5GetWorkingDays(@StartDate, @EndDate)
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkingMinutes = CAST(@value AS decimal(18,2))

	SET @WorkTime = @WorkingMinutes * @WorkDays
	
	SELECT
		@ProjectNumber = [Project].[Number],
		@ProjectFileAs = [Project].[FileAs]
	FROM
		[Project]
	WHERE
		[Project].[ID] = @ProjectID		
	
	SET @DivisionFileAs = CASE @DivisionSelector
         WHEN 0 THEN '()'
         WHEN 1 THEN ' '
         WHEN 2 THEN '()'
    END

	SELECT
		@CompanyFileAs = [Company].[FileAs]
	FROM
		[Company]
	WHERE
		[Company].[ID] = @CompanyID

	SELECT
		@DivisionFileAs = [Division].[FileAs]
	FROM
		[Division]
	WHERE
		[Division].[ID] = @DivisionID

	IF @EmployeeSelector = 0
		SET @EmployeesFileAs = '()'
	ELSE
	BEGIN
		IF @EmployeeSelector = 2
		BEGIN
			SET  @EmployeesFileAs = ', : '
			DECLARE employees CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
			SELECT 
				[Employee].[FileAs]
			FROM
				[Employee]
					INNER JOIN @EmployeeXml.nodes('/Employees/ID') T(c)
						ON T.c.value('.[1]', 'int') = [Employee].[ID]
			ORDER BY [FileAs] ASC
		END
		ELSE
		BEGIN
			DECLARE employees CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
				SELECT 
					[FileAs]
				FROM 
					@employees
				ORDER BY [FileAs] ASC
		END		
		OPEN employees
		FETCH NEXT FROM employees INTO @Employee
		WHILE @@FETCH_STATUS = 0
		BEGIN
			SET @EmployeesFileAs = ISNULL(@EmployeesFileAs,'') + @Employee + '; '
			FETCH NEXT FROM employees INTO @Employee
		END
		CLOSE employees
		DEALLOCATE employees
		SET @EmployeesFileAs = LEFT(@EmployeesFileAs, LEN(@EmployeesFileAs) - 1)
	END
    
	;
	WITH TimeEntryTemp ([EmployeeID], [Duration], 
						[BillableDuration], [UnbillableDuration], [VocationDuration]) as
	(
		SELECT
			[TimeEntry].[EmployeeID],
			SUM(ISNULL([Time].[Duration], 0)),
			SUM(ISNULL([BillableTime].[Duration], 0)),
			SUM(ISNULL([UnbillableTime].[Duration], 0)),
			CASE 
				WHEN @VocationSelector = 1 
				THEN SUM(ISNULL([Vocation].[Duration], 0))
				ELSE 0 END
		FROM
			@employees as [Employee]
				LEFT OUTER JOIN [Qualification]
					ON [Qualification].[ID] = [Employee].[QualificationID]
				INNER JOIN [TimeEntry] 
					ON [Employee].[ID] = [TimeEntry].[EmployeeID]
				INNER JOIN[Project]
					ON [Project].[ID] = [TimeEntry].[ProjectID]
				LEFT OUTER JOIN [TimeEntry] as [Time]
					ON [TimeEntry].[ID] = [Time].[ID]
						AND [Project].[ProjectTypeID] IN (@Type1, @Type2, @Type3) 
						AND ([TimeEntry].[ProjectID] = @ProjectID OR @ProjectID IS NULL)
				LEFT OUTER JOIN [TimeEntry] as [BillableTime]
					ON [TimeEntry].[ID] = [BillableTime].[ID]
						AND [BillableTime].[Billable] = 1
						AND [Project].[ProjectTypeID] IN (@Type1, @Type2, @Type3)
						AND ([TimeEntry].[ProjectID] = @ProjectID OR @ProjectID IS NULL)
				LEFT OUTER JOIN [TimeEntry] as [UnbillableTime]
					ON [TimeEntry].[ID] = [UnbillableTime].[ID]
						AND [UnbillableTime].[Billable] = 0
						AND [Project].[ProjectTypeID] IN (@Type1, @Type2, @Type3) 
						AND ([TimeEntry].[ProjectID] = @ProjectID OR @ProjectID IS NULL)
				LEFT OUTER JOIN [TimeEntry] as [Vocation]
					ON [TimeEntry].[ID] = [Vocation].[ID]
						AND [Project].[ProjectTypeID] = 5
		WHERE
			CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @EndDate
			AND CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) >= @StartDate
			AND [TimeEntry].[State] IN (3, 6)
			
		GROUP BY
			[TimeEntry].[EmployeeID]
	),
		BusyEntryTemp ([EmployeeID], [Planned]) as
		(SELECT
			[Employee].[ID] AS [EmployeeID],
			SUM(ISNULL([BusyEntry].[Planned],0)) as [Planned]
			FROM
				@employees as [Employee]
				INNER JOIN [vwAssignment] as [Assignment]
					ON [Assignment].[EmployeeID] = [Employee].[ID]
				INNER JOIN [Project]
					ON [Project].[ID] = [Assignment].[ProjectID]
				INNER JOIN [BusyEntry]
					ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
					AND [BusyEntry].[Date] >= @StartDate
					AND [BusyEntry].[Date] <= @EndDate
			WHERE 
				([Assignment].[ProjectID] = @ProjectID
				 OR @ProjectID IS NULL)
					AND [Project].[ProjectTypeID] IN (@Type1, @Type2, @Type3)
			GROUP BY
				[Employee].[ID]	
		)
	SELECT 
		[Employee].[FileAs] as [EmployeeFileAs],
		ISNULL([Qualification].[FileAs], '( )') as [QualificationFileAs],
		SUM(ISNULL([BusyEntry].[Planned], 0)) / 60.0 as [PlannedDuration],
		CASE WHEN (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) = 0 THEN NULL 
		ELSE SUM(ISNULL([BusyEntry].[Planned], 0)) / (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) END as [PlannedUtilization],
		SUM(ISNULL([Time].[BillableDuration], 0)) / 60.0 as [BillableDuration],
		SUM(ISNULL([Time].[UnbillableDuration], 0)) / 60.0 as [UnbillableDuration],
		SUM(ISNULL([Time].[Duration], 0)) / 60.0 as [Duration],
		CASE WHEN (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) = 0 THEN NULL 
		ELSE SUM(ISNULL([Time].[Duration], 0)) / (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) END as [DurationUtilization],
		CASE WHEN (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) = 0 THEN NULL 
		ELSE SUM(ISNULL([Time].[BillableDuration], 0)) / (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) END as [BillableUtilization],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 THEN null 
			ELSE (SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) / 60.0
			END as [Deviation],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 OR (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0)) = 0 THEN null 
			ELSE (SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) / (@WorkTime - ISNULL(SUM([Time].[VocationDuration]),0))
			END as [PercentDeviation],
		ISNULL(SUM([Time].[VocationDuration]),0) / 60.0 as [VocationDuration],
		ISNULL(SUM([Time].[VocationDuration]),0) / @WorkingMinutes as [VocationDurationDays]
	FROM
		@employees as [Employee]
			LEFT OUTER JOIN [Qualification]
				ON [Qualification].[ID] = [Employee].[QualificationID]
			LEFT OUTER JOIN [TimeEntryTemp] as [Time]
				ON [Employee].[ID] = [Time].[EmployeeID]
			LEFT OUTER JOIN BusyEntryTemp as [BusyEntry]
				ON [BusyEntry].[EmployeeID] = [Employee].[ID]
			LEFT OUTER JOIN @EmployeeXml.nodes('/Employees/ID') T(c)
						ON T.c.value('.[1]', 'int') = [Employee].[ID]
	WHERE
		[BusyEntry].[EmployeeID] IS NOT NULL
		OR [Time].[EmployeeID] IS NOT NULL
		OR (T.c.value('.[1]', 'int') IS NOT NULL AND @EmployeeSelector = 1)
	GROUP BY
		[Employee].[FileAs],
		[Qualification].[FileAs]

	SELECT
		@StartDate as [StartDate],
		@EndDate as [EndDate],
		@WorkDays as [WorkingDays],
		@WorkTime / 60.0 as [WorkingHours],
		@ProjectNumber as [ProjectName],
		@ProjectFileAs as [ProjectFileAs],
		ISNULL(@EmployeesFileAs, '( )') as [EmployeesFileAs],
		ISNULL(@CompanyFileAs, '()') AS [CompanyFileAs],
		@DivisionFileAs as [DivisionFileAs],
		CASE WHEN @VocationSelector = 0 
		THEN ' (  )'
		ELSE ' (  )'
		END as [Vocation]
			

RETURN 0
GO

GRANT EXEC ON ReportProjectUtilization TO PUBLIC

GO
