IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueAnalysisByClients')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueAnalysisByClients'
		DROP  Procedure  ReportRevenueAnalysisByClients
	END

GO

PRINT 'Creating Procedure ReportRevenueAnalysisByClients'
GO
/******************************************************************************
**		File: ReportRevenueByClient.sql
**		Name: ReportRevenueByClient
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		Auth: Pavel Svintsov			Date: 13.09.10
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		12.09.14	GNV			    
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportRevenueAnalysisByClients]
		@CompanyID_in TIdentifier,
		@CurrencySelector_in int,
		@ManagerID_in TIdentifier,
		@CompanyManagerSelector_in int,
		@CostCenterID_in TIdentifier,
		@CostCenterSelector_in int,
		@ServiceTypeID_in TIdentifier,
		@ServiceTypeSelector_in int,
		@InvoiceSelector_in int,
		@DateSelector_in int,
		@SumByCompanyGroups_in bit,		--   
		@CountSelector_in int,
		@Count_in int,
		@ScaleSelector INT
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE 
		@PeriodStart TDate,
		@PeriodEnd TDate,
		@CurrencyCode TCode3,
		@Value TVariant,
		@TotalRevenue float,
		@Rate float,
		@Prefix varchar(5),
		@ToCurrencyCode TCode3

	DECLARE
		@CompanyID TIdentifier,
		@CurrencySelector int,
		@ManagerID TIdentifier,
		@CompanyManagerSelector int,
		@CostCenterID TIdentifier,
		@CostCenterSelector int,
		@ServiceTypeID TIdentifier,
		@ServiceTypeSelector int,
		@InvoiceSelector int,
		@DateSelector int,
		@SumByCompanyGroups bit,		--   
		@CountSelector int,
		@Count int
	
	SELECT
		@CompanyID = @CompanyID_in,
		@CurrencySelector = @CurrencySelector_in,
		@ManagerID = @ManagerID_in,
		@CompanyManagerSelector = @CompanyManagerSelector_in,
		@CostCenterID = @CostCenterID_in,
		@CostCenterSelector = @CostCenterSelector_in,
		@ServiceTypeID = @ServiceTypeID_in,
		@ServiceTypeSelector = @ServiceTypeSelector_in,
		@InvoiceSelector = @InvoiceSelector_in,
		@DateSelector = @DateSelector_in,
		@SumByCompanyGroups = @SumByCompanyGroups_in,		
		@CountSelector = @CountSelector_in,
		@Count = @Count_in		

	
	DECLARE @RevenueHeader Table
	(
		CompanyName TName,
	    CurrencyCode nvarchar(32),
	    ManagerName TName,
		CostCenterSelector int,
	    CostCenterName TName,
	    ServiceTypeName TName,
	    SeriveIncludedName  TName,
	    InvoiceState TName,
	    DatePeriod TName, 
	    UserName TName,
	    [Count] TName,
		[SumByCompanyGroups] bit
	)

	INSERT INTO @RevenueHeader
	(
		CompanyName, 
	    CurrencyCode,
	    ManagerName,
		CostCenterSelector,
	    CostCenterName,
	    ServiceTypeName,
	    SeriveIncludedName,
	    InvoiceState,
	    DatePeriod, 
	    UserName,
	    [Count],
		[SumByCompanyGroups]
	)
	EXEC ReportRevenueAnalysisByClientsHeader
			@CompanyID, @CurrencySelector, @ManagerID, @CompanyManagerSelector, @CostCenterID, @CostCenterSelector, 
			@ServiceTypeID, @ServiceTypeSelector, @InvoiceSelector, @DateSelector,
			@CountSelector, @Count, @SumByCompanyGroups
	
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
	SET @CurrencyCode = CAST(@Value AS nvarchar(32))
	
	 
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
	SET @ToCurrencyCode = CAST(@Value AS nvarchar(32))
	
	
	SET @PeriodEnd = GETDATE()
	
	IF @DateSelector = 0
		SET @PeriodStart = DATEADD(year, 0, GETDATE())
	IF @DateSelector = 1
		SET @PeriodStart = DATEADD(year, -1, GETDATE())
	IF @DateSelector = 2
		SET @PeriodStart = DATEADD(year, -2, GETDATE())
	
	SET @PeriodStart = convert(char(8),dateadd(day,1-datepart(dayofyear,@PeriodStart),@PeriodStart),112)
	
	
	DECLARE @CustomerRevenue TABLE 
	(
		CompanyName TName,
		Manager TName,
	    ProjectCount int,
		ActiveProjectCount int,
	    AverageSum float,
		InvoiceCount int,
	    Debt float,
		Revenue float,
	    PayTerm int,
		Percentage float,	
		ParentCompanyID int			--ID  
	)

	INSERT INTO @CustomerRevenue 
	(	
		CompanyName,
		Manager,
	    ProjectCount, 
		ActiveProjectCount,
	    AverageSum,
		InvoiceCount,
	    Debt,
		Revenue,
	    PayTerm,
		ParentCompanyID
	)
		SELECT 
			[CustomerCompany].[FileAs] AS CompanyName,
		    (CASE  WHEN [ManagerEmployee].[FileAs] IS NOT NULL THEN [ManagerEmployee].[FileAs] ELSE '( )' END)  AS Manager,
		    COUNT(DISTINCT [Projects].[ID]) AS AllCount,
		    COUNT(DISTINCT CASE Projects.[State] WHEN 2 THEN [Projects].[ID] ELSE NULL END) AS ActiveCount,
		    ISNULL(AVG([Invoices].[Revenue]),0) AS AverageSum,
		    COUNT(DISTINCT [Invoices].[ID]) AS InvoiceCount,
		    CASE @CurrencySelector
				WHEN 0 THEN 
					SUM(CASE[Invoices].[State] 
							WHEN 2 THEN [Invoices].[TotalBC] - ISNULL(Payments.PaySum,0) 
							ELSE 0 END)
		        WHEN 1 THEN 
					SUM(CASE[Invoices].[State] 
							WHEN 2 THEN [Invoices].[TotalBC] - 
							ISNULL(Payments.PaySum*dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoices].[Date], @ToCurrencyCode),0) 
							ELSE 0 END) 
			END AS Debt,
		    ISNULL(SUM([Invoices].[Revenue]),0) AS Revenue,
		    ISNULL(AVG(DATEDIFF(day,[Invoices].[Date],[Payments].[PayDate])+1),0) as PayTerm,
			[dbo].[fnpjm7CompanyFindSingleParent]([CustomerCompany].[ID])
			
		FROM 
		(	
			SELECT 
				[Invoice].[ID],
				[Invoice].[State],
				CASE @CurrencySelector 
					WHEN 0 THEN SUM([InvoiceLine].[TotalBC])
					WHEN 1 THEN SUM([InvoiceLine].[TotalBC])*
						dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoice].[Date], @ToCurrencyCode)
				END AS Revenue,
				CASE @CurrencySelector
					WHEN 0 THEN [Invoice].[TotalBC]
					WHEN 1 THEN [Invoice].[TotalBC] *
						dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoice].[Date], @ToCurrencyCode) 
				END AS TotalBC,
				[Invoice].[Date],
				[Invoice].[ProjectID]
			FROM 
				[InvoiceLine]
				LEFT OUTER JOIN ServiceType
					ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
				INNER JOIN [Invoice]
					ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
		    WHERE 
			(
				(@InvoiceSelector = 0 AND [Invoice].[State] = 5) 
				OR 
				(@InvoiceSelector = 1 AND [Invoice].[State] IN (2,5))			
			) 
			AND
			(
				@DateSelector = 3 
				OR 
				(@DateSelector IN (0, 1, 2) AND [Invoice].[Date] BETWEEN @PeriodStart AND @PeriodEnd)
			) 
			AND 
			(
				@ServiceTypeSelector = 0 
				OR
				@ServiceTypeSelector = 1 AND (([InvoiceLine].[ServiceTypeID] IS NOT NULL AND [ServiceType].[RatesDepended] = 1) OR [InvoiceLine].[ServiceTypeID] IS NULL)
				OR
				@ServiceTypeSelector = 2 AND [ServiceType].[RatesDepended] = 0 
				OR
				@ServiceTypeSelector = 3 AND ISNULL(@ServiceTypeID, 0) = ISNULL([InvoiceLine].[ServiceTypeID], 0)
			) 
			GROUP BY 
				[Invoice].[ID], 
				[Invoice].[State],
				[Invoice].[TotalBC],
				[Invoice].[Date], 
				[Invoice].[ProjectID], 
				[Invoice].[BaseCurrencyRate],
				[Invoice].[CurrencyRate] 
		) AS Invoices
		LEFT JOIN 
		(	
			SELECT 
				[PaymentDetail].[InvoiceID],
		        SUM([Payment].[TotalBC]) AS PaySum,
		        MAX([Payment].[Date]) AS PayDate
			FROM 
				[Payment]
				INNER JOIN [PaymentDetail] 
					ON [PaymentDetail].[PaymentID] = [Payment].[ID]
			GROUP BY 
				[PaymentDetail].[InvoiceID]
		) AS Payments
			ON [Payments].[InvoiceID] = [Invoices].[ID]
		RIGHT JOIN [Project] AS [Projects]
			ON [Invoices].[ProjectID] = [Projects].[ID]
		INNER JOIN [Company] AS [CustomerCompany]
			ON [Projects].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [ManagerEmployee]
			ON [CustomerCompany].[ManagerEmployeeID] = [ManagerEmployee].[ID]
		WHERE 
		(
			/*[CustomerCompany].[ManagerEmployeeID] = @ManagerID 
			OR 
			@ManagerID IS NULL*/
			@CompanyManagerSelector = 0
			OR
			(@CompanyManagerSelector = 1 AND ISNULL([CustomerCompany].[ManagerEmployeeID], 0) = ISNULL(@ManagerID, 0)) 
		)
		AND
		(
			[Projects].[SupplierCompanyID] = @CompanyID 
			OR 
			@CompanyID IS NULL
		) 
		AND
		(
			@CostCenterSelector = 0
			OR
			(@CostCenterSelector = 1 AND ISNULL([Projects].[CostCenterID], 0) = ISNULL(@CostCenterID, 0)) 
		)
		GROUP BY 
			[CustomerCompany].[ID], 
			[CustomerCompany].[FileAs], 
			[ManagerEmployee].[FileAs]
		ORDER by 
			[Revenue] DESC,
			[Manager] ASC
		
		SELECT @TotalRevenue = SUM([Revenue]) FROM @CustomerRevenue
	       
		SET @Rate = [dbo].[fnReportCalculateSmartValue](@ScaleSelector, @TotalRevenue)

		SET @Prefix = CASE  
						 WHEN @Rate = 1 THEN ''
						 WHEN @Rate = 1000 THEN '.'
						 WHEN @Rate = 1000000 THEN '.'
						 WHEN @Rate = 1000000000 THEN '.'
					  END
		
		--SELECT
			--@ScaleSelector AS [ScaleCheck]

	
		UPDATE @CustomerRevenue
		SET Percentage = CASE
				WHEN @TotalRevenue = 0 THEN 0
					ELSE Revenue*100/@TotalRevenue
			END,
		AverageSum = AverageSum / @Rate,
		Debt = Debt / @Rate,
		Revenue = Revenue / @Rate
	
		UPDATE @RevenueHeader
		SET CurrencyCode = @Prefix + CurrencyCode    
		
		SELECT * FROM  @RevenueHeader
		

		IF @SumByCompanyGroups = 1
		BEGIN
			--      
			INSERT INTO @CustomerRevenue
			SELECT
				(
					SELECT 
						[C].[FileAs] 
					FROM
						[Company] AS [C] 
					WHERE 
						[C].[ID] = [CR].[ParentCompanyID]
				),
				(
					SELECT  
						[E].[FileAs] 
					FROM 
						[Employee] AS [E]
						LEFT JOIN [Company] AS [C]
							ON [E].[ID] = [C].[ManagerEmployeeID]
					WHERE 
						[C].[ID] = [CR].[ParentCompanyID]
				),
				SUM([CR].[ProjectCount]),
				SUM([CR].[ActiveProjectCount]),
				SUM([CR].[AverageSum]),
				SUM([CR].[InvoiceCount]),
				SUM([CR].[Debt]),
				SUM([CR].[Revenue]),
				SUM([CR].[PayTerm]),
				SUM([CR].[Percentage]),
				NULL		
			FROM
				@CustomerRevenue AS [CR]
			WHERE
				[CR].[ParentCompanyID] IS NOT NULL
			GROUP BY
				[CR].[ParentCompanyID]


			DELETE FROM @CustomerRevenue WHERE [ParentCompanyID] IS NOT NULL

		END


		IF @CountSelector = 3
			SELECT * 
			FROM @CustomerRevenue
		ELSE
			SELECT TOP(CASE @CountSelector WHEN 0 THEN 5 
			                               WHEN 1 THEN 10 
			                               WHEN 2 THEN @Count
			           END) *
			FROM @CustomerRevenue
			
	
	RETURN 0
END
GO

GRANT EXEC ON ReportRevenueAnalysisByClients TO PUBLIC

GO

