IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[VistaWordFacture]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure VistaWordFacture'
		DROP PROCEDURE [dbo].[VistaWordFacture]
	END
GO

PRINT 'Creating procedure VistaWordFacture'
GO

/******************************************************************************
**		File: VistaWordFacture.sql
**		Name: VistaWordFacture
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/

CREATE PROCEDURE [VistaWordFacture]
	@ID TIdentifier
AS
	SET NOCOUNT ON

	DECLARE @CurrencyCode TCode,
			@StatementID TIdentifier,
			@CurrencyRate TMoney,
			@FactureCurrency TIdentifier,
			@CustomerID TIdentifier, 
			@SupplierID TIdentifier,
			@CurrencyNumericCode TCode3,
			@CountryNumericCode TCode3
	SELECT			
		@SupplierID = [Facture].[SupplierCompanyID],
		@CustomerID = [Facture].[CustomerCompanyID],
		@CurrencyCode = CASE [Project].[FactureCurrency]
			WHEN 0 THEN [Project].[CurrencyCode]
			ELSE [Facture].[CurrencyCode]
		END,
		@CurrencyRate = [CurrencyRate],
		@FactureCurrency = [FactureCurrency]
	FROM
		[Facture]
		INNER JOIN [Project]
			ON [Facture].[ProjectID] = [Project].[ID]
	WHERE 
		[Facture].[ID] = @ID		
	
	IF @FactureCurrency = 0
		SET @CurrencyRate = 1
	
	SELECT
		@StatementID = [FactureLine].[DocumentID]
	FROM
		[Facture]
			INNER JOIN [FactureLine]
				ON [Facture].[ID] = [FactureLine].[FactureID]
	WHERE 
		[FactureLine].[DocumentClass] = dbo.adfGetClassByName('Pjm5.Statement')

	DECLARE @CurrencyClass TClass, @CurrencyID TIdentifier, @CurrencyMale TBool, @CurrencyName TName, @CompanyClass TClass
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @CurrencyClass = dbo.adfGetClassByName('Adf.Currency')
	SELECT @CurrencyID = [ID] FROM [Currency] WHERE [Code] = @CurrencyCode
	SET @CurrencyMale = CASE 
		WHEN dbo.adfPropertyValueGetText(@CurrencyClass, @CurrencyID, '00000001-0000-0000-0000-000000000000') = 'False'
			THEN 0
		ELSE 1
	END

	SELECT @CurrencyName = [FileAs] FROM [Currency] WHERE [Currency].[ID] = @CurrencyID 
	SELECT @CurrencyNumericCode = [NumericCode] FROM [Currency] WHERE [Currency].[ID] = @CurrencyID

DECLARE @Table TABLE(
		[CalculationLineID] TIdentifier,
		[ApplyVAT] TBool,
		[FactureLineID] TIdentifier,
		[VATRate] TMoney)

INSERT INTO @Table(
		[CalculationLineID],
		[FactureLineID],
		[ApplyVAT],
		[VATRate]
		)
	SELECT
		[CalculationLine].[ID],
		[FactureLine].[ID],
		[Project].[ApplyVAT],
		[FactureLine].[VATRate]
	FROM
		[Facture]
			INNER JOIN [FactureLine]
				ON [Facture].[ID] = [FactureLine].[FactureID]
			INNER JOIN [Calculation]
				ON [FactureLine].[DocumentClass] = [Calculation].[Class]
					AND [FactureLine].[DocumentID] = [Calculation].[ID]
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID] = [Calculation].[ID]
			INNER JOIN [Project]
				ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Facture].[ID] = @ID

		
DECLARE @TimeEntry TABLE(
		[FactureLineID] TIdentifier,
		[UOM] TName,
		[UOMNumericCode] TCode3,
		[NameID] TIdentifier,		
		[Name] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney,
		[TotalWithVAT] TMoney
	)
	
		INSERT INTO @TimeEntry
			(
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price],
			[Amount],
			[Total],
			[VAT],
			[TotalWithVAT])
			
		SELECT
			[T].[FactureLineID] as [FactureLineID],
			'.' as [UOM],
			'356',
			'  (' + [Employee].[Initials]+ ')' as [Name],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [CalculationLine].[Amount] != 0
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT]) / [CalculationLine].[Amount]
				ELSE [CalculationLine].[Price]
			END as [Price],
			[CalculationLine].[Amount] as [Amount],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [T].[ApplyVAT] != 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
			END as [Total],
			[CalculationLine].[VAT] as [VAT],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [T].[ApplyVAT] != 1
					THEN [CalculationLine].[Amount] * [CalculationLine].[Price]
				ELSE ([CalculationLine].[Amount] * [CalculationLine].[Price] + [CalculationLine].[VAT])
			END as [TotalWithVAT]
		FROM 
			@Table as [T]
				INNER JOIN [CalculationLine]
					ON [T].[CalculationLineID] = [CalculationLine].[ID]
				INNER JOIN [TimeEntry]
					ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND
						[TimeEntry].[ID] = [CalculationLine].[DocumentID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [TimeEntry].[EmployeeID] 
		
	
	DECLARE @ServiceRequest TABLE(
		[FactureLineID] TIdentifier,
		[UOM] TName,
		[UOMNumericCode] TCode3,
		[NameID] TIdentifier,		
		[Name] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney,
		[TotalWithVAT] TMoney
	)
	
		INSERT INTO @ServiceRequest
			(
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price],
			[Amount],
			[Total],
			[VAT],
			[TotalWithVAT])
		
			SELECT
			[T].[FactureLineID] [FactureLineID],
			[UOM].[Code] as [UOM],
			[UOM].[NumericCode],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([ServiceAssignment].[Class], [ServiceAssignment].[ID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]) as [Name],
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[Price]/(1+ [T].[VatRate])
				ELSE 
			[ServiceRequestLine].[Price]
			END as [Price],
			[ServiceRequestLine].[FactAmount] as [Amount],
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]/(1+ [T].[VatRate])
				ELSE 
				[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]			
			END as [Total],
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]/(1+ [T].[VatRate])
				ELSE 
				[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]			
			END * [T].[VatRate] as [VAT],
			CASE 
				WHEN [ServiceRequest].[VATIsIncluded] = 1 
					THEN [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]	
				ELSE  [ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price]*(1+ [T].[VatRate])
			END as [TotalWithVAT]
		FROM
			@Table AS [T]
			INNER JOIN [CalculationLine]
				ON [T].[CalculationLineID] = [CalculationLine].[ID]
			INNER JOIN [ServiceRequest]
				ON [ServiceRequest].[Class] = [CalculationLine].[DocumentClass] AND
					[ServiceRequest].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [ServiceRequestLine]	
				ON [ServiceRequestLine].[ServiceRequestID] = [ServiceRequest].[ID]
			INNER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [ServiceRequestLine].[ServiceAssignmentID]
			INNER JOIN [Service]
				ON [Service].[ID] = [ServiceAssignment].[ServiceID]
			LEFT OUTER JOIN [UOM]
				ON [UOM].[ID] = [Service].[UOMID]

	
		DECLARE @t TABLE(
		[FactureLineID] TIdentifier,
		[UOM] TName,
		[UOMNumericCode] TCode3,
		[NameID] TIdentifier,		
		[Name] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney,
		[TotalWithVAT] TMoney
	)
	
		INSERT INTO @t
			(
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price],
			[Amount],
			[Total],
			[VAT],
			[TotalWithVAT])
		
		SELECT
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price],
			SUM([Amount]),
			SUM([Total]),
			SUM([VAT]),
			SUM([TotalWithVAT])
		FROM @TimeEntry
		GROUP BY
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price]
		
		UNION ALL
		
		SELECT
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price],
			SUM([Amount]),
			SUM([Total]),
			SUM([VAT]),
			SUM([TotalWithVAT])
		FROM @ServiceRequest
		GROUP BY
			[FactureLineID],
			[UOM],
			[UOMNumericCode],
			[Name],
			[Price]
		
		/*UNION ALL
			
		SELECT
			[T].[FactureLineID] as [FactureLineID],
			'-' as [UOM],
			' (,    )' as [Name],
			NULL as [Price],
			NULL as [Amount],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [T].[ApplyVAT] != 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
			END as [Total],
			[CalculationLine].[VAT] as [VAT],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [T].[ApplyVAT] != 1
					THEN  [CalculationLine].[Amount] * [CalculationLine].[Price]				
				ELSE ([CalculationLine].[Amount] * [CalculationLine].[Price] + [CalculationLine].[VAT])
			END as [TotalWithVAT]
		FROM
			@Table as [T]
			INNER JOIN [CalculationLine]
				ON [T].[CalculationLineID] = [CalculationLine].[ID]
			INNER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
					[Expense].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [PhoneCall]
				ON [Expense].[ID] = [PhoneCall].[ExpenseID]
		
		UNION ALL
		
			SELECT
			[T].[FactureLineID] as [FactureLineID],
			'-' as [UOM],
			' (,    )' as [Name],
			NULL as [Price],
			NULL as [Amount],
			[Calculation].[Total],
			[Calculation].[VATRate] * 100 AS [VATRate],
			[Calculation].[VAT],
		[Calculation].[TotalWithVAT],
		FROM
			@Table as [T]
			INNER JOIN [CalculationLine]
				ON [T].[CalculationLineID] = [CalculationLine].[ID]
			INNER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
					[Expense].[ID] = [CalculationLine].[DocumentID]*/

	SELECT
		[Facture].[Class],
		[Facture].[ID],
		[Facture].[State],
		[Facture].[Flag],
		[Facture].[FileAs],
		[Facture].[Date],
		[Facture].[Number],
		[Facture].[ProjectID],
		@CurrencyCode AS [CurrencyCode],
		@CurrencyMale AS [CurrencyMale],
		@CurrencyName AS [CurrencyName],
		@CurrencyNumericCode AS [CurrencyNumericCode],
		[Facture].[CurrencyRate],
		[Facture].[Scale],
		[Facture].[SupplierCompanyID],
		dbo.fnPjm6GetDetailedLegalCompanyName([SupplierCompany].[LegalName], 1) AS [SupplierCompanyName],
		[SupplierCompany].[ExecutiveEmployeeID] AS [SupplierExecutiveEmployeeID],
		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		ISNULL([SupplierExecutiveEmployee].[LastName] + ISNULL(' ' + [SupplierExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [SupplierExecutiveEmployee].[MiddleName], ''), 
			[SupplierExecutiveEmployee].[FileAs]) AS [ExecutiveName],
		ISNULL([SupplierAccountantEmployee].[LastName] + ISNULL(' ' + [SupplierAccountantEmployee].[FirstName], '') + ISNULL(' ' + [SupplierAccountantEmployee].[MiddleName], ''), 
			[SupplierAccountantEmployee].[FileAs]) AS [AccountantName], 
		[Facture].[SupplierAddress],
		[Facture].[SupplierINN],
		[Facture].[SupplierKPP],
		[Facture].[CustomerCompanyID],
		[CustomerCompany].[LegalName] AS [CustomerCompanyName],
		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerCompany].[AccountantEmployeeID] AS [CustomerAccountantEmployeeID],
		[Facture].[CustomerAddress],
		[Facture].[CustomerINN],
		[Facture].[CustomerKPP],
		[Facture].[Sender],
		[Facture].[Recipient],
		[Facture].[DocumentNumber],
		[Facture].[DocumentDate],
		[Facture].[Created],
		[Facture].[CreatedBy],
		[Facture].[Modified],
		[Facture].[ModifiedBy],
		[Facture].[Comments],
		[Facture].[Timestamp],
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [Facture].[TotalPC]
			ELSE [Facture].[Total]
		END AS [Total],
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [Facture].[VATPC]
			ELSE [Facture].[VAT]
		END AS [VAT],
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [Facture].[TotalWithVATPC]
			ELSE [Facture].[TotalWithVAT]
		END AS [TotalWithVAT],
		[Facture].[Advance]
	FROM
		[Facture]
		INNER JOIN [Project]
			ON [Facture].[ProjectID] = [Project].[ID]
		INNER JOIN [Company] AS [CustomerCompany]	
			ON [Facture].[CustomerCompanyID] = [CustomerCompany].[ID]
		INNER JOIN [Company] AS [SupplierCompany]	
			ON [Facture].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierExecutiveEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutiveEmployee].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierAccountantEmployee]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountantEmployee].[ID]
	WHERE
		[Facture].[ID] = @ID
	
	SELECT
		[FactureLine].[ID],
		[FactureLine].[FactureID],
		[FactureLine].[DocumentClass],
		[FactureLine].[DocumentID],
		[FactureLine].[UOMID],
		[T].[Amount] AS [Amount],
		[FactureLine].[VATIsIncluded], 
		[FactureLine].[VATRate], 
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [FactureLine].[OriginalPricePC]
			ELSE [FactureLine].[OriginalPrice]
		END AS [OriginalPrice],
		[T].[Price] * @CurrencyRate AS [Price],
		ISNULL([T].[Total] * @CurrencyRate, 
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [FactureLine].[TotalPC]
			ELSE [FactureLine].[Total]
		END) AS [Total],
		ISNULL(CASE [Project].[FactureCurrency]
			WHEN 0 THEN [FactureLine].[ExcisePC]
			ELSE [FactureLine].[Excise]
		END, 0) AS [Excise],
		ISNULL([T].[VAT] * @CurrencyRate,
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [FactureLine].[VATPC]
			ELSE [FactureLine].[VAT]
		END) AS [VAT],
		CASE [FactureLine].[VATRate] WHEN 0 THEN ' ' ELSE
			CASE [Facture].[Advance]
				WHEN 0 THEN LTRIM(STR([FactureLine].[VatRate]*100))+'%'
				ELSE LTRIM(STR([FactureLine].[VatRate]*100))+'% / 1'+LTRIM(STR([FactureLine].[VatRate]*100))+'%' END
		END AS [VATRate2],
		ISNULL([T].[TotalWithVAT] * @CurrencyRate,
		CASE [Project].[FactureCurrency]
			WHEN 0 THEN [FactureLine].[TotalWithVATPC]
			ELSE [FactureLine].[TotalWithVAT]
		END) AS [TotalWithVAT],
		ISNULL([FactureLine].[Country], '-') AS [Country],
		ISNULL([FactureLine].[CustomDeclaration], '-') AS [CustomDeclaration],
		ISNULL([T].[Name],' (,    )') AS [Description],
		ISNULL([T].[UOM], '-') AS [UOM],
		ISNULL([T].[UOMNumericCode], '-') AS [UOMNumericCode],
		ISNULL([Country].[NumericCode], '-') AS [CountryNumericCode]	--  

	FROM
		[FactureLine]
		INNER JOIN [Facture]
			ON [FactureLine].[FactureID] = [Facture].[ID]
		INNER JOIN [Project]
			ON [Facture].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN @t AS [T]
			ON [T].[FactureLineID] = [FactureLine].[ID]
		LEFT OUTER JOIN [Country]
			ON [FactureLine].[Country] = [Country].[FileAs]
	WHERE
		[FactureLine].[FactureID] = @ID
	ORDER BY
		[FactureLine].[Description]
		
	SELECT
		[FactureID],
		[PaymentID]
	FROM
		[FacturePayment]
	WHERE
		[FactureID] = @ID
		
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @SupplierID AND 
		[Address].[BusinessCardClass] = @CompanyClass
		
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @CustomerID AND 
		[Address].[BusinessCardClass] = @CompanyClass

	RETURN 0
GO

GRANT EXECUTE ON [VistaWordFacture] TO PUBLIC
GO

  