IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6StatementCreateRecurrence]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6StatementCreateRecurrence'
		DROP PROCEDURE [dbo].[pjm6StatementCreateRecurrence]
	END
GO
PRINT 'Creating procedure pjm6StatementCreateRecurrence'
GO
/******************************************************************************
**		File: pjm6StatementCreateRecurrence.sql
**		Name: StatementCreateRecurrence
**		Auth: pavel.svintsov
**		Date: 13/06/2011 14:07:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		01.07.11	SYV				 WarningFlagID,   
**		10.12.13	SAP				  
**		12.02.15	SAP			 GUID    adfwfGetInitialState
*******************************************************************************/
CREATE PROCEDURE [pjm6StatementCreateRecurrence]
	@ID TIdentifier
AS
	DECLARE 
		@Flag TFlag,
		@Class TClass,
		@State TState,
		@StatementState TState,
		@Number TCode,
		@FileAs TName,
		@ProjectID TIdentifier,
		@Date TDate,
		@DueDate TDate,
		@PeriodStart TDate,
		@PeriodEnd TDate,
		@SupplierBankAccountID TIdentifier,
		@CurrencyRate TAmount,
		@BaseCurrencyRate TAmount,
		@CurrencyCode TCode3,
		@ProjectCurrencyCode TCode3,
		@BaseCurrencyCode TCode3,
		@Comments TNotes,
		@PaymentCurrencyPoint TIdentifier,
		@Advance TBool,
		@RecurrenceID TIdentifier,
		@SupplierCompanyID TIdentifier,
		@CustomerCompanyID TIdentifier,
		@Scale TCount,
		@rv int,
		@value TVariant,

		@WarningFlagID TIdentifier,
		@PrevCurrencyRate TAmount,
		@PrevBaseCurrencyRate TAmount
			
	SET NOCOUNT ON
	
	SELECT
		@Flag = [Statement].[Flag],
		@Class = [Statement].[Class],
		@StatementState = [Statement].[State],
		@Number = '',
		@FileAs = '',
		@ProjectID = [Statement].[ProjectID],
		@Date = [Statement].[Date],
		@CurrencyCode = [Statement].[CurrencyCode],
		@Comments = [Statement].[Comments],
		@SupplierCompanyID = [Statement].[SupplierCompanyID],
		@CustomerCompanyID = [Statement].[CustomerCompanyID],
		@Scale = [Statement].[Scale],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PeriodStart = [Statement].[PeriodStart],
		@PeriodEnd = [Statement].[PeriodEnd],
		@PrevCurrencyRate = [Statement].[CurrencyRate],
		@PrevBaseCurrencyRate = [Statement].[BaseCurrencyRate]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Project].[ID] = [Statement].[ProjectID]
	WHERE
		[Statement].[ID] = @ID
	
	SELECT
		@RecurrenceID = [RecurrencePatternID]
	FROM
		[Document]
	WHERE
		[Class] = @Class AND [ID] = @ID
	IF @RecurrenceID IS NULL
		RETURN 0
		
	DECLARE 
		@NewID TIdentifier,
		@NewDate TDatetime,
		@NewPeriodStart TDatetime,
		@NewPeriodEnd TDatetime,
		@CurrentDate TDatetime

	SET @CurrentDate = GETDATE()
	SET @NewDate = dbo.fnPjm5RecurrenceGetNextDateTime(@RecurrenceID, @Date, @CurrentDate)
	SET @NewPeriodStart = DATEADD(day, 1, @PeriodEnd)
	SET @NewPeriodEnd =  @NewDate
	IF @NewDate IS NULL OR @NewPeriodStart IS NULL OR @NewPeriodEnd IS NULL
		RETURN 0

	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value AS varchar(3))
	SET @CurrencyRate = dbo.fnCurrencyGetExactRate(@CurrencyCode, @ProjectCurrencyCode, @NewDate)
	SET @BaseCurrencyRate = dbo.fnCurrencyGetExactRate(@BaseCurrencyCode, @ProjectCurrencyCode, @NewDate)

	SET @State = dbo.adfwfGetInitialState('5F1BCDEB-EDAF-44AE-BCC0-3D37E6516A60')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SET @WarningFlagID = NULL

	IF @CurrencyRate IS NULL
	BEGIN
		IF @PrevCurrencyRate > 1
			SET @CurrencyRate = -1.0 * @PrevCurrencyRate
		ELSE
			SET @CurrencyRate = @PrevCurrencyRate


		SET @WarningFlagID = 6
	END

	IF @BaseCurrencyRate IS NULL
	BEGIN
		SET @BaseCurrencyRate = @PrevBaseCurrencyRate
		SET @WarningFlagID = 6
	END

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0  AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	INSERT INTO [Statement]
		([Flag], [State], [Date], [Number], [FileAs],
		 [ProjectID], [CurrencyRate], [BaseCurrencyRate], 
		 [CurrencyCode], [Comments],
		 [PeriodStart], [PeriodEnd],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale], [Periodical], [WarningFlagID])
	VALUES
		(@Flag, @State, @NewDate, @Number, @FileAs, 
		 @ProjectID,
		 CASE WHEN @CurrencyRate < 0.0 THEN -1.0 * @CurrencyRate  ELSE @CurrencyRate END,
		 CASE WHEN @BaseCurrencyRate < 0.0 THEN -1.0 * @BaseCurrencyRate ELSE @BaseCurrencyRate END,
		 @CurrencyCode, @Comments,
		 @NewPeriodStart, @NewPeriodEnd,
		 @SupplierCompanyID, @CustomerCompanyID,
		 @Scale, 0, @WarningFlagID)
	IF @@ERROR != 0
		RETURN 1

	SET @NewID = SCOPE_IDENTITY()

	INSERT INTO [StatementLine] 
		([StatementID], [DocumentClass], [DocumentID], 
		[Description], [Amount], [UOMID], [Price], [VATIsIncluded], [VATRate], [VAT],
		[PricePC], [VATPC], [ServiceTypeID], [BasePrice], [SortKey])
	SELECT
		@NewID, 
		[DocumentClass], 
		[DocumentID], 
		[Description], 
		[Amount], 
		[UOMID], 
		CASE WHEN @CurrencyRate < 0 THEN -1.0 * [PricePC] * @CurrencyRate ELSE [PricePC] / @CurrencyRate END, 
		[VATIsIncluded], 
		[VATRate], 
		CASE WHEN @CurrencyRate < 0 THEN -1.0 * [VATPC] * @CurrencyRate ELSE [VATPC] / @CurrencyRate END,
		[PricePC],
		[VATPC],
		[ServiceTypeID], [BasePrice], [SortKey]
	FROM
		[StatementLine]
	WHERE
		[StatementID] = @ID AND
		(
			[DocumentClass] IS NULL OR
			[DocumentClass] = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
		)
	IF @@ERROR != 0
		RETURN 1

	EXEC @rv = adfDocumentCategoryCopy @Class, @ID, @NewID
	IF @rv != 0
		RETURN @rv

	EXEC @rv = adfDocumentContactCopy @Class, @ID, @NewID
	IF @rv != 0
		RETURN @rv

	UPDATE
		[Document]
	SET
		[RecurrencePatternID] = @RecurrenceID
	WHERE
		[Class] = @Class AND [ID] = @NewID

	IF @@ERROR != 0
		RETURN 1
	DECLARE @Occurrences TCount
	SELECT @Occurrences = [Occurrences] FROM [RecurrencePattern] WHERE [ID] = @RecurrenceID
	IF ISNULL(@Occurrences, 0) > 0
	BEGIN
		UPDATE
			[RecurrencePattern]
		SET
			[Occurrences] = @Occurrences - 1
		WHERE
			[ID] = @RecurrenceID
		IF @@ERROR != 0
			RETURN 1
	END
	
	IF @StatementState != @State
	BEGIN
		UPDATE
			[Statement]
		SET
			[Statement].[State] = @StatementState,
			[Statement].[Modified] = DEFAULT,
			[Statement].[ModifiedBy] = DEFAULT
		WHERE
			[Statement].[ID] = @NewID

		IF @@ERROR != 0
			RETURN 1
	END
	
	
	RETURN 0
GO

GRANT EXECUTE ON pjm6StatementCreateRecurrence TO PUBLIC
GO   