IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5StatementUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5StatementUpdate'
		DROP PROCEDURE [dbo].[pjm5StatementUpdate]
	END
GO

PRINT 'Creating procedure pjm5StatementUpdate'
GO

/******************************************************************************
**		File: pjm5StatementUpdate.sql
**		Name: pjm5StatementUpdate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/21/2005 15:47:39
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		30.06.11	SYV			      
**		01.07.11	SYV			 WarningFlagID,   
**		11.03.13	MAB			  OPENXML
**		08.03.14	SAP			   ,    != . 
**		16.04.14	GNV			    WarningFlagID  Statement
**		24.07.14	SAP			           
*******************************************************************************/
CREATE PROCEDURE pjm5StatementUpdate
	@Xml XML
AS
	DECLARE @ID TIdentifier,
			@Date TDate,
			@Number TCode,
			@Class TClass,
			@State TState,
			@FileAs TName,
			@ProjectID TIdentifier,
			@Periodical TBool,
			@PeriodStart TDate,
			@PeriodEnd TDate,
			@Comments TNotes,
			@StatementCurrencyRate TAmount,
			@CurrencyRate TAmount,
			@BaseCurrencyRate TAmount,
			@PrevCurrencyCode TCode3,
			@CurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@NationalCurrencyCode TCode3,
			@value TVariant,
			@ReminderState TState,
			@ReminderInterval TTimeSpan,
			@ReminderTime TDateTime,
			@ReturnDate TDate,
			@rv int,
			@RecurrenceID TIdentifier,
			@SupplierCompanyID TIdentifier, 
			@CustomerCompanyID TIdentifier,
			@ExchangeBanned TBool,
			@WarningFlagID TIdentifier,
			@StatementBaseCurrencyRate TAmount
	
	SET NOCOUNT ON

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrencyCode = CAST(@value AS varchar(3))

	SELECT
		@ID							= @Xml.value('(/pjm5StatementGet/Statement/ID)[1]','int'),
		@Class						= @Xml.value('(/pjm5StatementGet/Statement/Class)[1]','int'),
		@State						= @Xml.value('(/pjm5StatementGet/Statement/State)[1]','int'),
		@Date						= CONVERT(datetime, @Xml.value('(/pjm5StatementGet/Statement/Date)[1]','nvarchar(19)')),
		@Number						= @Xml.value('(/pjm5StatementGet/Statement/Number)[1]','varchar(32)'),
		@FileAs						= @Xml.value('(/pjm5StatementGet/Statement/FileAs)[1]','nvarchar(512)'),
		@ProjectID					= @Xml.value('(/pjm5StatementGet/Statement/ProjectID)[1]','int'),
		@PeriodStart				= CONVERT(datetime, @Xml.value('(/pjm5StatementGet/Statement/PeriodStart)[1]','nvarchar(19)')),
		@PeriodEnd					= CONVERT(datetime, @Xml.value('(/pjm5StatementGet/Statement/PeriodEnd)[1]','nvarchar(19)')),
		@CurrencyRate				= @Xml.value('(/pjm5StatementGet/Statement/CurrencyRate)[1]','money'),
		@BaseCurrencyRate			= @Xml.value('(/pjm5StatementGet/Statement/BaseCurrencyRate)[1]','money'),
		@CurrencyCode				= @Xml.value('(/pjm5StatementGet/Statement/CurrencyCode)[1]','char(3)'),
		@ReturnDate					= CONVERT(datetime, @Xml.value('(/pjm5StatementGet/Statement/ReturnDate)[1]','varchar(19)')),
		@ReminderState				= CASE @Xml.value('(/pjm5StatementGet/Statement/ReminderState)[1]','varchar(5)') WHEN 'false' THEN 0 ELSE 1 END,
		@ReminderTime				= CONVERT(datetime, @Xml.value('(/pjm5StatementGet/Statement/ReminderTime)[1]','varchar(19)')),

		@SupplierCompanyID			= @Xml.value('(/pjm5StatementGet/Statement/SupplierCompanyID)[1]','int'), 
		@CustomerCompanyID			= @Xml.value('(/pjm5StatementGet/Statement/CustomerCompanyID)[1]','int'),
		@Comments					= @Xml.value('(/pjm5StatementGet/Statement/Comments)[1]','nvarchar(max)'),

		@ProjectCurrencyCode		= [Project].[CurrencyCode],
		@PrevCurrencyCode			= [Statement].[CurrencyCode],
		@StatementCurrencyRate		= [Statement].[CurrencyRate],
		@StatementBaseCurrencyRate	= [Statement].[BaseCurrencyRate],
		@ExchangeBanned				= @Xml.value('(/pjm5StatementGet/Statement/ExchangeBanned)[1]','bit'),
		@RecurrenceID				= @Xml.value('(/pjm5StatementGet/Statement/RecurrencePatternID)[1]','int'),
		@WarningFlagID				= [Statement].[WarningFlagID]
	FROM
		[Statement] INNER JOIN [Project]
			ON [Project].[ID] = [Statement].[ProjectID]
	WHERE
		[Statement].[ID] = @Xml.value('(/pjm5StatementGet/Statement/ID)[1]','int')
	
				
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllStatements')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		

	--     
	DECLARE @ApprovedRatesUpdated TBool
	SELECT
		@ApprovedRatesUpdated = CASE WHEN
			[State] = 2 AND
			(
				ISNULL([CurrencyRate], -100) = ISNULL(@CurrencyRate, -100) OR
				ISNULL([CurrencyCode], -100) = ISNULL(@CurrencyCode, -100) OR
				ISNULL([BaseCurrencyRate], -100) = ISNULL(@BaseCurrencyRate, -100)
			)
		THEN 1 ELSE 0 END
	FROM
		[Statement]
	WHERE
		[ID] = @ID

	IF @ApprovedRatesUpdated = 1
	BEGIN
		RAISERROR('#TransitionTemplateCouldNotBeFound', 16, -1)
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DECLARE @OnlyCustomFields TBool
	SELECT
		@OnlyCustomFields = CASE WHEN
			[Statement].[ExchangeBanned] != @ExchangeBanned AND
			ISNULL([Statement].[Date], -100) = ISNULL(@Date, -100) AND
			ISNULL([Statement].[ReturnDate], -100) = ISNULL(@ReturnDate, -100) AND
			ISNULL([Statement].[Number], -100) = ISNULL(@Number, -100) AND
			ISNULL([Statement].[FileAs], -100) = ISNULL(@FileAs, -100) AND
			ISNULL([Statement].[ProjectID], -100) = ISNULL(@ProjectID, -100) AND
			ISNULL([Statement].[PeriodStart], -100) = ISNULL(@PeriodStart, -100) AND
			ISNULL([Statement].[PeriodEnd], -100) = ISNULL(@PeriodEnd, -100) AND
			ISNULL([Statement].[CurrencyRate], -100) = ISNULL(@CurrencyRate, -100) AND
			ISNULL([Statement].[BaseCurrencyRate], -100) = ISNULL(@BaseCurrencyRate, -100) AND
			ISNULL([Statement].[CurrencyCode], -100) = ISNULL(@CurrencyCode, -100) AND
			ISNULL([Statement].[SupplierCompanyID], -100) = ISNULL(@SupplierCompanyID, -100) AND
			ISNULL([Statement].[CustomerCompanyID], -100) = ISNULL(@CustomerCompanyID, -100) AND
			ISNULL([Statement].[Comments], -100) = ISNULL(@Comments, -100)			
		THEN 1 ELSE 0 END
	FROM
		[Statement]
	WHERE
		[Statement].[ID] = @ID

	IF @OnlyCustomFields = 1
	BEGIN
		UPDATE
			[Statement]
		SET
			[Statement].[ExchangeBanned] = @ExchangeBanned
		WHERE
			[Statement].[ID] = @ID
		
		EXEC pjm5StatementGet @ID
		RETURN 0
	END

	----------------------------------------------rec--------------------------------------------------
	DECLARE -- RECURRENCE
		@RStartDate TDate, 
		@REndDate TDate, 
		@RRecurrenceType TIdentifier, 
		@ROccurrences TCount,
		@RInterval TCount, 
		@RDayOfWeekMask TIdentifier, 
		@RInstance TIdentifier, 
		@RMonthOfYear TCount, 
		@RDayOfMonth TCount,
		@Recurrence TBool

	SET @Recurrence = 0
	IF (SELECT @Xml.value('(/pjm5StatementGet/RecurrencePattern/ID)[1]', 'int')) IS NOT NULL
	BEGIN
		SET @Recurrence = 1
		SELECT
			@RStartDate			= @Xml.value('(/pjm5StatementGet/RecurrencePattern/StartDate)[1]','varchar(19)'),
			@REndDate			= @Xml.value('(/pjm5StatementGet/RecurrencePattern/EndDate)[1]','varchar(19)'), 
			@RRecurrenceType	= @Xml.value('(/pjm5StatementGet/RecurrencePattern/RecurrenceType)[1]','int'), 
			@ROccurrences		= @Xml.value('(/pjm5StatementGet/RecurrencePattern/Occurrences)[1]','int'),
			@RInterval			= @Xml.value('(/pjm5StatementGet/RecurrencePattern/Interval)[1]','int'), 
			@RDayOfWeekMask		= @Xml.value('(/pjm5StatementGet/RecurrencePattern/DayOfWeekMask)[1]','int'), 
			@RInstance			= @Xml.value('(/pjm5StatementGet/RecurrencePattern/Instance)[1]','int'), 
			@RMonthOfYear		= @Xml.value('(/pjm5StatementGet/RecurrencePattern/MonthOfYear)[1]','int'), 
			@RDayOfMonth		= @Xml.value('(/pjm5StatementGet/RecurrencePattern/DayOfMonth)[1]','int')
	END

	IF @State = 1
	BEGIN
		IF @Recurrence = 0 AND @RecurrenceID IS NOT NULL
		BEGIN
			UPDATE [Document] SET [RecurrencePatternID] = NULL WHERE [Class] = @Class AND [ID] = @ID
			IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
		ELSE IF @Recurrence = 1 AND @RecurrenceID IS NULL
		BEGIN
			INSERT INTO [RecurrencePattern]
				([StartDate], [EndDate], [RecurrenceType], [Occurrences],
				[Interval], [DayOfWeekMask], [Instance], [MonthOfYear], [DayOfMonth])
			VALUES
				(@RStartDate, @REndDate, @RRecurrenceType, @ROccurrences,
				@RInterval, @RDayOfWeekMask, @RInstance, @RMonthOfYear, @RDayOfMonth)
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
			SET @RecurrenceID = SCOPE_IDENTITY()
			
			UPDATE [Document] SET [RecurrencePatternID] = @RecurrenceID WHERE [Class] = @Class AND [ID] = @ID
			IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
		ELSE IF @Recurrence = 1 AND @RecurrenceID IS NOT NULL
		BEGIN
			UPDATE
				[RecurrencePattern]
			SET
				[StartDate] = @RStartDate, 
				[EndDate] = @REndDate, 
				[RecurrenceType] = @RRecurrenceType, 
				[Occurrences] = @ROccurrences,
				[Interval] = @RInterval, 
				[DayOfWeekMask] = @RDayOfWeekMask, 
				[Instance] = @RInstance, 
				[MonthOfYear] = @RMonthOfYear, 
				[DayOfMonth] = @RDayOfMonth
			WHERE
				[ID] = @RecurrenceID
			IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END
	---------------------------------------------------------------------------------------------------

	BEGIN TRANSACTION

	UPDATE 
		[Statement]
	SET
		[Statement].[Date] = @Date,
		[Statement].[ReturnDate] = @ReturnDate,
		[Statement].[Number] = ISNULL(@Number, ''),
		[Statement].[FileAs] = @FileAs,
		[Statement].[ProjectID] = @ProjectID,
		[Statement].[PeriodStart] = @PeriodStart,
		[Statement].[PeriodEnd] = @PeriodEnd,
		[Statement].[CurrencyRate] = @CurrencyRate,
		[Statement].[BaseCurrencyRate] = @BaseCurrencyRate,
		[Statement].[CurrencyCode] = @CurrencyCode,
		[Statement].[SupplierCompanyID] = @SupplierCompanyID, 
		[Statement].[CustomerCompanyID] = @CustomerCompanyID,
		[Statement].[Comments] = @Comments,
		[Statement].[Modified] = DEFAULT,
		[Statement].[ModifiedBy] = DEFAULT,
		[WarningFlagID] = @WarningFlagID
	FROM 
		[Statement]
	WHERE
		[Statement].[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF ISNULL(@StatementCurrencyRate, -1) != ISNULL(@CurrencyRate, -1) OR 		
		@PrevCurrencyCode != @CurrencyCode
	BEGIN
		DECLARE @lines TABLE (
		   ID int,
		   DocumentID int null,
		   VATIsIncluded bit null,
		   VATRate decimal(18,4) null,
		   Amount decimal(18,4) null,
		   PricePC money null,
		   VATPC money null,
		   Price money null,
		   VAT money null,
		   BasePrice int,
		   modified bit)
		INSERT INTO @lines 
			(ID,DocumentID,VATIsIncluded,VATRate,Amount,PricePC,VATPC,Price,VAT,BasePrice,modified)
		SELECT 
			ID,DocumentID,VATIsIncluded,VATRate,Amount,PricePC,VATPC,Price,VAT,BasePrice,0 
		FROM 
			[StatementLine] 
		WHERE 
			StatementID = @ID
		
		IF @CurrencyRate = 1
		BEGIN
			UPDATE @lines
			SET 
				PricePC = Price,
				VATPC = VAT,
				modified = 1
			WHERE
				BasePrice = 2

			UPDATE @lines
			SET 
				Price = PricePC,
				VAT = VATPC,
				modified = 1
			WHERE
				BasePrice = 1

			UPDATE @lines
			SET
				[VATPC] = CASE [VATIsIncluded]
						WHEN 0 THEN ROUND([Amount] * [PricePC] * [VatRate], 2)
						ELSE ROUND([Amount] * [PricePC] * [VatRate] / (1 + [VatRate]), 2)
					END
			WHERE
				BasePrice = 2
			
			UPDATE @lines
			SET
				[VAT] = CASE [VATIsIncluded]
						WHEN 0 THEN ROUND([Amount] * [Price] * [VatRate], 2)
						ELSE ROUND([Amount] * [Price] * [VatRate] / (1 + [VatRate]), 2)
					END
			WHERE
				BasePrice = 1
		END
		ELSE
		BEGIN
			DECLARE
				@lineID int, @lineDocumentID int, 
				@lineVATIsIncluded bit, @lineVATRate decimal(18,4),@lineAmount decimal(18,4),
				@linePricePC money,	@lineVATPC money, @linePrice money, @lineVAT money,  
				@lineBasePrice int, @lineModified bit
			DECLARE lines CURSOR FAST_FORWARD READ_ONLY FOR
				SELECT
					[ID], [DocumentID], [VATIsIncluded],[VATRate],[Amount],[PricePC], [VATPC], [Price], 
					[VAT], [BasePrice]				
				FROM
					@lines
			OPEN lines
			FETCH NEXT FROM lines INTO
				@lineID, @lineDocumentID, @lineVATIsIncluded, @lineVATRate, @lineAmount, 
				@linePricePC, @lineVATPC, @linePrice, @lineVAT,	@lineBasePrice
				
			WHILE @@FETCH_STATUS = 0
			BEGIN
			
				DECLARE	
					@TVWPC money,
					@TVW money,
					@Ttl money,
					@TtlPC money,
					@V money,
					@VPC money,
					@PVW money,
					@PVWPC money,
					@P money,
					@PPC money

				IF @lineBasePrice = 1
				BEGIN
					IF @lineVATIsIncluded = 1
						SET @TVWPC = ROUND(@linePricePC * @lineAmount,2)
					ELSE
						SET @TVWPC = ROUND(@linePricePC * @lineAmount,2) + @lineVATPC

					IF @CurrencyCode = @NationalCurrencyCode
						SET @TVW = ROUND(@TVWPC * @CurrencyRate,2)
					ELSE
						SET @TVW = ROUND(@TVWPC / @CurrencyRate,2)
					SET @V = ROUND(@TVW * @lineVATRate / (1 + @lineVATRate), 2)
					SET @Ttl = @TVW - @V
					SET @PVW = ROUND(@TVW / @lineAmount, 2)
					SET @P = ROUND(@Ttl / @lineAmount, 2)

					IF @lineVATIsIncluded = 0
						SET @linePrice = @P
					ELSE
						SET @linePrice = @PVW

					SET @lineVAT = @V
				END
				ELSE
				BEGIN
					IF @lineVATIsIncluded = 1
						SET @TVW = @linePrice * @lineAmount
					ELSE
						SET @TVW = @linePrice * @lineAmount + @lineVAT

					IF @CurrencyCode = @NationalCurrencyCode
							SET @TVWPC = ROUND(@TVW / @CurrencyRate,2)
						ELSE
							SET @TVWPC = ROUND(@TVW * @CurrencyRate,2)
					SET @VPC = ROUND(@TVWPC * @lineVATRate / (1 + @lineVATRate), 2)
					SET @TtlPC = @TVWPC - @VPC
					SET @PVWPC = ROUND(@TVWPC / @lineAmount, 2)
					SET @PPC = ROUND(@TtlPC / @lineAmount, 2)

					IF @lineVATIsIncluded = 0
						SET @linePricePC = @PPC
					ELSE
						SET @linePricePC = @PVWPC

					SET @lineVATPC = @VPC
				END 

				UPDATE @lines
				SET [PricePC] = @linePricePC,
					[VATPC] = @lineVATPC,
					[Price] = @linePrice,
					[VAT] = @lineVAT,
					[modified] = 1
				WHERE
					[ID] = @lineID

				FETCH NEXT FROM lines INTO
					@lineID, @lineDocumentID, @lineVATIsIncluded, @lineVATRate, @lineAmount, 
					@linePricePC, @lineVATPC, @linePrice, @lineVAT,	@lineBasePrice
			END
			CLOSE [lines]
			DEALLOCATE [lines]

			--UPDATE @lines
			--SET 
			--	PricePC = ROUND(CASE 
			--				WHEN @CurrencyCode = @NationalCurrencyCode THEN Price / @CurrencyRate
			--				ELSE Price * @CurrencyRate
			--			END, 2),
			--	modified = 1
			--WHERE
			--	BasePrice = 2
				
			--UPDATE @lines
			--SET 
			--	Price = ROUND(CASE 
			--				WHEN @CurrencyCode = @NationalCurrencyCode THEN PricePC * @CurrencyRate
			--				ELSE PricePC / @CurrencyRate
			--			END, 2),
			--	modified = 1
			--WHERE
			--	BasePrice = 1
		END

		
			
		UPDATE
			[StatementLine]
		SET
			PricePC = l.PricePC,
			VATPC = l.VATPC,
			Price = l.Price,
			VAT = l.VAT
		FROM
			[StatementLine]
			INNER JOIN @lines l
				ON l.[ID] = [StatementLine].[ID]
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	IF ISNULL(@StatementCurrencyRate, -1) != ISNULL(@CurrencyRate, -1) OR 
		ISNULL(@StatementBaseCurrencyRate, -1) != ISNULL(@BaseCurrencyRate, -1) OR
		@PrevCurrencyCode != @CurrencyCode
	BEGIN
		SET @WarningFlagID = NULL
	END

	UPDATE 
		[Statement]
	SET 
		[Statement].[TotalBC]= ROUND(CASE
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN ISNULL([Statement].[TotalPC], 0)  / @BaseCurrencyRate
						ELSE ISNULL([Statement].[TotalPC], 0)  * @BaseCurrencyRate
					END, 2),
		[Statement].[TotalWithVATBC] = ROUND(CASE 
						WHEN @ProjectCurrencyCode = @NationalCurrencyCode
							THEN ISNULL([Statement].[TotalWithVATPC], 0)  / @BaseCurrencyRate
						ELSE ISNULL([Statement].[TotalWithVATPC],0) * @BaseCurrencyRate
					END, 2),
		[Statement].[WarningFlagID] = @WarningFlagID
	FROM 
		[Statement]
	WHERE
		[Statement].[ID] = @ID

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	IF @OnlyCustomFields = 0
	BEGIN
		UPDATE
			[Statement]
		SET
			[Statement].[ExchangeBanned] = @ExchangeBanned
		WHERE
			[Statement].[ID] = @ID
	END

	SET @ReminderInterval = DATEDIFF(minute, @ReminderTime, @ReturnDate)
	EXEC @rv = pjm7StatementReminderCreate @ID,
		@ReturnDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN @rv
	END
	
	COMMIT TRANSACTION
	
	EXEC pjm5StatementGet @ID

	RETURN 0
GO

GRANT EXECUTE ON pjm5StatementUpdate TO PUBLIC
GO
