IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trTaskUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trTaskUpdate'
		DROP  Trigger pjm5trTaskUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trTaskUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------    --------			-------------------------------------------
**		11.02.10	SYV					      
**										  UserParameters
**		08.08.13	SAP					     
**		16.06.15	KAA					      
*******************************************************************************/

PRINT 'Creating Trigger pjm5trTaskUpdate'
GO
CREATE Trigger pjm5trTaskUpdate 
ON [Task] FOR UPDATE
AS
BEGIN
	IF EXISTS(
		SELECT * 
		FROM
			[inserted]
			INNER JOIN [deleted]
				ON [inserted].[ID] = [deleted].[ID]
			INNER JOIN [Project]
				ON [Project].[ID] = [inserted].[ProjectID]
		WHERE
			[inserted].[State] != [deleted].[State] AND
			[Project].[ProjectManagerEmployeeID] != dbo.adfGetCurrentEmployeeID() AND
			[Project].[ManagerAssistantEmployeeID] != dbo.adfGetCurrentEmployeeID() AND 
			(dbo.adfHasAccessRightByName('ManageProject') = 0 OR dbo.adfHasAccessRightByName('ViewAllProjects') = 0)
		)
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	IF EXISTS(SELECT * FROM [inserted] WHERE [inserted].[State] = 3 AND [inserted].[PercentComplete] != 1)
	BEGIN
		RAISERROR('#completedtaskisnotcomleted', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	-- We should not change state of task in draft project
	IF EXISTS (
		SELECT *
		FROM [inserted]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID]
			INNER JOIN [Project]
				ON [inserted].[ProjectID] = [Project].[ID]
		WHERE [Project].[State] = 1 AND
			[inserted].[State] != [deleted].[State]
	)
	BEGIN
		RAISERROR('#IsDraftProjectTask', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[EmployeeCalendar]
	SET
		[Approved] = [Approved] + [BusyEntry].[Planned]
	FROM
		[EmployeeCalendar]
		INNER JOIN [BusyEntry]
			ON ([EmployeeCalendar].[Date] = [BusyEntry].[Date] AND
				[EmployeeCalendar].[EmployeeID] = [BusyEntry].[EmployeeID])
		INNER JOIN [inserted]
			ON [inserted].[ID] = [BusyEntry].[TaskID]
		INNER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	WHERE
		inserted.[State] = 2 AND deleted.[State] = 8
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE 
		[BusyEntry]
	SET
		[Canceled] = CASE
			WHEN [deleted].[State] != 3 AND [inserted].[State] = 3 AND
				[BusyEntry].[Date] > [inserted].[EndDate]
				THEN [BusyEntry].[Planned]
			WHEN [deleted].[State] = 3 AND [inserted].[State] != 3 AND
				[BusyEntry].[Date] > [deleted].[EndDate]
				THEN 0
			WHEN [deleted].[State] IN (6, 8) AND [inserted].[State] = 2
				THEN 0
			WHEN [deleted].[State] != 6 AND [inserted].[State] = 6 AND
				[BusyEntry].[Date] > [inserted].[EndDate]
				THEN [BusyEntry].[Planned]
			ELSE [BusyEntry].[Canceled]
		END
	FROM
		[BusyEntry]
		INNER JOIN [inserted]
			ON [inserted].[ID] = [BusyEntry].[TaskID]
		INNER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	DECLARE @ToState TState,
			@FromState TState,
			@value TVariant,
			@Approve bit,
			@UserID int
	
	SET @value = NULL
	SET @UserID = dbo.adfGetCurrentUserID()		
	
	SELECT
		@FromState = [State]
	FROM
		[deleted]
	
	SELECT
		@ToState = [State]
	FROM
		[inserted]
	
	SELECT @value = [Value] FROM [UserParameter] WHERE [Name] = 'TimeEntryApproveForDocumentInFinalState' AND [UserID] = @UserID
	SET @Approve = ISNULL(CAST(@value as bit), 0)
	
	IF @ToState = 3 AND @FromState = 2 AND @Approve = 1
	BEGIN
		DECLARE @DocumentClass TClass,
				@DocumentID TIdentifier
		SELECT
				@DocumentClass = [Class],
				@DocumentID = [ID]
		FROM
			[inserted]		
		EXEC pjm6TimeEntryAutoApproveForDocumentInFinalState @DocumentClass, @DocumentID
	END
	
END
GO
