IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TimeEntryOwnCalendarBrowse')
	BEGIN
		PRINT 'Dropping Procedure TimeEntryOwnCalendarBrowse'
		DROP  Procedure  TimeEntryOwnCalendarBrowse
	END

GO

PRINT 'Creating Procedure TimeEntryOwnCalendarBrowse'
GO
/******************************************************************************
**		File: 
**		Name: TimeEntryOwnCalendarBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure TimeEntryOwnCalendarBrowse
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	DECLARE @employeeID int

	SET NOCOUNT ON
	
	SET @employeeID = dbo.adfGetCurrentEmployeeID()
	
	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[FileAs],
		[TimeEntry].[StartTime],
		DATEADD(minute, [TimeEntry].[Duration], [TimeEntry].[StartTime]) as [EndTime],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[ProjectID],
		[Project].[Number] as [ProjectCode],
		[TimeEntry].[TaskID],
		[Task].[FileAs] as [TaskName],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[Billable],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[Modified],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		[Class].[Guid]
	FROM
		[TimeEntry] INNER JOIN [Class]
			ON ([TimeEntry].[Class] = [Class].[Class])
		LEFT OUTER JOIN [Project]
			ON [TimeEntry].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Task]
			ON [TimeEntry].[TaskID] = [Task].[ID]
	WHERE
		[TimeEntry].[EmployeeID] = @employeeID 
		AND
		[TimeEntry].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd
	UNION ALL
	SELECT
		[MeetingRequest].[Class],
		[MeetingRequest].[ID],
		[MeetingRequest].[State],
		[MeetingRequest].[FileAs],
		[MeetingRequest].[StartTime],
		DATEADD(minute, [MeetingRequest].[Duration], [MeetingRequest].[StartTime]) as [EndTime],
		[MeetingRequest].[ActivityTypeID],
		[MeetingRequest].[ProjectID],
		[Project].[Number] as [ProjectCode],
		NULL,
		[MeetingRequest].[Location],
		[MeetingRequest].[OriginatorEmployeeID],
		0,
		[MeetingRequest].[Color],
		[MeetingRequest].[Comments],
		[MeetingRequest].[Created],
		[MeetingRequest].[Modified],
		[MeetingRequest].[CreatedBy],
		[MeetingRequest].[ModifiedBy],
		[MeetingRequest].[Timestamp],
		[Class].[Guid]
	FROM
		[MeetingRequest] INNER JOIN [Class]
			ON ([MeetingRequest].[Class] = [Class].[Class])
		LEFT OUTER JOIN [Project]
			ON [MeetingRequest].[ProjectID] = [Project].[ID]
	WHERE
		(
			[MeetingRequest].[OriginatorEmployeeID] = @employeeID AND [MeetingRequest].[State] NOT IN (3, 4)
		OR
			(EXISTS(SELECT * FROM [Attendee] WHERE [MeetingRequestID] = [MeetingRequest].[ID] AND [EmployeeID] = @employeeID AND ([ResponseType] IS NULL OR [ResponseType] IN ('Accept', 'Tentative'))) AND [MeetingRequest].[State] = 2)
		)
	AND
		[MeetingRequest].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd
	
	RETURN 0
GO

GRANT EXEC ON TimeEntryOwnCalendarBrowse TO PUBLIC
GO
 